#!/bin/sh
# 
# if your're using this script, you have to provide an on_error function
# and you must have included functions.sh

# appl: e.g. innovaphone-reporting
# folder: e.g. web/innovaphone-reporting
function install_web()
{
    appl=$1
    folder=$2
    doc_root=/var/www/innovaphone
    username="www-data"
    groupname="www-data"

    innovaphone_dir=$doc_root
    innovaphone_apps_dir=$doc_root/apps
    app_dir=$doc_root/apps/${appl}
    log_msg "innovaphone web server directory: $innovaphone_dir"
    log_msg "${appl} web directory: $app_dir"
    app_tmp=`mktemp -d ./$(basename $0).XXXXXX`
    if [ $? -ne 0 ]; then
        log_error "Can't create temp dir for application files, exiting..."
	    on_error
        exit 1
    fi
    chown $username:$groupname $app_tmp
    chmod 777 $app_tmp
    chown $username:$groupname ./
    if [ ! -d $innovaphone_dir ]; then
        log_error "Innovaphone directory does not exist, exiting..."
	    on_error
        exit 1
    fi
    if [ ! -d $innovaphone_apps_dir ]; then
        log_msg "No application installed, create application directory"
        mkdir $innovaphone_apps_dir
        chown $username:$groupname $innovaphone_apps_dir
    fi

    if ! chmod -R 755 $folder 2>/dev/null
    then
        log_error "Problem changing permissions"
        on_error
        exit 1
    fi
    
    if ! find "$folder" -type f -iname "*.php" | xargs dos2unix -f 2>/dev/null
    then
        log_error "Problem converting to unix format"
        on_error
        exit 1
    fi

    if ! chown -R $username:$groupname $folder 2>/dev/null
    then
        log_error "Problem converting files to lighttpd user and group"
        on_error
        exit 1
    fi
    
    if [ ! -d ${folder}/tmp ]; then
        log_msg "Creating application tmp directory"
        mkdir ${folder}/tmp
    fi
    if [ ! -d ${folder}/log ]; then
        log_msg "Creating application log directory"
        mkdir ${folder}/log
    fi

    chown -R ${appl}:$groupname ${folder}
    #chmod -R 775 ${folder}/report_images 
    chmod -R 775 ${folder}/tmp 
    chmod -R 775 ${folder}/log
    if [ -d ${app_dir} ]; then
        mv -f $folder/* ${app_dir}
    else
        mv -f $folder $innovaphone_apps_dir
    fi
    
    dos2unix ${app_dir}/version 2>/dev/null
    app_version=`cat ${app_dir}/version`;
    app_hotfix=`cat ${app_dir}/hotfix`;
    app_xml=${app}.xml
    dos2unix ${app_xml} 2>/dev/null
    echo "    <version>${app_version}</version>" >> ${app_xml}
    echo "    <hotfix>${app_hotfix}</hotfix>" >> ${app_xml}
    echo "</application>" >> ${app_xml}
    mv ${app_xml} ${innovaphone_apps_dir}
    chown $username:$groupname ${innovaphone_apps_dir}/${app}.xml
}