/*
 *  Report generator
 */
#include "fcgi_stdio.h"
#include <stdio.h>
#include <stdlib.h>
#include <syslog.h>
#include <time.h>
#include <string.h>
#include "libpq-fe.h"
#include "inno-lib/inno-lib.h"
#include "pg_report.h"
#include "reporting/reporting_config.h"
#include <setjmp.h>
#include "hpdf.h"
#include "libpq-fe.h"
#include "zlib.h"

#define QUERY_MISSED_UPDATE     "UPDATE cdr_users SET missed_calls_time=date_trunc('second', localtimestamp) WHERE cn='%s' AND %s='%s'"

//#define _ADD_CALL_FLOW
//#define TEST_PERFORMANCE

#ifdef TEST_PERFORMANCE
//#define strcpy(x, y) t_strcpy(x, y)
//#define strcat(x, y) t_strcat(x, y)
#endif

const char* xml_events_print[] = {
    " caller=\"",
    " ep1_number=\"",
    " ep1_name=\"",
    " ep1_dn=\"",
    " ep2_number=\"",
    " ep2_name=\"",
    " ep2_dn=\"",
    " status=\"",
    " type=\"",
    " entry=\""
};
int num_xml_events_print = sizeof(xml_events_print)/sizeof(const char*);

const char* pdf_events_attrib[] = {
    "caller",
    "img_caller",
    "ep1_number",
    "ep1_name",
    "ep1_dn",
    "ep1",
    "img_ep1",
    "ep2_number",
    "ep2_name",
    "ep2_dn",
    "ep2",
    "img_ep2",
    "status",
    "img_status",
    "type",
    "entry"
};
int num_pdf_events_attrib = sizeof(pdf_events_attrib)/sizeof(const char*);

const char* xml_events_attrib[] = {
    "caller",
    "ep1_number",
    "ep1_name",
    "ep1_dn",
    "ep2_number",
    "ep2_name",
    "ep2_dn",
    "status",
    "type",
    "entry"
};
int num_xml_events_attrib = sizeof(xml_events_attrib)/sizeof(const char*);

const char* call_flow_indexes_pdf[] = {
    "number",
    "name",
    "dn",
    "formatted"
};
int num_call_flow_indexes_pdf = sizeof(call_flow_indexes_pdf)/sizeof(const char*);

const char* call_flow_indexes_xml[] = {
    "number",
    "name",
    "dn",
};
int num_call_flow_indexes_xml = sizeof(call_flow_indexes_xml)/sizeof(const char*);

const char* msg_lookup_table[] = {
    "alert-to",
    "alert-from",
    "setup-to",
    "setup-from",
    "conn-to",
    "conn-from",
    "transfer-to",
    "transfer-from",
    "transfer-remote",
    "transfered",
    "forwarded",
    "connected",
    "disc-from",
    "disc-to",
    "rel-from",
    "rel-to",
    "cf-from",
    "cf-to",
    "scf",
    "sct",
    "from",
    "to",
    "ct",
    "cf",
    "ep",
    "pickup-from",
    "reject-from",
    "info-from",
    "info-to",
    "unknown",
};
int num_msg_lookup_table = sizeof(msg_lookup_table)/sizeof(const char*);

const char* image_lookup_table[] = {
    "dummy.jpg",
    "busy.jpg",
    "busy_callback.jpg",
    "conn.jpg",
    "conn_callback.jpg",
    "dir_in.jpg",
    "dir_out.jpg",
    "dir_in_pdf.jpg",
    "dir_out_pdf.jpg",
    "error.jpg",
    "error_callback.jpg",
    "error_pdf.jpg",
    "cf.jpg",
    "cf_rev.jpg",
    "cf_pdf.jpg",
    "cf_rev_pdf.jpg",
    "ct.jpg",
    "ct_rev.jpg",
    "ct_pdf.jpg",
    "ct_rev_pdf.jpg",
    "cct.jpg",
    "cct_rev.jpg",
    "no_res.jpg",
    "no_res_callback.jpg",
    "no_res_pdf.jpg",
    "state.jpg",
    "pickup.jpg",
    "pickup_rev.jpg",
    "pickup_pdf.jpg",
    "pickup_rev_pdf.jpg",
};
int num_image_lookup_table = sizeof(image_lookup_table)/sizeof(const char*);

const char *parse_errors[] = {
    "config parsing was successful",
    "connection string to database is empty",
    "no memory available for connection string",
    "query string is empty",
    "no memory available for query string",
    "href string is empty",
    "no memory available for href",
    "format string is empty",
    "no memory available for format string",
    "server string is empty",
    "no memory available for server string",
    "filename string is empty",
    "no memory available for filename string",
    "no memory available for sort order string",
    "no memory available for sort value string",
    "no memory available for group value string",
    "no memory available for logo image string",
    "no memory available for footer image string",
    "no memory available for columns string",
    "no memory available for mypbx translations",
    "cn string is empty",
    "no memory available for cn",
    "no memory available for language",
    "no memory available for displayed duration",
    "user group string is empty",
    "no memory available for user group",
    "no memory available for user pbx"
};

int num_parse_errors = sizeof(parse_errors)/sizeof(const char*);

const char* column_lookup_table[] = {
    "local_stamp",
    "date_part('epoch', local_stamp AT TIME ZONE 'UTC') AS unix_time",
    "cu.cn",
    "cdrp_conf",
    "cdr_dir",
    "cdrp_type",
    "alert_duration",
    "cdrp_callback_e164",
    "cdrp_callback_h323",
    "cdrp_callback_dn",
    "cdrp_callback_time",
    "date_part('epoch', cdrp_callback_time AT TIME ZONE 'UTC') AS unix_time_callback",
    "cdrp_call_flow",
    "call_duration",
    "conn_duration",
    "billing_duration",
    "cdrp_cdr_id_groups",
    "cu.sys",
    "cdr_node",
    "cu.pbx",
    "cdr_phys",
    "cause_code",
    "date_part('epoch', utc_stamp AT TIME ZONE 'UTC') AS utc_unix_time",
    "datum",
    "time",
    "datum_sort",
    "id",
    "recorder_path"
};
int num_column_lookup_table = sizeof(column_lookup_table)/sizeof(const char*);

const char* xml_lookup_table_open[] = {
    "    <time time=\"",
    "",
    "    <obj>",
    "    <id>",
    "",
    "    <call>",
    "    <alert-duration seconds=\"",
    "",
    "",
    "",
    "",
    "",
    "    <flow>",
    "    <call-duration seconds=\"",
    "    <conn-duration seconds=\"",
    "    <billing-duration seconds=\"",
    "    <groups>",
    "    <system>",
    "    <node>",
    "    <pbx>",
    "    <phys>",
    "    <cause>",
    "",
    "",
    "",
    "",
    "",
    "    <vr-path>"
};

const char* xml_lookup_table_close[] = {
    "</time>\r\n",
    "",
    "</obj>\r\n",
    "</id>\r\n",
    "",
    "</call>\r\n",
    "</alert-duration>\r\n",
    "",
    "",
    "",
    "",
    "",
    "</flow>\r\n",
    "</call-duration>\r\n",
    "</conn-duration>\r\n",
    "</billing-duration>\r\n",
    "</groups>\r\n",
    "</system>\r\n",
    "</node>\r\n",
    "</pbx>\r\n",
    "</phys>\r\n",
    "</cause>\r\n",
    "",
    "",
    "",
    "",
    "",
    "</vr-path>\r\n"
};

const char* xml_lookup_table[] = {
    "time",
    "",
    "obj",
    "id",
    "",
    "call",
    "alert-duration",
    "",
    "",
    "",
    "",
    "",
    "flow",
    "call-duration",
    "conn-duration",
    "billing-duration",
    "groups",
    "system",
    "node",
    "pbx",
    "phys",
    "cause",
    "",
    "",
    "",
    "",
    "",
    "vr-path"
};

const char* image_load_table[] = {
    "apps/innovaphone-reporting/images/dir.jpg",        /* dummy, avoid error when loading */
    "apps/innovaphone-reporting/images/busy.jpg",
    "apps/innovaphone-reporting/images/busy_callback.jpg",
    "apps/innovaphone-reporting/images/conn.jpg",
    "apps/innovaphone-reporting/images/conn_callback.jpg",
    "apps/innovaphone-reporting/images/dir_in.jpg",
    "apps/innovaphone-reporting/images/dir_out.jpg",
    "apps/innovaphone-reporting/images/dir_in_pdf.jpg",
    "apps/innovaphone-reporting/images/dir_out_pdf.jpg",
    "apps/innovaphone-reporting/images/error.jpg",
    "apps/innovaphone-reporting/images/error_callback.jpg",
    "apps/innovaphone-reporting/images/error_pdf.jpg",
    "apps/innovaphone-reporting/images/cf.jpg",
    "apps/innovaphone-reporting/images/cf_rev.jpg",
    "apps/innovaphone-reporting/images/cf_pdf.jpg",
    "apps/innovaphone-reporting/images/cf_rev_pdf.jpg",
    "apps/innovaphone-reporting/images/ct.jpg",
    "apps/innovaphone-reporting/images/ct_rev.jpg",
    "apps/innovaphone-reporting/images/ct_pdf.jpg",
    "apps/innovaphone-reporting/images/ct_rev_pdf.jpg",
    "apps/innovaphone-reporting/images/cct.jpg",
    "apps/innovaphone-reporting/images/cct_rev.jpg",
    "apps/innovaphone-reporting/images/no_res.jpg",
    "apps/innovaphone-reporting/images/no_res_callback.jpg",
    "apps/innovaphone-reporting/images/no_res_pdf.jpg",
    "apps/innovaphone-reporting/images/state.jpg",
    "apps/innovaphone-reporting/images/pickup.jpg",
    "apps/innovaphone-reporting/images/pickup_rev.jpg",
    "apps/innovaphone-reporting/images/pickup_pdf.jpg",
    "apps/innovaphone-reporting/images/pickup_rev_pdf.jpg",
};

#define NUM_PDF_IMAGES         sizeof(image_load_table)/sizeof(const char*)
#define XML_EVENTS_ATTRIB      sizeof(xml_events_attrib)/sizeof(const char*)
#define PDF_EVENTS_ATTRIB      sizeof(pdf_events_attrib)/sizeof(const char*)
#define CALL_FLOW_INDEXES_XML  sizeof(call_flow_indexes_xml)/sizeof(const char*)
#define CALL_FLOW_INDEXES_PDF  sizeof(call_flow_indexes_pdf)/sizeof(const char*)
#define NUM_PRINT_XML_EVENTS   sizeof(xml_events_print)/sizeof(const char*)
#define TOTAL_NUMBER_COLUMNS   sizeof(column_lookup_table)/sizeof(const char*)

inline int m_strchr(char *src, char c) 
{
    int i;
    for(i=0; src[i] != c; i++);
    return i;
}

inline char * t_strcat(char *dest, const char *src)
{
    size_t i,j;
    for (i = 0; dest[i] != '\0'; i++)
        ;
    for (j = 0; src[j] != '\0'; j++)
        dest[i+j] = src[j];
    dest[i+j] = '\0';
    return dest;
}

inline char *t_strcpy(char *dest, const char *src)
{
  unsigned i=0;
  for (i=0; src[i] != '\0'; ++i)
    dest[i] = src[i];
  dest[i] = '\0';
  return dest;
}

static void 
defaultNoticeProcessor (void * arg, const char * message) 
{ 
    //printf ("Error: %s", message); 
    do_log(LOG_REPORTING, "", "reporting: PG ERROR %s", message);
}

static void
error_handler  (HPDF_STATUS   error_no,
                HPDF_STATUS   detail_no,
                void         *user_data)
{
    do_log(LOG_REPORTING, "", "reporting: PDF ERROR no=%04X, detail_no=%u", (HPDF_UINT)error_no, (HPDF_UINT)detail_no);
    //printf ("ERROR: error_no=%04X, detail_no=%u\n", (HPDF_UINT)error_no,
    //            (HPDF_UINT)detail_no);
}

static int
lookup_image(const char *image)
{
    int i;

    for(i=0; i<NUM_PDF_IMAGES; i++) {
        if( !strcmp( image, image_lookup_table[i]) )
            return i;
    }
    return 0;
}

static int
lookup_msg(char msg[])
{
    int i;
    const int available_msgs = sizeof msg_lookup_table / sizeof *msg_lookup_table;
    for(i=0; i<available_msgs; i++) {
        if( !strcmp( msg, msg_lookup_table[i]) )
            return i;
    }
    return 0;
}

#define SEMI_CHAR 0x3B
#define AMP_CHAR 0x26
#define COMMA_CHAR 0x2C
#define SLASH_CHAR 0x2F
#define A_CHAR 0x61
#define G_CHAR 0x67
#define L_CHAR 0x6C
#define M_CHAR 0x6D
#define O_CHAR 0x6F
#define P_CHAR 0x70
#define Q_CHAR 0x71
#define S_CHAR 0x73
#define T_CHAR 0x74
#define U_CHAR 0x75
#define LEFT_CURLY_BRACKET_CHAR 0x7B
#define RIGHT_CURLY_BRACKET_CHAR 0x7D

/*
 *  It returns the length of the field
 */

inline int
find_separator(char *inp, int separator) {
    int ret=1, slashs = 0;

    /* field is empty */
    if(inp[0] == separator) return 0;
    if(inp[0] == SLASH_CHAR) slashs++;

    while((inp[ret] != separator) || (slashs & 1)) {
        if(inp[ret] == SLASH_CHAR) slashs++;
        else slashs = 0;
        ret++;
    }
    return ret;
}

inline void
strcpy_unescape(char *dst, char *src, int len) {
    int i, ind_out = 0;

    for(i=0;i<len;i++) {
        if((int)src[i] == SLASH_CHAR) {
            i++;
        }
        dst[ind_out++] = src[i];
    }
    dst[ind_out] = '\0';
}

inline int
xmlentities_unescape(char *inp, char *out, int len)
{
    int i, ind_out;

    out[0] = 0;

    for(i=0,ind_out=0;i<len;i++) {
        switch((int)inp[i]) {
            case 38:	/*&*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = A_CHAR;
                out[ind_out++] = M_CHAR;
                out[ind_out++] = P_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 34:	/*"*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = Q_CHAR;
                out[ind_out++] = U_CHAR;
                out[ind_out++] = O_CHAR;
                out[ind_out++] = T_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 39:	/*'*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = A_CHAR;
                out[ind_out++] = P_CHAR;
                out[ind_out++] = O_CHAR;
                out[ind_out++] = S_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 60:	/*<*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = L_CHAR;
                out[ind_out++] = T_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 62:	/*>*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = G_CHAR;
                out[ind_out++] = T_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 47:	/*/*/
                i++;
                out[ind_out++] = inp[i];
                break;
            default:
                out[ind_out++] = inp[i];
        }
    }
    out[ind_out++] = 0;

    return ind_out;
}

inline int
xmlentities(char *inp, char *out, int len)
{
    int i, ind_out;

    out[0] = 0;

    for(i=0,ind_out=0;i<len;i++) {
        switch((int)inp[i]) {
            case 38:	/*&*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = A_CHAR;
                out[ind_out++] = M_CHAR;
                out[ind_out++] = P_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 34:	/*"*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = Q_CHAR;
                out[ind_out++] = U_CHAR;
                out[ind_out++] = O_CHAR;
                out[ind_out++] = T_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 39:	/*'*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = A_CHAR;
                out[ind_out++] = P_CHAR;
                out[ind_out++] = O_CHAR;
                out[ind_out++] = S_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 60:	/*<*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = L_CHAR;
                out[ind_out++] = T_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            case 62:	/*>*/
                out[ind_out++] = AMP_CHAR;
                out[ind_out++] = G_CHAR;
                out[ind_out++] = T_CHAR;
                out[ind_out++] = SEMI_CHAR;
                break;
            default:
                out[ind_out++] = inp[i];
        }
    }
    out[ind_out++] = 0;

    return ind_out;
}

static void free_allocated_mem(char ***events, int num_events, int num_subevents, int offset, int err)
{
    int i, j, l;
    char **ttemp = *events;
    
    if(err) {
        do_log(LOG_REPORTING, "", "reporting: ERROR no memory available");
    }

    for(i=0;i<num_events;i++) {
        l = offset;
        while(l-->0) ttemp++;
        for(j=offset;j<num_subevents;j++) {
            if(*ttemp) free(*ttemp);
            ttemp++;
        }
    }
    free(*events);
    *events = NULL;
}

static int
pg_array_parse_xml(char *text, int cause, int c_type, char ***events, char ***subevents, int *numEvents, xml_strings *ptr_xml, remote_t *remote, int digits_to_hide, int anonym, char *pbx, char *phys, ldap_servers_t *ldap_servers)
{
    char *remote_e164 = NULL;
    char *remote_h323 = NULL;
    char *remote_dn = NULL;
    char *remote_f = NULL;
    int i, j;
    char **p_div, **tmp_events, **ttemp, **ptr_ev_state, **sub_events, **sct_event = NULL;
    char *ttemp_msg;
    int ind = 0, start_ind = 0, ind_t, is_scf = 0;
    int cnt = 0, is_call_state = 0, max_string_len = 0, is_transfer = 0;
    char *ep1_last_name = NULL, *ep1_last_number = NULL, *ep1_last_dn = NULL;
    char *ep2_last_name = NULL, *ep2_last_number = NULL, *ep2_last_dn = NULL;
    char *last_name = NULL, *last_number = NULL, *last_dn = NULL;
    char *cause_code = NULL;
    char **call_state = NULL;
    char *msg_buffer;
    int *call_flow_msgs;
    int ep1_right = 0;
    *numEvents=0;

    switch(cause) {
        case codeUnalloc:            /* 1 */
        case codeNoRouteSpec:        /* 2 */
        case codeNoRouteDest:        /* 3 */
        case codeChUnacep:           /* 6 */
        case codeCallRej:            /* 21 */
        case codeDestOutOrder:       /* 27 */
        case codeInvNumberFormat:    /* 28 */
        case codeNoCircChAv:         /* 34 */
        case codeNetworkOutOrder:    /* 38 */
        case codeTempFailure:        /* 41 */
        case codeReqNoCircChAv:      /* 44 */
        case codeResourcesUnav:      /* 47 */
        case codeOutCallsBarred:     /* 52 */
        case codeServOptUnav:        /* 63 */
        case codeNoBearerCapImp:     /* 65 */
        case codeIncompDest:         /* 88 */
        case codeRecOnTimerExp:      /* 102 */
        case codeProtError:          /* 111 */
        case codeInterworkUnspec:    /* 127 */
            cause_code = ptr_xml->er;
            break;
        case codeNoUserResp:         /* 18 */
        case codeNoRespFromUser:     /* 19 */
            cause_code = ptr_xml->al;
            ptr_xml->state = ptr_xml->al;
            break;
        case codeUserBusy:           /* 17 */
            cause_code = ptr_xml->bu;
            ptr_xml->state = ptr_xml->bu;
            break;
    }

    int len_text = strlen(text);
    int secArray = 0;
    for(i=1;i<len_text-2;i++) {                                                 /* {{,,,},{,,,},...,{,,,}}, skip first { */
        if(((text[i] == 0x7D) && (text[i+1] == 0x2C) && (text[i+2] == 0x7B)) || /* },{*/
           ((text[i+1] == 0x7D) && (text[i+2] == 0x7D))) {                      /* }} */ 
            secArray++;
            if(text[i+2] == 0x7D) 
                break;
        }
    }

    if(secArray > MAX_NUM_EVENTS) secArray = MAX_NUM_EVENTS;

    *subevents = (char **)malloc(secArray*CALL_FLOW_INDEXES_XML*sizeof(char *));
    if(*subevents == NULL) {
        do_log(LOG_REPORTING, "", "reporting: couldn't get memory for temp!");
        return -1;
    }
    ttemp = *subevents;
    for(i=0;i<(secArray*CALL_FLOW_INDEXES_XML);i++) {
       *ttemp++ = NULL;
    }

    call_flow_msgs = (int *)malloc(secArray*sizeof(int));
    if(call_flow_msgs == NULL) {
        do_log(LOG_REPORTING, "", "reporting: couldn't get memory for call flow messages!");
        free_allocated_mem(subevents, secArray, CALL_FLOW_INDEXES_XML, 0, FLAG_ERROR);                         /* msg, dir */
        return -1;
    }

    for(i=0;i<num_msg_lookup_table;i++) {
        max_string_len = MAX(strlen(msg_lookup_table[i]), max_string_len);
    }
    msg_buffer = (char *)malloc((max_string_len << 2)*sizeof(char));
    if(msg_buffer == NULL) {
        do_log(LOG_REPORTING, "", "reporting: couldn't get memory for msg buffer!");
        free(call_flow_msgs);
        free_allocated_mem(subevents, secArray, CALL_FLOW_INDEXES_XML, 0, FLAG_ERROR);                         /* msg, dir */
        return -1;
    }

    if(trace_level & TRACE_CALL_FLOW) {
        do_log(LOG_REPORTING, "", "reporting: call-flow: %s %p", text, *subevents);
    }

    ttemp = *subevents;
    for(i=0,j=2;i<secArray;i++) {           /* j chars */
        int l, msg_length, e164_length, h323_length, dn_length, hide = 0;
        char *pch, *h323_xml_entities = NULL, *e164 = NULL, *dn_xml_entities = NULL;

        /* calculate length of each parameter */
        pch = &text[j];
        for(msg_length=0; *pch++ != ',' && *pch; msg_length++);
        for(e164_length=0; *pch++ != ',' && *pch; e164_length++);
        h323_length = find_separator(pch, COMMA_CHAR);
        pch = &pch[h323_length+1];
        dn_length = find_separator(pch, RIGHT_CURLY_BRACKET_CHAR);

        /* allocate memory */
        if(e164_length) e164 = (char *)malloc(((e164_length+1)<<2)*sizeof(char)); 
        if(h323_length) h323_xml_entities = (char *)malloc(((h323_length+1)<<3)*sizeof(char));      /* 6 == '&quot;' */
        if(dn_length) dn_xml_entities = (char *)malloc(((dn_length+1)<<3)*sizeof(char));            /* 6 == '&quot;' */
        
        pch = &text[j];

        /* msg */
        ttemp_msg = msg_buffer;
        for (l=0; l<msg_length; l++)
            *ttemp_msg++ = *pch++;
        *ttemp_msg = '\0';
        if(trace_level & TRACE_CALL_FLOW) {
            do_log(LOG_REPORTING, "", "reporting: msg[%d]: %s", msg_length, msg_buffer);
        }
        call_flow_msgs[i] = lookup_msg(msg_buffer);
        if(call_flow_msgs[i] == SCF_MSG)
            is_scf++;
        else if((call_flow_msgs[i] == SCT_MSG) && (sct_event == NULL)) 
            sct_event = ttemp;

        /* e164 */
        pch++;
        *ttemp = e164;
        if(e164_length) {
            if(digits_to_hide && ldap_servers->ldap != NULL) {
                ldap_t **servers = ldap_servers->ldap;
 
                while(*servers != NULL) {
                    ldap_t *tmp = *servers;
                    if(strcmp(phys,"")) {
                        if((!strcasecmp(tmp->pbx, phys) || !strcmp(tmp->pbx, "%"))  && (strncmp(pch, tmp->el, strlen(tmp->el)) == 0) ) {
                            hide = 1;
                            break;
                        }
                    } else {
                        if((!strcasecmp(tmp->pbx, pbx) || !strcmp(tmp->pbx, "%")) && (strncmp(pch, tmp->el, strlen(tmp->el)) == 0) ) {
                            hide = 1;
                            break;
                        }
                    }
                    servers++;
                    if(trace_level & TRACE_CALL_FLOW) {
                        do_log(LOG_REPORTING, "", "check phys[%d] %s(%d) %s(%d) %s(%d) el=%d - %s len=%d cmp=%d-%d-%d", hide, tmp->pbx, strlen(tmp->pbx), phys, strlen(phys), pbx, strlen(pbx), pch[0], tmp->el, strlen(tmp->el), strcasecmp(tmp->pbx, phys), strcasecmp(tmp->pbx, pbx), strncmp(pch, tmp->el, strlen(tmp->el)));
                    }
                }

                if(hide) {
                    if(digits_to_hide > e164_length) {
                        memset(e164, 0x2a, e164_length);
                        e164[e164_length] = '\0';
                        pch += e164_length;
                    } else {
                        for(l = 0; l < (e164_length - digits_to_hide); l++) {
                            *e164++ = *pch++;
                        }
                        for(; l < e164_length; l++) {
                           *e164++ = 0x2a;
                           pch++;
                        }
                        *e164 = '\0';
                    }
                } else {
                    for (l=0; l<e164_length; l++)
                        *e164++ = *pch++;
                    *e164 = '\0';
                }
            } else {
                for (l=0; l<e164_length; l++)
                    *e164++ = *pch++;
                *e164 = '\0';
            }
            if(trace_level & TRACE_CALL_FLOW) {
                do_log(LOG_REPORTING, "", "reporting: e164[%d]: %s", e164_length, *ttemp);
            }
        }
        if(anonym && !hide) {
            if(e164_length) {
                strcpy(*ttemp, "*"); // points to e164
            }
            else {
                *ttemp = malloc(2*sizeof(char));
                strcpy(*ttemp, "*");
            }
        }
        ttemp++;

        /* h323 */
        pch++;
        if(hide || anonym) {
            free(h323_xml_entities);
            h323_xml_entities = NULL;
        } else {
            if(h323_length) {
                xmlentities_unescape(pch, h323_xml_entities, h323_length);
                if(trace_level & TRACE_CALL_FLOW) {
                    do_log(LOG_REPORTING, "", "reporting: h323[%d]: %s", h323_length, h323_xml_entities);
                }
            }
        }
        pch += h323_length + 1;  /* , */
        *ttemp++ = h323_xml_entities;

        /* dn */
        if(hide || anonym) {
            free(dn_xml_entities);
            dn_xml_entities = NULL;
        } else {
            if(dn_length) {
                xmlentities_unescape(pch, dn_xml_entities, dn_length);
                if(trace_level & TRACE_CALL_FLOW) {
                    do_log(LOG_REPORTING, "", "reporting: dn[%d]: %s", dn_length, dn_xml_entities);
                }
            }
        }
        *ttemp++ = dn_xml_entities; 
        j += msg_length + 1 + e164_length + 1 + h323_length + 1 + dn_length + 3;
    }

    if(trace_level & TRACE_CALL_FLOW_TOTAL) {
        ttemp = *subevents;
        for(ind_t=0; ind_t<secArray; ind_t++) {
            do_log(LOG_REPORTING, "", "reporting: %s-%s-%s-%s", 
                   msg_lookup_table[call_flow_msgs[ind_t]], 
                   *(ttemp+ind_t*CALL_FLOW_INDEXES_XML+NUMBER_XML), 
                   *(ttemp+ind_t*CALL_FLOW_INDEXES_XML+NAME_XML), 
                   *(ttemp+ind_t*CALL_FLOW_INDEXES_XML+DN_XML));
        }
    }

    *events = (char **)malloc((secArray*XML_EVENTS_ATTRIB)*sizeof(char *));
    if(*events == NULL) {
        free(msg_buffer);
        free(call_flow_msgs);
        free_allocated_mem(subevents, secArray, CALL_FLOW_INDEXES_XML, 0, FLAG_ERROR);                         /* msg, dir */
        return -1;
    }
    tmp_events = *events;
    for(i=0;i<(secArray*XML_EVENTS_ATTRIB);i++) {
        *tmp_events++ = NULL;
    }

    ttemp = *subevents;
    tmp_events = *events;

    if((call_flow_msgs[0] == CF_MSG) || (call_flow_msgs[0] == CT_MSG)) {
        if(call_flow_msgs[1] == SETUP_TO_MSG) {
            ptr_xml->tmpDir = ptr_xml->ep2;
        } else if(call_flow_msgs[1] == SETUP_FROM_MSG) {
            ptr_xml->tmpDir = ptr_xml->ep1;
        }
    } else {
        if(call_flow_msgs[0] == TO_MSG) {
            ptr_xml->tmpDir = ptr_xml->ep2;
        }
        else if(call_flow_msgs[0] == FROM_MSG) {
            ptr_xml->tmpDir = ptr_xml->ep1;
        }
    }

    if(is_scf || (sct_event != NULL)) {
        /* to-h323-e164-dn */
        ep1_last_number = *ttemp++;        /* e164 */
        ep1_last_name = *ttemp++;          /* h323 */
        ep1_last_dn = *ttemp++;            /* dn */
        /* setup-h323-e164-dn */
        ep2_last_number = *ttemp++;        /* e164 */
        ep2_last_name = *ttemp++;          /* h323 */
        ep2_last_dn = *ttemp++;            /* dn */
        if(ep2_last_number) {
            remote_e164 = (char *)malloc((strlen(ep2_last_number)+1)*sizeof(char)); 
            strcpy(remote_e164, ep2_last_number);
        }
        if(ep2_last_name) {
            remote_h323 = (char *)malloc((strlen(ep2_last_name)+1)*sizeof(char)); 
            strcpy(remote_h323, ep2_last_name);
        }
        if(ep2_last_dn) {
            remote_dn = (char *)malloc((strlen(ep2_last_dn)+1)*sizeof(char)); 
            strcpy(remote_dn, ep2_last_dn);
        }
        /* scf/sct-h323-e164 */
        if(sct_event != NULL) {
            char **sct_event_tmp = sct_event;
            int first_sct = 1;

            /* ct event happens before cf event if any */ 
            if(sct_event == ttemp) {
               ttemp += CALL_FLOW_INDEXES_XML;
               cnt = 3;                                             /* to/from-setup-sct-? */
            } else {
               cnt = 2;                                             /* to/from-setup-scf-...-sct */
            }
            tmp_events++;                                           /* caller is unknown with a 'ct' */
            *tmp_events++ = *sct_event++;                           /* e164 */
            *tmp_events++ = *sct_event++;                           /* h323 */
            *tmp_events++ = *sct_event++;                           /* dn */
            *tmp_events++ = ep2_last_number;
            *tmp_events++ = ep2_last_name;
            *tmp_events++ = ep2_last_dn;
            *tmp_events++ = ptr_xml->co;                            /* state */
            tmp_events += 2;                                        /* type/entry */
            ind = 1;
            while((call_flow_msgs[cnt] == SCF_MSG) && (ttemp != sct_event_tmp)) {
                /* New Event */
                tmp_events++;                                       /* caller */
                *tmp_events++ = *ttemp++;                           /* e164 */
                *tmp_events++ = *ttemp++;                           /* h323 */
                *tmp_events++ = *ttemp++;                           /* dn */
                tmp_events += 3;                                    /* ep2 */
                *tmp_events++ = ptr_xml->al;                        /* state */
                if(first_sct) {
                    *tmp_events++ = ptr_xml->ct;                    /* type */
                    first_sct = 0;
                } else
                    *tmp_events++ = ptr_xml->cf;                    /* type */
                tmp_events++;                                       /* entry */
                ind++;
                cnt++;                                              /* scf/sct */
            }
            /* ct event was reached, skip it */
            if(sct_event_tmp == ttemp) {
                ttemp += CALL_FLOW_INDEXES_XML;
            }
            /* New Event */
            tmp_events++;                                           /* caller */
            *tmp_events++ = ep1_last_number;                        /* e164 */
            *tmp_events++ = ep1_last_name;                          /* h323 */
            *tmp_events++ = ep1_last_dn;                            /* dn */
            tmp_events += 3;                                        /* ep2 */
            call_state = tmp_events;
            tmp_events++;
            if(is_scf)
                *tmp_events++ = ptr_xml->cf;                        /* type   */
            else
                *tmp_events++ = ptr_xml->ct;                        /* type   */
            ptr_xml->type = ptr_xml->ct;                            /* xml-type */
            *tmp_events++ = ptr_xml->true;                          /* entry  */
            ind++;
            start_ind = ind;
        } else {
            *tmp_events++ = ptr_xml->tmpDir;                        /* caller */
            *tmp_events++ = *ttemp++;                               /* e164 */
            *tmp_events++ = *ttemp++;                               /* h323 */
            *tmp_events++ = *ttemp++;                               /* dn */
            *tmp_events++ = ep2_last_number;
            *tmp_events++ = ep2_last_name;
            *tmp_events++ = ep2_last_dn;
            *tmp_events++ = ptr_xml->al;                            /* state */
            tmp_events += 2;                                        /* type/entry */
            ind = 1;
            cnt = 3;                                                /* to/from-setup-scf/sct */
            while(call_flow_msgs[cnt] == SCF_MSG) {
                /* New Event */
                tmp_events++;                                       /* caller */
                *tmp_events++ = *ttemp++;                           /* e164 */
                *tmp_events++ = *ttemp++;                           /* h323 */
                *tmp_events++ = *ttemp++;                           /* dn */
                tmp_events += 3;                                    /* ep2 */
                *tmp_events++ = ptr_xml->al;                        /* state */
                *tmp_events++ = ptr_xml->cf;                        /* type */
                tmp_events++;                                       /* entry */
                ind++;
                cnt++;                                              /* scf/sct */
            }
            /* New Event */
            tmp_events++;                                           /* caller */
            *tmp_events++ = ep1_last_number;                        /* e164 */
            *tmp_events++ = ep1_last_name;                          /* h323 */
            *tmp_events++ = ep1_last_dn;                            /* dn */
            tmp_events += 3;                                        /* ep2 */
            call_state = tmp_events;
            tmp_events++;
            *tmp_events++ = ptr_xml->cf;                            /* type   */
            ptr_xml->type = ptr_xml->cf;                            /* xml-type */
            *tmp_events++ = ptr_xml->true;                          /* entry  */
            ind++;
            start_ind = ind;
        }
        last_number = ep1_last_number;
        last_name = ep1_last_name;
        last_dn = ep1_last_dn;
    } else {
        int conn_disc_rel = 0;
        int f_pickup = 0;

        *tmp_events++ = ptr_xml->tmpDir;           /* caller */
        ep1_last_number = *ttemp++;
        ep1_last_name = *ttemp++;
        ep1_last_dn = *ttemp++;
        *tmp_events++ = ep1_last_number;           /* e164 */
        *tmp_events++ = ep1_last_name;             /* h323 */
        *tmp_events++ = ep1_last_dn;               /* dn   */
        /* actual msg is setup, if next alert better, more information available */
        if((call_flow_msgs[2] == ALERT_TO_MSG) || (call_flow_msgs[2] == ALERT_FROM_MSG) || 
           (call_flow_msgs[2] == TRANSFERRED_MSG) || (call_flow_msgs[2] == FORWARDED_MSG)) {
            int conn_index, alert_index;

            if((call_flow_msgs[3] == ALERT_TO_MSG) || (call_flow_msgs[3] == ALERT_FROM_MSG) || 
               (call_flow_msgs[3] == TRANSFERRED_MSG) || (call_flow_msgs[3] == FORWARDED_MSG)) {
                conn_index = 4;
                alert_index = 3;
            } 
            else {
                conn_index = 3;
                alert_index = 2;
            }
            // Check Pickup for internal calls
            if( (c_type == 0) && ((call_flow_msgs[conn_index] == CONN_TO_MSG) || (call_flow_msgs[conn_index] == CONN_FROM_MSG)) &&
                ((*(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NAME_XML) && *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NAME_XML) &&
                  strcmp(*(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NAME_XML), *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NAME_XML))) ||
                 (*(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+DN_XML) && *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+DN_XML) &&
                  strcmp(*(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+DN_XML), *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+DN_XML))) ||
                 (*(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NUMBER_XML) && *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NUMBER_XML) &&
                  (strlen(*(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NUMBER_XML)) == strlen(*(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NUMBER_XML))) &&
                  strcmp(*(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NUMBER_XML), *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NUMBER_XML)))) ) {
                f_pickup = 1;
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NUMBER_XML);       /* e164 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NAME_XML);         /* h323 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+DN_XML);           /* dn   */
                *tmp_events++= ptr_xml->al;               /* state */
                tmp_events++;                             /* type */
                *tmp_events++ = ptr_xml->true;            /* entry */
                
                tmp_events++;                             /* type */
                tmp_events += 3;                          /* ep1 */ 
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NUMBER_XML);       /* e164 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NAME_XML);         /* h323 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+DN_XML);           /* dn   */
                ep2_last_number = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NUMBER_XML);
                ep2_last_name = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NAME_XML);
                ep2_last_dn = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+DN_XML);
                *tmp_events++ = ptr_xml->co;              /* state */
                *tmp_events++ = ptr_xml->pu;              /* type */
                *tmp_events++ = ptr_xml->true;            /* entry */
                cnt = conn_index+1;                               /* to/from-setup-alert-transfered(?)-conn */
                ptr_xml->state = ptr_xml->co;
                is_call_state = 1;
                ind = start_ind = 2;
            }
            else {
                if((call_flow_msgs[conn_index] == CONN_TO_MSG) || (call_flow_msgs[conn_index] == CONN_FROM_MSG)) {
                    // if external call alert message contains called number
                    if(c_type && *(ttemp+CALL_FLOW_INDEXES_XML+NUMBER_XML)) {
                        ep2_last_number = *(ttemp+CALL_FLOW_INDEXES_XML+NUMBER_XML);
                        ep2_last_name = *(ttemp+CALL_FLOW_INDEXES_XML+NAME_XML);
                        ep2_last_dn = *(ttemp+CALL_FLOW_INDEXES_XML+DN_XML);
                    }
                    else {
                        ep2_last_number = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NUMBER_XML);
                        ep2_last_name = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+NAME_XML);
                        ep2_last_dn = *(ttemp+(CALL_FLOW_INDEXES_XML*(conn_index-1))+DN_XML);
                    }
                    cnt = conn_index+1;                               /* to/from-setup-alert-transfered(?)-conn */
                    ptr_xml->state = ptr_xml->co;
                    is_call_state = 1;
                    conn_disc_rel = 1;
                } else {
                    ep2_last_number = *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NUMBER_XML);
                    ep2_last_name = *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+NAME_XML);
                    ep2_last_dn = *(ttemp+(CALL_FLOW_INDEXES_XML*(alert_index-1))+DN_XML);
                    cnt = alert_index+1;                              /* to/from-setup-alert-transfered(?) */
                }
                *tmp_events++ = ep2_last_number;       /* e164 */
                *tmp_events++ = ep2_last_name;         /* h323 */
                *tmp_events++ = ep2_last_dn;           /* dn   */
            }
        } 
        else if((call_flow_msgs[2] == CONN_TO_MSG) || (call_flow_msgs[2] == CONN_FROM_MSG)) {
            // if call setup message contains called number
            if(*(ttemp+NUMBER_XML)) {
                ep2_last_number = *(ttemp+NUMBER_XML);
                ep2_last_name = *(ttemp+NAME_XML);
                ep2_last_dn = *(ttemp+DN_XML);
            }
            else {
                ep2_last_number = *(ttemp+CALL_FLOW_INDEXES_XML+NUMBER_XML);
                ep2_last_name = *(ttemp+CALL_FLOW_INDEXES_XML+NAME_XML);
                ep2_last_dn = *(ttemp+CALL_FLOW_INDEXES_XML+DN_XML);
            }
            *tmp_events++ = ep2_last_number; /* e164 */
            *tmp_events++ = ep2_last_name; /* h323 */
            *tmp_events++ = ep2_last_dn; /* dn */
            cnt = 2+1; /* to/from-setup-conn */
            ptr_xml->state = ptr_xml->co;
            is_call_state = 1;
            conn_disc_rel = 1;
        }
        else {
            if((call_flow_msgs[2] == REL_TO_MSG) || (call_flow_msgs[2] == REL_FROM_MSG)) {
                // SKIP setup info, better to take rel info's if rel contains something
                if(*(ttemp+CALL_FLOW_INDEXES_XML+NUMBER_XML) || *(ttemp+CALL_FLOW_INDEXES_XML+NAME_XML) || *(ttemp+CALL_FLOW_INDEXES_XML+DN_XML)) {
                    conn_disc_rel = 2;
                    // setup
                    ep2_last_number = *ttemp++;
                    ep2_last_name = *ttemp++;
                    ep2_last_dn = *ttemp++;
                }
            }
            else if (secArray >= 4 && ((call_flow_msgs[2] == DISC_TO_MSG) || (call_flow_msgs[2] == DISC_FROM_MSG)) && \
                     ((call_flow_msgs[3] == REL_TO_MSG) || (call_flow_msgs[3] == REL_FROM_MSG))) {
                // SKIP setup/disc info, better to take rel info's if rel contains something
                if(*(ttemp+CALL_FLOW_INDEXES_XML*2+NUMBER_XML) || *(ttemp+CALL_FLOW_INDEXES_XML*2+NAME_XML) || *(ttemp+CALL_FLOW_INDEXES_XML*2+DN_XML)) {
                    conn_disc_rel = 3;
                    // setup
                    ep2_last_number = *ttemp++;
                    ep2_last_name = *ttemp++;
                    ep2_last_dn = *ttemp++;
                    // disc
                    ttemp++;
                    ttemp++;
                    ttemp++;
                }
            }
            // ttemp points to rel event
            if(conn_disc_rel >= 2 && ep2_last_dn && ep2_last_number && (*(ttemp+NUMBER_XML)) && !(*(ttemp+DN_XML)) && !strcmp(ep2_last_number, *(ttemp+NUMBER_XML))) {
                ep2_last_number = *ttemp++;
                ep2_last_name = *ttemp++;
                ttemp++;            
            }
            else {
                ep2_last_number = *ttemp++;
                ep2_last_name = *ttemp++;
                ep2_last_dn = *ttemp++;
            }     
            *tmp_events++ = ep2_last_number;       /* e164 */
            *tmp_events++ = ep2_last_name;         /* h323 */
            *tmp_events++ = ep2_last_dn;           /* dn   */
            cnt = 2;                               /* cf/ct/to/from-setup-? */
        }
        /* remote: outgoing/incomming */
        if(ep2_last_number) {
            remote_e164 = (char *)malloc((strlen(ep2_last_number)+1)*sizeof(char)); 
            strcpy(remote_e164, ep2_last_number);
        }
        if(ep2_last_name) {
            remote_h323 = (char *)malloc((strlen(ep2_last_name)+1)*sizeof(char)); 
            strcpy(remote_h323, ep2_last_name);
        }
        if(ep2_last_dn) {
            remote_dn = (char *)malloc((strlen(ep2_last_dn)+1)*sizeof(char)); 
            strcpy(remote_dn, ep2_last_dn);
        }
        last_number = ep2_last_number;
        last_name = ep2_last_name;
        last_dn = ep2_last_dn;
        if(!f_pickup) {
            if(conn_disc_rel >= 2) {
                *tmp_events = ptr_xml->er;
                cnt = secArray;
            } else if(conn_disc_rel == 1) {
                *tmp_events = ptr_xml->co;
            } else {
                call_state = tmp_events; 
            }
            tmp_events += 2;                          /* state/type */
            *tmp_events++ = ptr_xml->true;            /* entry */
            ind = start_ind = 1;
        }
    }

    ttemp = *subevents;
    /* state of entry event */
    for(ind_t=cnt; ind_t<secArray && !is_call_state; ind_t++) {
        switch(call_flow_msgs[ind_t]) {
            case CONN_TO_MSG:
            case CONNECTED_MSG:
            case CONN_FROM_MSG:
            case TRANSFER_TO_MSG:
            case TRANSFER_FROM_MSG:
            case TRANSFER_REMOTE:
                *call_state = ptr_xml->co;
                ptr_xml->state = ptr_xml->co;
                is_call_state = 1;
                break;
            case TRANSFERRED_MSG:
                if( (call_flow_msgs[ind_t+1] == CONN_TO_MSG) ||\
                    (call_flow_msgs[ind_t+1] == CONN_FROM_MSG) ||\
                    (call_flow_msgs[ind_t+1] == CONNECTED_MSG) ) {
                    *call_state = ptr_xml->co;
                    ptr_xml->state = ptr_xml->co;
                } else {
                    *call_state = ptr_xml->al;
                    if(ptr_xml->state == ptr_xml->er) ptr_xml->state = ptr_xml->al;
                }
                is_call_state = 1;
                break;
            case CF_TO_MSG:
            case CF_FROM_MSG:
            case DISC_FROM_MSG:
            case DISC_TO_MSG:
            case REL_FROM_MSG:
            case REL_TO_MSG:
                *call_state = ptr_xml->al;
                if(ptr_xml->state == ptr_xml->er) ptr_xml->state = ptr_xml->al;
                is_call_state = 1;
                break;
        }
    }
    /* needed for remote and incomming calls, search for a transfer_to at the beginning */
    if(ptr_xml->tmpDir == ptr_xml->ep2) {
        for(ind_t=cnt; ind_t<secArray; ind_t++) {
            if(call_flow_msgs[ind_t] == TRANSFER_TO_MSG || call_flow_msgs[ind_t] == TRANSFER_REMOTE) {
                is_transfer = 1;
                break;
            }
        }
    }

    /*  incoming calls: best found state in call flow state */
    if(ptr_xml->tmpDir == ptr_xml->ep1 && ptr_xml->state != ptr_xml->co) {
        for(ind_t=cnt; ind_t<secArray; ind_t++) {
            switch(call_flow_msgs[ind_t]) {
                case CONN_TO_MSG:
                case CONNECTED_MSG:
                case CONN_FROM_MSG:
                case TRANSFER_TO_MSG:
                case TRANSFER_FROM_MSG:
                case TRANSFER_REMOTE:
                    ptr_xml->state = ptr_xml->co;
                    break;
            }
        }
    }

    ptr_ev_state = NULL;
    p_div = NULL;
    ttemp = *subevents+CALL_FLOW_INDEXES_XML*cnt;
    sub_events = *subevents;
    for(; cnt<secArray; cnt++) {
        if(trace_level & TRACE_CALL_FLOW) {
            do_log(LOG_REPORTING, "", "reporting: msg: %s", msg_lookup_table[call_flow_msgs[cnt]]);
            do_log(LOG_REPORTING, "", "last number: %s %s %s", last_number, last_name, last_dn);
            do_log(LOG_REPORTING, "", "ep1 last: %s %s %s", ep1_last_number, ep1_last_name, ep1_last_dn);
            do_log(LOG_REPORTING, "", "ep2 last: %s %s %s", ep2_last_number, ep2_last_name, ep2_last_dn);
        }
        // Check Pickup
        if(((call_flow_msgs[cnt] == ALERT_TO_MSG) ||
            (call_flow_msgs[cnt] == ALERT_FROM_MSG) ||
            (call_flow_msgs[cnt] == TRANSFER_TO_MSG) ||
            (call_flow_msgs[cnt] == TRANSFER_FROM_MSG) ||
            (call_flow_msgs[cnt] == CF_TO_MSG) ||
            (call_flow_msgs[cnt] == CF_FROM_MSG)) &&
            ((call_flow_msgs[cnt+1] == CONN_FROM_MSG) || (call_flow_msgs[cnt+1] == CONN_TO_MSG) || (call_flow_msgs[cnt+1] == CONNECTED_MSG)) &&
            ((*(ttemp+NAME_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML) && strcmp(*(ttemp+NAME_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML))) ||
             (*(ttemp+DN_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+DN_XML) && strcmp(*(ttemp+DN_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+DN_XML))) ||
             (*(ttemp+NUMBER_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML) && (strlen(*(ttemp+NUMBER_XML)) == strlen(*(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML))) && strcmp(*(ttemp+NUMBER_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML))))) {
            int side = 0;
            tmp_events++;                               /* caller */
            if(p_div && ((call_flow_msgs[cnt] == ALERT_TO_MSG) || (call_flow_msgs[cnt] == ALERT_FROM_MSG))) {
                // rewrite with alert data
                *(p_div+NUMBER_XML) = *(ttemp+NUMBER_XML);
                *(p_div+NAME_XML) = *(ttemp+NAME_XML);
                *(p_div+DN_XML) = *(ttemp+DN_XML);
                ttemp += CALL_FLOW_INDEXES_XML;
                cnt++;                                          // points now to connect event
                if(!ep1_right) {
                    tmp_events += 3;                        /* ep1 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);    /* ep2 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                    ep2_last_number = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);
                    ep2_last_name = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    ep2_last_dn = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                }
                else {
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);    /* ep1  */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                    ep1_last_number = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);
                    ep1_last_name = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    ep1_last_dn = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                    tmp_events += 3;                        /* ep2 */
                }
            }
            else {
                if((call_flow_msgs[cnt] == ALERT_TO_MSG) || (call_flow_msgs[cnt] == TRANSFER_TO_MSG) || (call_flow_msgs[cnt] == CF_TO_MSG)) {
                    if(!ep1_right) {
                        tmp_events += 3;                        /* ep1 */
                        *tmp_events++ = *(ttemp+NUMBER_XML);    /* ep2 */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        side = 1;
                    }
                    else {
                        *tmp_events++ = *(ttemp+NUMBER_XML);    /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        tmp_events += 3;                        /* ep2 */
                    }
                } 
                else {
                    if(!ep1_right) {
                        *tmp_events++ = *(ttemp+NUMBER_XML);    /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        tmp_events += 3;                        /* ep2 */
                        ep1_right = 1;
                    }
                    else {
                        tmp_events += 3;                        /* ep1 */
                        *tmp_events++ = *(ttemp+NUMBER_XML);    /* ep2 */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        side = 1;
                        ep1_right = 0;
                    }
                }
                ttemp += CALL_FLOW_INDEXES_XML;
                *tmp_events++ = ptr_xml->al;
                if((call_flow_msgs[cnt] == CF_TO_MSG) || (call_flow_msgs[cnt] == CF_FROM_MSG)) {
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = ptr_xml->cf;                       /* xml-type */
                    }
                    *tmp_events++ = ptr_xml->cf;                           /* type */
                    tmp_events++;                                          /* entry */
                }
                else if((call_flow_msgs[cnt] == TRANSFER_TO_MSG) || (call_flow_msgs[cnt] == TRANSFER_FROM_MSG)) {
                    if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                        *tmp_events = ptr_xml->cct;             /* type   */
                    else
                        *tmp_events = ptr_xml->ct;              /* type   */
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = *tmp_events;            /* xml-type   */
                    }
                    tmp_events += 2;                            /* type/entry */
                }
                else
                    tmp_events += 2;                            /* type/entry */
                ind++;
                cnt++;                                          // points now to connect event
                tmp_events++;                                   /* caller */
                if(!side) {
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);    /* ep1  */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                    ep1_last_number = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);
                    ep1_last_name = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    ep1_last_dn = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                    tmp_events += 3;                        /* ep2 */
                }
                else {
                    tmp_events += 3;                        /* ep1 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);    /* ep2 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                    ep2_last_number = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);
                    ep2_last_name = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
                    ep2_last_dn = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
                }
            }
            ttemp += CALL_FLOW_INDEXES_XML;
            *tmp_events++ = ptr_xml->co;                /* type */
            last_number = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NUMBER_XML);
            last_name = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+NAME_XML);
            last_dn = *(sub_events+CALL_FLOW_INDEXES_XML*cnt+DN_XML);
            *tmp_events++ = ptr_xml->pu;                /* state */
            tmp_events++;                               /* entry */
            ind++;
            ptr_xml->state = ptr_xml->co;
            ptr_ev_state = NULL;
        }
        else {
            switch(call_flow_msgs[cnt]) {
                case CF_TO_MSG:
                    tmp_events++;                                      /* caller */   
                    if(!ep1_right) {
                        tmp_events += 3;                               /* ep1 */
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);           /* ep2  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        ptr_ev_state = tmp_events;                     /* state */
                        *tmp_events++ = ptr_xml->al;
                        ep2_last_number = *(ttemp+NUMBER_XML);
                        ep2_last_name = *(ttemp+NAME_XML);
                        ep2_last_dn = *(ttemp+DN_XML);
                    } else {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);           /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        ep1_last_number = *(ttemp+NUMBER_XML);
                        ep1_last_name = *(ttemp+NAME_XML);
                        ep1_last_dn = *(ttemp+DN_XML);
                        tmp_events += 3;                               /* ep2 */ 
                        ptr_ev_state = tmp_events;                     /* state */
                        *tmp_events++ = ptr_xml->al;
                    }
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        if( *(p_div+NUMBER_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML) ) {
                            check_ep += (strcmp(*(p_div+NAME_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML)) != 0); 
                            checked_ep = 1;
                        }
                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML);
                            *(p_div+NAME_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML);
                            *(p_div+DN_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+DN_XML);
                            last_number = *(p_div+NUMBER_XML);
                            last_name = *(p_div+NAME_XML);
                            last_dn = *(p_div+DN_XML);
                        }
                    }
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = ptr_xml->cf;                       /* xml-type   */
                    }
                    *tmp_events++ = ptr_xml->cf;                           /* type */
                    tmp_events++;                                          /* entry */ 
                    ind++;
                    break;
                case CF_FROM_MSG:
                    tmp_events++;                                          /* caller */   
                    if(!ep1_right) {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);               /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        ep1_last_number = *(ttemp+NUMBER_XML);
                        ep1_last_name = *(ttemp+NAME_XML);
                        ep1_last_dn = *(ttemp+DN_XML);
                        tmp_events += 3;                                   /* ep2 */ 
                        ep1_right = 1;
                    } else {
                        tmp_events += 3;                                   /* ep1 */ 
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);               /* ep2  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        ep2_last_number = *(ttemp+NUMBER_XML);
                        ep2_last_name = *(ttemp+NAME_XML);
                        ep2_last_dn = *(ttemp+DN_XML);
                        ep1_right = 0;
                    }
                    ptr_ev_state = tmp_events;                             /* state */
                    *tmp_events++ = ptr_xml->al;
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = ptr_xml->cf;                       /* xml-type */
                    }
                    *tmp_events++ = ptr_xml->cf;                           /* type */
                    tmp_events++;                                          /* entry */
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        if( *(p_div+NUMBER_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML) ) {
                            check_ep += (strcmp(*(p_div+NAME_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML)) != 0);
                            checked_ep = 1;
                        }
                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML);
                            *(p_div+NAME_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML);
                            *(p_div+DN_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+DN_XML);
                            last_number = *(p_div+NUMBER_XML);
                            last_name = *(p_div+NAME_XML);
                            last_dn = *(p_div+DN_XML);
                        }
                    }
                    ind++;
                    break;
                case TRANSFER_REMOTE:
                case TRANSFER_TO_MSG:
                    tmp_events++;                                          /* caller */   
                    if(ep1_right) {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);               /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        ep1_last_number = *(ttemp+NUMBER_XML);
                        ep1_last_name = *(ttemp+NAME_XML);
                        ep1_last_dn = *(ttemp+DN_XML);
                        tmp_events += 3;                                   /* ep2 */ 
                        if(call_flow_msgs[cnt] == TRANSFER_REMOTE)
                            *tmp_events++ = ptr_xml->co;
                        else {
                            ptr_ev_state = tmp_events;                     /* state */
                            *tmp_events++ = ptr_xml->al;
                        }
                    } else {
                        tmp_events += 3;                                   /* ep1 */ 
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);               /* ep2  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        if(call_flow_msgs[cnt] == TRANSFER_REMOTE)
                            *tmp_events++ = ptr_xml->co;
                        else {
                            ptr_ev_state = tmp_events;                     /* state */
                            *tmp_events++ = ptr_xml->al;
                        }
                        ep2_last_number = *(ttemp+NUMBER_XML);
                        ep2_last_name = *(ttemp+NAME_XML);
                        ep2_last_dn = *(ttemp+DN_XML);
                        if(is_transfer) {
                            /* remote: outgoing/incomming */
                            if(remote_e164 != NULL) {
                                free(remote_e164);
                                remote_e164 = NULL;
                            }
                            if(ep2_last_number) {
                                remote_e164 = (char *)malloc((strlen(ep2_last_number)+1)*sizeof(char)); 
                                strcpy(remote_e164, ep2_last_number);
                            }
                            if(remote_h323 != NULL) {
                                free(remote_h323);
                                remote_h323 = NULL;
                            }
                            if(ep2_last_name) {
                                remote_h323 = (char *)malloc((strlen(ep2_last_name)+1)*sizeof(char)); 
                                strcpy(remote_h323, ep2_last_name);
                            }
                            if(remote_dn != NULL) {
                                free(remote_dn);
                                remote_dn = NULL;
                            }
                            if(ep2_last_dn) {
                                remote_dn = (char *)malloc((strlen(ep2_last_dn)+1)*sizeof(char)); 
                                strcpy(remote_dn, ep2_last_dn);
                            }
                            is_transfer = 0;
                        }
                    }
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        if( *(p_div+NUMBER_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML) ) {
                            check_ep += (strcmp(*(p_div+NAME_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML)) != 0);
                            checked_ep = 1;
                        }
                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML);
                            *(p_div+NAME_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML);
                            *(p_div+DN_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+DN_XML);
                            last_number = *(p_div+NUMBER_XML);
                            last_name = *(p_div+NAME_XML);
                            last_dn = *(p_div+DN_XML);
                        }
                    }
                    if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                        *tmp_events = ptr_xml->cct;             /* type   */
                    else
                        *tmp_events = ptr_xml->ct;              /* type   */
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = *tmp_events;            /* xml-type   */
                    }
                    tmp_events += 2;                            /* type/entry */
                    ind++;
                    break;
                case TRANSFER_FROM_MSG:
                    tmp_events++;                               /* caller */   
                    if(!ep1_right) {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);    /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        ep1_last_number = *(ttemp+NUMBER_XML);
                        ep1_last_name = *(ttemp+NAME_XML);
                        ep1_last_dn = *(ttemp+DN_XML);
                        tmp_events += 3;                        /* ep2 */ 
                        ep1_right = 1;
                    } else {
                        tmp_events += 3;                        /* ep1 */ 
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_XML);    /* ep2  */
                        *tmp_events++ = *(ttemp+NAME_XML);
                        *tmp_events++ = *(ttemp+DN_XML);
                        ep2_last_number = *(ttemp+NUMBER_XML);
                        ep2_last_name = *(ttemp+NAME_XML);
                        ep2_last_dn = *(ttemp+DN_XML);
                        ep1_right = 0;
                    }
                    ptr_ev_state = tmp_events;                  /* state */
                    *tmp_events++ = ptr_xml->al;
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        // For Dn
                        if( *(p_div+NUMBER_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_XML) && *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML) ) {
                            check_ep += (strcmp(*(p_div+NAME_XML), *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML)) != 0);
                            checked_ep = 1;
                        }
                        // end For Dn

                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NUMBER_XML);
                            *(p_div+NAME_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+NAME_XML);
                            *(p_div+DN_XML) =  *(sub_events+CALL_FLOW_INDEXES_XML*(cnt+1)+DN_XML);
                            last_number = *(p_div+NUMBER_XML);
                            last_name = *(p_div+NAME_XML);
                            last_dn = *(p_div+DN_XML);
                        }
                    }
                    if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                        *tmp_events = ptr_xml->cct;             /* type   */
                    else
                        *tmp_events = ptr_xml->ct;              /* type   */
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = *tmp_events;            /* xml-type */
                    }
                    tmp_events += 2;                            /* state/entry */
                    ind++;
                    break;
                case CONNECTED_MSG:
                case CONN_TO_MSG:
                case CONN_FROM_MSG:
                    ptr_xml->state = ptr_xml->co;
                    if(ptr_ev_state) *ptr_ev_state = ptr_xml->co;
                    ptr_ev_state = NULL;
                case ALERT_TO_MSG:
                case ALERT_FROM_MSG:
                case DISC_FROM_MSG:
                case DISC_TO_MSG:
                case REL_FROM_MSG:
                case REL_TO_MSG:
                default:
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    p_div = NULL;
                    break;
            }
        }
        if(call_flow_msgs[cnt] == TRANSFER_REMOTE) break;
    }

    if(ind > 0 && cause_code != NULL) {
        *(tmp_events-3) = cause_code;                            /* bu, er */
        if(cause_code == ptr_xml->bu && ptr_xml->state != ptr_xml->co) 
            ptr_xml->state = cause_code;
        else if(cause_code == ptr_xml->er && ind == 1)           /* ind > 1, there is for sure a better state, "al" probably */
            ptr_xml->state = cause_code;
    }
    *numEvents = ind;
 
    if(remote) {
        remote->remote_e164 = remote_e164;
        remote->remote_h323 = remote_h323;
        remote->remote_dn = remote_dn;
        remote->remote = remote_f;
    }
    else {
        if(remote_e164) free(remote_e164);
        if(remote_h323) free(remote_h323);
        if(remote_dn) free(remote_dn);
        if(remote_f) free(remote_f);
    }

    if(trace_level & TRACE_CALL_FLOW_TOTAL) {
        ttemp = *events;
        for(i=0; i<secArray; i++) {
            for(j=0; j<num_xml_events_print; j++) {
                if(*ttemp != NULL) {
                    do_log(LOG_REPORTING, "", "reporting: %s = %s", xml_events_attrib[j], *ttemp);
                }
                ttemp++;
            }
        }
        do_log(LOG_REPORTING, "", "reporting: free: %d-%d-%p", secArray, *numEvents, *subevents);
    }

    free(msg_buffer);
    free(call_flow_msgs);

    return secArray;
}

static int
pg_array_parse_pdf(char *text, int cause, int c_type, char ***events, char ***subevents, int *numEvents, xml_strings *ptr_xml, remote_t *remote, csv_infos_t *csv, int is_callback, int digits_to_hide, int anonym, char *pbx, char *phys, ldap_servers_t *ldap_servers)
{
    char *remote_e164 = NULL;
    char *remote_h323 = NULL;
    char *remote_dn = NULL;
    char *remote_f = NULL;
    char *object_info = NULL, *object_called = NULL, *diverting = NULL, *transferring = NULL;
    int set_transferring = 0, first_event = 1;
    int i, j;
    char **p_div, **tmp_events, **ttemp, **ptr_ev_state, **sub_events, **sct_event = NULL;
    char *ttemp_msg;
    int ind = 0, start_ind = 0, ind_t, is_scf = 0;
    int cnt = 0, is_call_state = 0, max_string_len = 0, is_transfer = 0;
    char *ep1_last_name = NULL, *ep1_last_number = NULL, *ep1_last_dn = NULL, *ep1_last = NULL;
    char *ep2_last_name = NULL, *ep2_last_number = NULL, *ep2_last_dn = NULL, *ep2_last = NULL;
    char *last_name = NULL, *last_number = NULL, *last_dn = NULL, *last = NULL;
    char *cause_code = NULL;
    char **call_state = NULL;
    char *msg_buffer;
    int *call_flow_msgs;
    int caller_img = DUMMY;
    int ep1_right = 0;
    *numEvents=0;

    switch(cause) {
        case codeUnalloc:            /* 1 */
        case codeNoRouteSpec:        /* 2 */
        case codeNoRouteDest:        /* 3 */
        case codeChUnacep:           /* 6 */
        case codeCallRej:            /* 21 */
        case codeDestOutOrder:       /* 27 */
        case codeInvNumberFormat:    /* 28 */
        case codeNoCircChAv:         /* 34 */
        case codeNetworkOutOrder:    /* 38 */
        case codeTempFailure:        /* 41 */
        case codeReqNoCircChAv:      /* 44 */
        case codeResourcesUnav:      /* 47 */
        case codeOutCallsBarred:     /* 52 */
        case codeServOptUnav:        /* 63 */
        case codeNoBearerCapImp:     /* 65 */
        case codeIncompDest:         /* 88 */
        case codeRecOnTimerExp:      /* 102 */
        case codeProtError:          /* 111 */
        case codeInterworkUnspec:    /* 127 */
            cause_code = ptr_xml->er;
            break;
        case codeNoUserResp:         /* 18 */
        case codeNoRespFromUser:     /* 19 */
            cause_code = ptr_xml->al;
            ptr_xml->state = ptr_xml->al;
            break;
        case codeUserBusy:           /* 17 */
            cause_code = ptr_xml->bu;
            ptr_xml->state = ptr_xml->bu;
            break;
    }

    int len_text = strlen(text);
    int secArray = 0;
    for(i=1;i<len_text-2;i++) {                                                 /* {{,,,},{,,,},...,{,,,}}, skip first { */
        if(((text[i] == 0x7D) && (text[i+1] == 0x2C) && (text[i+2] == 0x7B)) || /* },{*/
           ((text[i+1] == 0x7D) && (text[i+2] == 0x7D))) {                      /* }} */ 
            secArray++;
            if(text[i+2] == 0x7D) 
                break;
        }
    }

    if(secArray > MAX_NUM_EVENTS) secArray = MAX_NUM_EVENTS;

    *subevents = (char **)malloc(secArray*CALL_FLOW_INDEXES_PDF*sizeof(char *));
    if(*subevents == NULL) {
        do_log(LOG_REPORTING, "", "reporting: couldn't get memory for temp!");
        return -1;
    }
    ttemp = *subevents;
    for(i=0;i<(secArray*CALL_FLOW_INDEXES_PDF);i++) {
       *ttemp++ = NULL;
    }

    call_flow_msgs = (int *)malloc(secArray*sizeof(int));
    if(call_flow_msgs == NULL) {
        do_log(LOG_REPORTING, "", "reporting: couldn't get memory for call flow messages!");
        free_allocated_mem(subevents, secArray, CALL_FLOW_INDEXES_PDF, 0, FLAG_ERROR);                         /* msg, dir */
        return -1;
    }

    for(i=0;i<num_msg_lookup_table;i++) {
        max_string_len = MAX(strlen(msg_lookup_table[i]), max_string_len);
    }
    msg_buffer = (char *)malloc((max_string_len << 2)*sizeof(char));
    if(msg_buffer == NULL) {
        do_log(LOG_REPORTING, "", "reporting: couldn't get memory for msg buffer!");
        free(call_flow_msgs);
        free_allocated_mem(subevents, secArray, CALL_FLOW_INDEXES_PDF, 0, FLAG_ERROR);                         /* msg, dir */
        return -1;
    }

    if(trace_level & TRACE_CALL_FLOW) {
        do_log(LOG_REPORTING, "", "reporting: call-flow: %s %p", text, *subevents);
    }

    ttemp = *subevents;
    for(i=0,j=2;i<secArray;i++) {           /* j chars */
        int l, msg_length, e164_length, h323_length, dn_length, hide = 0;
        char *pch, *h323_xml_entities = NULL, *e164 = NULL, *dn_xml_entities = NULL, *formatted = NULL;
        int rewrite_diverting = 0;

        /* calculate length of each parameter */
        pch = &text[j];
        for(msg_length=0; *pch++ != ',' && *pch; msg_length++);
        for(e164_length=0; *pch++ != ',' && *pch; e164_length++);
        h323_length = find_separator(pch, COMMA_CHAR);
        pch = &pch[h323_length+1];
        dn_length = find_separator(pch, RIGHT_CURLY_BRACKET_CHAR);

        /* allocate memory */
        if(e164_length) e164 = (char *)malloc(((e164_length+1)<<2)*sizeof(char)); 
        if(h323_length) h323_xml_entities = (char *)malloc(((h323_length+1)<<3)*sizeof(char));      /* 6 == '&quot;' */
        if(dn_length) dn_xml_entities = (char *)malloc(((dn_length+1)<<3)*sizeof(char));            /* 6 == '&quot;' */
        if(e164_length || h323_length ||dn_length) {
            formatted = (char *)malloc(((e164_length+h323_length+dn_length)<<3)*sizeof(char));
            formatted[0] = '\0';
        }
        if(first_event) {
            if((object_info = (char *)malloc(((e164_length+h323_length+dn_length)<<3)*sizeof(char))) != NULL) {
                object_info[0] = '\0';
            }
            else first_event = 0;
        }
 
        pch = &text[j];

        /* msg */
        ttemp_msg = msg_buffer;
        for (l=0; l<msg_length; l++)
            *ttemp_msg++ = *pch++;
        *ttemp_msg = '\0';
        if(trace_level & TRACE_CALL_FLOW) {
            do_log(LOG_REPORTING, "", "reporting: msg[%d]: %s", msg_length, msg_buffer);
        }
        call_flow_msgs[i] = lookup_msg(msg_buffer);
        if(call_flow_msgs[i] == SCF_MSG) {
            if(is_scf == 0) {
                if((diverting = (char *)malloc(((e164_length+h323_length+dn_length)<<3)*sizeof(char))) != NULL) {
                    diverting[0] = '\0';
                    rewrite_diverting = 1;
                }
            }
            else if(is_scf == 1) {
                object_called = diverting;
                if((diverting = (char *)malloc(((e164_length+h323_length+dn_length)<<3)*sizeof(char))) != NULL) {
                    diverting[0] = '\0';
                    rewrite_diverting = 1;
                }
            }
            else {
                diverting[0] = '\0';
                rewrite_diverting = 2;
            }
            is_scf++;
        }
        else if((call_flow_msgs[i] == SCT_MSG) && (sct_event == NULL)) {
            sct_event = ttemp;
            if(!transferring) {
                if((transferring = (char *)malloc(((e164_length+h323_length+dn_length)<<3)*sizeof(char))) != NULL) {
                    transferring[0] = '\0';
                    set_transferring = 1;
                }
            }
        }

        /* e164 */
        pch++;
        *ttemp = e164;
        if(e164_length) {
            if(digits_to_hide && ldap_servers->ldap != NULL) {
                ldap_t **servers = ldap_servers->ldap;
 
                while(*servers != NULL) {
                    ldap_t *tmp = *servers;
                    if(strcmp(phys,"")) {
                        if(!strcasecmp(tmp->pbx, phys) && (strncmp(pch, tmp->el, strlen(tmp->el)) == 0) ) {
                            hide = 1;
                            break;
                        }
                    } else {
                        if(!strcasecmp(tmp->pbx, pbx) && (strncmp(pch, tmp->el, strlen(tmp->el)) == 0) ) {
                            hide = 1;
                            break;
                        }
                    }
                    servers++;
                    if(trace_level & TRACE_CALL_FLOW) {
                        do_log(LOG_REPORTING, "", "check phys[%d] %s(%d) %s(%d) %s(%d) el=%d - %s len=%d cmp=%d-%d-%d", hide, tmp->pbx, strlen(tmp->pbx), phys, strlen(phys), pbx, strlen(pbx), pch[0], tmp->el, strlen(tmp->el), strcasecmp(tmp->pbx, phys), strcasecmp(tmp->pbx, pbx), strncmp(pch, tmp->el, strlen(tmp->el)));
                    }
                }

                if(hide) {
                    if(digits_to_hide > e164_length) {
                        memset(e164, 0x2a, e164_length);
                        e164[e164_length] = '\0';
                        pch += e164_length;
                    } else {
                        for(l = 0; l < (e164_length - digits_to_hide); l++) {
                            *e164++ = *pch++;
                        }
                        for(; l < e164_length; l++) {
                           *e164++ = 0x2a;
                           pch++;
                        }
                        *e164 = '\0';
                    }
                } else {
                    for (l=0; l<e164_length; l++)
                        *e164++ = *pch++;
                    *e164 = '\0';
                }
            } else {
                for (l=0; l<e164_length; l++)
                    *e164++ = *pch++;
                *e164 = '\0';
            }
            if(trace_level & TRACE_CALL_FLOW) {
                do_log(LOG_REPORTING, "", "reporting: e164[%d]: %s", e164_length, *ttemp);
            }
        }
        if(anonym && !hide) {
            if(e164_length) {
                strcpy(*ttemp, "*"); // points to e164
            }
            else {
                *ttemp = malloc(2*sizeof(char));
                strcpy(*ttemp, "*");
            }
        }
        ttemp++;

        /* h323 */
        pch++;
        if(hide || anonym) {
            free(h323_xml_entities);
            h323_xml_entities = NULL;
            if(e164_length) {
               strcpy(formatted, *(ttemp-1));
            }    
        } else {
            if(h323_length) {
                //xmlentities(pch, h323_xml_entities, h323_length);
                strcpy_unescape(h323_xml_entities, pch, h323_length);
                if(trace_level & TRACE_CALL_FLOW) {
                    do_log(LOG_REPORTING, "", "reporting: h323[%d]: %s", h323_length, h323_xml_entities);
                }
                strcpy(formatted, h323_xml_entities);
                if(e164_length) {
                    strcat(formatted, " (");
                    strcat(formatted, *(ttemp-1));
                    strcat(formatted, ")");
                }
            } else if(e164_length) {
               strcpy(formatted, *(ttemp-1));
            }    
        }
        pch += h323_length + 1;  /* , */
        *ttemp++ = h323_xml_entities;

        /* dn */
        if(hide || anonym) {
            free(dn_xml_entities);
            dn_xml_entities = NULL;
        } else {
            if(dn_length) {
                //xmlentities(pch, dn_xml_entities, dn_length);
                strcpy_unescape(dn_xml_entities, pch, dn_length);
                if(trace_level & TRACE_CALL_FLOW) {
                    do_log(LOG_REPORTING, "", "reporting: dn[%d]: %s", dn_length, dn_xml_entities);
                }
                strcat(formatted, " ");
                strcat(formatted, dn_xml_entities);
            }
        }
        *ttemp++ = dn_xml_entities; 
        *ttemp++ = formatted; 
        j += msg_length + 1 + e164_length + 1 + h323_length + 1 + dn_length + 3;
        if(set_transferring) {
            strcpy(transferring, formatted);
            set_transferring = 0;
        }
        if(first_event) {
            strcpy(object_info, formatted);
            first_event = 0;
        }
        if(rewrite_diverting) {
            strcpy(diverting, formatted);
        }

        if(trace_level & TRACE_CALL_FLOW_TOTAL) {
            if(formatted != NULL) {
                do_log(LOG_REPORTING, "", "reporting: formatted[%d]: %s", (e164_length+h323_length+dn_length)<<3, formatted);
            }
        }
    }

    if(trace_level & TRACE_CALL_FLOW_TOTAL) {
        ttemp = *subevents;
        for(ind_t=0; ind_t<secArray; ind_t++) {
            do_log(LOG_REPORTING, "", "reporting: %s-%s-%s-%s-%s", 
                   msg_lookup_table[call_flow_msgs[ind_t]], 
                   *(ttemp+ind_t*CALL_FLOW_INDEXES_PDF+NUMBER_PDF), 
                   *(ttemp+ind_t*CALL_FLOW_INDEXES_PDF+NAME_PDF), 
                   *(ttemp+ind_t*CALL_FLOW_INDEXES_PDF+DN_PDF), 
                   *(ttemp+ind_t*CALL_FLOW_INDEXES_PDF+FORMATTED_PDF));
        }
    }

    *events = (char **)malloc((secArray*PDF_EVENTS_ATTRIB)*sizeof(char *));
    if(*events == NULL) {
        free(call_flow_msgs);
        free(msg_buffer);
        free_allocated_mem(subevents, secArray, CALL_FLOW_INDEXES_PDF, 0, FLAG_ERROR);                         /* msg, dir */
        return -1;
    }
    tmp_events = *events;
    for(i=0;i<(secArray*PDF_EVENTS_ATTRIB);i++) {
        *tmp_events++ = NULL;
    }

    ttemp = *subevents;
    tmp_events = *events;

    if((call_flow_msgs[0] == CF_MSG) || (call_flow_msgs[0] == CT_MSG)) {
        if(call_flow_msgs[1] == SETUP_TO_MSG) {
            ptr_xml->tmpDir = ptr_xml->ep2;
            caller_img = DIR_IN;
        } else if(call_flow_msgs[1] == SETUP_FROM_MSG) {
            ptr_xml->tmpDir = ptr_xml->ep1;
            caller_img = DIR_OUT;
        }
    } else if(call_flow_msgs[0] == TO_MSG) {
        ptr_xml->tmpDir = ptr_xml->ep2;
        caller_img = DIR_IN;
    } else if(call_flow_msgs[0] == FROM_MSG) {
        ptr_xml->tmpDir = ptr_xml->ep1;
        caller_img = DIR_OUT;
    }

    if(is_scf || (sct_event != NULL)) {
        /* to-h323-e164-dn */
        ep1_last_number = *ttemp++;        /* e164 */
        ep1_last_name = *ttemp++;          /* h323 */
        ep1_last_dn = *ttemp++;            /* dn */
        ep1_last = *ttemp++;               /* formatted */
        /* setup-h323-e164-dn */
        ep2_last_number = *ttemp++;        /* e164 */
        ep2_last_name = *ttemp++;          /* h323 */
        ep2_last_dn = *ttemp++;            /* dn */
        ep2_last = *ttemp++;               /* formatted */
        if(ep2_last_number) {
            remote_e164 = (char *)malloc((strlen(ep2_last_number)+1)*sizeof(char)); 
            strcpy(remote_e164, ep2_last_number);
        }
        if(ep2_last_name) {
            remote_h323 = (char *)malloc((strlen(ep2_last_name)+1)*sizeof(char)); 
            strcpy(remote_h323, ep2_last_name);
        }
        if(ep2_last_dn) {
            remote_dn = (char *)malloc((strlen(ep2_last_dn)+1)*sizeof(char)); 
            strcpy(remote_dn, ep2_last_dn);
        }
        if(ep2_last) {
            remote_f = (char *)malloc((strlen(ep2_last)+1)*sizeof(char)); 
            strcpy(remote_f, ep2_last);
        }
        /* scf/sct-h323-e164 */
        if(sct_event != NULL) {
            char **sct_event_tmp = sct_event;
            int first_sct = 1;

            /* ct event happens before cf event if any */ 
            if(sct_event == ttemp) {
               ttemp += CALL_FLOW_INDEXES_PDF;
               cnt = 3;                                             /* to/from-setup-sct-? */
            } else {
               cnt = 2;                                             /* to/from-setup-scf-...-sct */
            }
            tmp_events += 2;                                        /* caller is unknown with a 'ct' */
            *tmp_events++ = *sct_event++;                           /* e164 */
            *tmp_events++ = *sct_event++;                           /* h323 */
            *tmp_events++ = *sct_event++;                           /* dn */
            *tmp_events++ = *sct_event++;                           /* formatted */
            tmp_events++;                                           /* ep1_img */
            *tmp_events++ = ep2_last_number;
            *tmp_events++ = ep2_last_name;
            *tmp_events++ = ep2_last_dn;
            *tmp_events++ = ep2_last;
            tmp_events++;                                           /* ep2_img */
            *tmp_events++ = ptr_xml->co;                            /* state */
            if(is_callback)
                *tmp_events++ = (char *)image_lookup_table[CONN_CALLBACK];
            else
                *tmp_events++ = (char *)image_lookup_table[CONN];
            tmp_events += 2;                                        /* type/entry */
            ind = 1;
            while((call_flow_msgs[cnt] == SCF_MSG) && (ttemp != sct_event_tmp)) {
                /* New Event */
                tmp_events += 2;                                    /* caller */
                *tmp_events++ = *ttemp++;                           /* e164 */
                *tmp_events++ = *ttemp++;                           /* h323 */
                *tmp_events++ = *ttemp++;                           /* dn */
                *tmp_events++ = *ttemp++;                           /* formatted */
                if(first_sct) {
                    *tmp_events++ = (char *)image_lookup_table[CT];     /* ep1_img */
                    tmp_events += 5;                                    /* ep2 */
                    *tmp_events++ = ptr_xml->al;                        /* state */
                    *tmp_events++ = (char *)image_lookup_table[NO_RES]; /* state_img */
                    *tmp_events++ = ptr_xml->ct;                        /* type */
                    first_sct = 0;
                } else {
                    *tmp_events++ = (char *)image_lookup_table[CF];     /* ep1_img */
                    tmp_events += 5;                                    /* ep2 */
                    *tmp_events++ = ptr_xml->al;                        /* state */
                    *tmp_events++ = (char *)image_lookup_table[NO_RES]; /* state_img */
                    *tmp_events++ = ptr_xml->cf;                        /* type */
                }
                tmp_events++;                                       /* entry */
                ind++;
                cnt++;                                              /* scf/sct */
            }
            /* ct event was reached, skip it */
            if(sct_event_tmp == ttemp) {
                ttemp += CALL_FLOW_INDEXES_PDF;
            }
            /* New Event */
            tmp_events += 2;                                        /* caller */
            *tmp_events++ = ep1_last_number;                        /* e164 */
            *tmp_events++ = ep1_last_name;                          /* h323 */
            *tmp_events++ = ep1_last_dn;                            /* dn */
            *tmp_events++ = ep1_last;                               /* formatted */
            if(is_scf)
                *tmp_events++ = (char *)image_lookup_table[CF];     /* ep1_img */
            else
                *tmp_events++ = (char *)image_lookup_table[CT];     /* ep1_img */
            tmp_events += 5;                                        /* ep2 */
            call_state = tmp_events;
            tmp_events += 2;                                        /* state */
            if(is_scf)
                *tmp_events++ = ptr_xml->cf;                        /* type   */
            else
                *tmp_events++ = ptr_xml->ct;                        /* type   */
            ptr_xml->type = ptr_xml->ct;                            /* xml-type */
            *tmp_events++ = ptr_xml->true;                          /* entry  */
            ind++;
            start_ind = ind;
        } else {
            *tmp_events++ = ptr_xml->tmpDir;                        /* caller */
            *tmp_events++ = (char *)image_lookup_table[caller_img]; /* caller_img */
            *tmp_events++ = *ttemp++;                               /* e164 */
            *tmp_events++ = *ttemp++;                               /* h323 */
            *tmp_events++ = *ttemp++;                               /* dn */
            *tmp_events++ = *ttemp++;                               /* formatted */
            tmp_events++;
            *tmp_events++ = ep2_last_number;
            *tmp_events++ = ep2_last_name;
            *tmp_events++ = ep2_last_dn;
            *tmp_events++ = ep2_last;
            tmp_events++;
            *tmp_events++ = ptr_xml->al;                            /* state */
            if(is_callback)
                *tmp_events++ = (char *)image_lookup_table[NO_RES_CALLBACK];
            else
                *tmp_events++ = (char *)image_lookup_table[NO_RES];
            tmp_events += 2;                                        /* type/entry */
            ind = 1;
            cnt = 3;                                                /* to/from-setup-scf/sct */
            while(call_flow_msgs[cnt] == SCF_MSG) {
                /* New Event */
                tmp_events += 2;                                    /* caller */
                *tmp_events++ = *ttemp++;                           /* e164 */
                *tmp_events++ = *ttemp++;                           /* h323 */
                *tmp_events++ = *ttemp++;                           /* dn */
                *tmp_events++ = *ttemp++;                           /* formatted */
                *tmp_events++ = (char *)image_lookup_table[CF];     /* state_img */
                tmp_events += 5;                                    /* ep2 */
                *tmp_events++ = ptr_xml->al;                        /* state */
                *tmp_events++ = (char *)image_lookup_table[NO_RES]; /* state_img */
                *tmp_events++ = ptr_xml->cf;                        /* type */
                tmp_events++;                                       /* entry */
                ind++;
                cnt++;                                              /* scf/sct */
            }
            /* New Event */
            tmp_events += 2;                                        /* caller */
            *tmp_events++ = ep1_last_number;                        /* e164 */
            *tmp_events++ = ep1_last_name;                          /* h323 */
            *tmp_events++ = ep1_last_dn;                            /* dn */
            *tmp_events++ = ep1_last;                               /* formatted */
            *tmp_events++ = (char *)image_lookup_table[CF];         /* ep1_img */
            tmp_events += 5;                                        /* ep2 */
            call_state = tmp_events;
            tmp_events += 2;                                        /* state */
            *tmp_events++ = ptr_xml->cf;                            /* type   */
            ptr_xml->type = ptr_xml->cf;                            /* xml-type */
            *tmp_events++ = ptr_xml->true;                          /* entry  */
            ind++;
            start_ind = ind;
        }
        last_number = ep1_last_number;
        last_name = ep1_last_name;
        last_dn = ep1_last_dn;
        last = ep1_last;
    } else {
        int conn_disc_rel = 0;
        int f_pickup = 0;

        *tmp_events++ = ptr_xml->tmpDir;           /* caller */
        *tmp_events++ = (char *)image_lookup_table[caller_img]; /* img caller */
        ep1_last_number = *ttemp++;
        ep1_last_name = *ttemp++;
        ep1_last_dn = *ttemp++;
        ep1_last = *ttemp++;
        *tmp_events++ = ep1_last_number;           /* e164 */
        *tmp_events++ = ep1_last_name;             /* h323 */
        *tmp_events++ = ep1_last_dn;               /* dn   */
        *tmp_events++ = ep1_last;                  /* formatted */
        tmp_events++;                              /* image_ep1 */
        /* actual msg is setup, if next alert better, more information available */
        if((call_flow_msgs[2] == ALERT_TO_MSG) || (call_flow_msgs[2] == ALERT_FROM_MSG) || 
           (call_flow_msgs[2] == TRANSFERRED_MSG) || (call_flow_msgs[2] == FORWARDED_MSG)) {
            int conn_index, alert_index;

            if((call_flow_msgs[3] == ALERT_TO_MSG) || (call_flow_msgs[3] == ALERT_FROM_MSG) || 
               (call_flow_msgs[3] == TRANSFERRED_MSG) || (call_flow_msgs[3] == FORWARDED_MSG)) {
                conn_index = 4;
                alert_index = 3;
            } 
            else {
                conn_index = 3;
                alert_index = 2;
            }
            // Check Pickup for internal calls
            if( (c_type == 0) && ((call_flow_msgs[conn_index] == CONN_TO_MSG) || (call_flow_msgs[conn_index] == CONN_FROM_MSG)) &&
                ((*(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NAME_PDF) && *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NAME_PDF) &&
                  strcmp(*(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NAME_PDF), *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NAME_PDF))) ||
                (*(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+DN_PDF) && *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+DN_PDF) &&
                  strcmp(*(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+DN_PDF), *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+DN_PDF))) ||
                (*(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NUMBER_PDF) && *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NUMBER_PDF) &&
                  (strlen(*(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NUMBER_PDF)) == strlen(*(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NUMBER_PDF))) &&
                  strcmp(*(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NUMBER_PDF), *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NUMBER_PDF)))) ) {
                f_pickup = 1;
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NUMBER_PDF);       /* e164 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NAME_PDF);         /* h323 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+DN_PDF);           /* dn   */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+FORMATTED_PDF);    /* formatted */
                tmp_events++;
                *tmp_events++= ptr_xml->al;               /* state */
                *tmp_events++ = (char *)image_lookup_table[NO_RES];
                tmp_events++;                             /* type */
                *tmp_events++ = ptr_xml->true;            /* entry */

                tmp_events += 2;                          /* caller */
                tmp_events += 5;                          /* ep1 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NUMBER_PDF);       /* e164 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NAME_PDF);         /* h323 */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+DN_PDF);           /* dn   */
                *tmp_events++ = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+FORMATTED_PDF);    /* formatted */
                *tmp_events++ = (char *)image_lookup_table[PICKUP_REV];
                ep2_last_number = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NUMBER_PDF);
                ep2_last_name = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NAME_PDF);
                ep2_last_dn = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+DN_PDF);
                ep2_last = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+FORMATTED_PDF);
                *tmp_events++ = ptr_xml->co;              /* state */
                *tmp_events++ = (char *)image_lookup_table[CONN];
                *tmp_events++ = ptr_xml->pu;              /* type */
                *tmp_events++ = ptr_xml->true;            /* entry */
                cnt = conn_index+1;                               /* to/from-setup-alert-transfered(?)-conn */
                ptr_xml->state = ptr_xml->co;
                is_call_state = 1;
                ind = start_ind = 2;
            }
            else {
                if((call_flow_msgs[conn_index] == CONN_TO_MSG) || (call_flow_msgs[conn_index] == CONN_FROM_MSG)) {
                    // if external call alert message contains called number
                    if(c_type && *(ttemp+CALL_FLOW_INDEXES_PDF+NUMBER_PDF)) {
                        ep2_last_number = *(ttemp+CALL_FLOW_INDEXES_PDF+NUMBER_PDF);
                        ep2_last_name = *(ttemp+CALL_FLOW_INDEXES_PDF+NAME_PDF);
                        ep2_last_dn = *(ttemp+CALL_FLOW_INDEXES_PDF+DN_PDF);
                        ep2_last = *(ttemp+CALL_FLOW_INDEXES_PDF+FORMATTED_PDF);
                    }
                    else {
                        ep2_last_number = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NUMBER_PDF);
                        ep2_last_name = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+NAME_PDF);
                        ep2_last_dn = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+DN_PDF);
                        ep2_last = *(ttemp+(CALL_FLOW_INDEXES_PDF*(conn_index-1))+FORMATTED_PDF);
                    }
                    cnt = conn_index+1;                               /* to/from-setup-alert-transfered(?)-conn */
                    ptr_xml->state = ptr_xml->co;
                    is_call_state = 1;
                    conn_disc_rel = 1;
                } else {
                    ep2_last_number = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NUMBER_PDF);
                    ep2_last_name = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+NAME_PDF);
                    ep2_last_dn = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+DN_PDF);
                    ep2_last = *(ttemp+(CALL_FLOW_INDEXES_PDF*(alert_index-1))+FORMATTED_PDF);
                    cnt = alert_index+1;                              /* to/from-setup-alert-transfered(?) */
                }
                *tmp_events++ = ep2_last_number;       /* e164 */
                *tmp_events++ = ep2_last_name;         /* h323 */
                *tmp_events++ = ep2_last_dn;           /* dn   */
                *tmp_events++ = ep2_last;              /* formatted */
                tmp_events++;                          /* image_ep2 */
            }
        } else if((call_flow_msgs[2] == CONN_TO_MSG) || (call_flow_msgs[2] == CONN_FROM_MSG)) {
            // if call setup message contains called number
            if(*(ttemp+NUMBER_PDF)) {
                ep2_last_number = *(ttemp+NUMBER_PDF);
                ep2_last_name = *(ttemp+NAME_PDF);
                ep2_last_dn = *(ttemp+DN_PDF);
                ep2_last = *(ttemp+FORMATTED_PDF);
            }
            else {
                ep2_last_number = *(ttemp+CALL_FLOW_INDEXES_PDF+NUMBER_PDF);
                ep2_last_name = *(ttemp+CALL_FLOW_INDEXES_PDF+NAME_PDF);
                ep2_last_dn = *(ttemp+CALL_FLOW_INDEXES_PDF+DN_PDF);
                ep2_last = *(ttemp+CALL_FLOW_INDEXES_PDF+FORMATTED_PDF);
            }
            *tmp_events++ = ep2_last_number;    /* e164 */
            *tmp_events++ = ep2_last_name;      /* h323 */
            *tmp_events++ = ep2_last_dn;        /* dn */
            *tmp_events++ = ep2_last;           /* formatted */
            tmp_events++;                       /* image_ep2 */
            cnt = 2+1; /* to/from-setup-conn */
            ptr_xml->state = ptr_xml->co;
            is_call_state = 1;
            conn_disc_rel = 1;
        }
        else {
            if((call_flow_msgs[2] == REL_TO_MSG) || (call_flow_msgs[2] == REL_FROM_MSG)) {
                // SKIP setup info, better to take rel info's if rel contains something
                if(*(ttemp+CALL_FLOW_INDEXES_PDF+NUMBER_PDF) || *(ttemp+CALL_FLOW_INDEXES_PDF+NAME_PDF) || *(ttemp+CALL_FLOW_INDEXES_PDF+DN_PDF)) {
                    conn_disc_rel = 2;
                    // setup
                    ep2_last_number = *ttemp++;
                    ep2_last_name = *ttemp++;
                    ep2_last_dn = *ttemp++;
                    ep2_last = *ttemp++;
                }
            }
            else if (secArray >= 4 && ((call_flow_msgs[2] == DISC_TO_MSG) || (call_flow_msgs[2] == DISC_FROM_MSG)) && \
                     ((call_flow_msgs[3] == REL_TO_MSG) || (call_flow_msgs[3] == REL_FROM_MSG))) {
                // SKIP setup/disc info, better to take rel info's if rel contains something
                if(*(ttemp+CALL_FLOW_INDEXES_PDF*2+NUMBER_PDF) || *(ttemp+CALL_FLOW_INDEXES_PDF*2+NAME_PDF) || *(ttemp+CALL_FLOW_INDEXES_PDF*2+DN_PDF)) {
                    conn_disc_rel = 3;
                    // setup
                    ep2_last_number = *ttemp++;
                    ep2_last_name = *ttemp++;
                    ep2_last_dn = *ttemp++;
                    ep2_last = *ttemp++;
                    // disc
                    ttemp++;
                    ttemp++;
                    ttemp++;
                    ttemp++;
                }
            }
            // ttemp points to rel event
            if(conn_disc_rel >= 2 && ep2_last_dn && ep2_last_number && (*(ttemp+NUMBER_PDF)) && !(*(ttemp+DN_PDF)) && !strcmp(ep2_last_number, *(ttemp+NUMBER_PDF))) {
                ep2_last_number = *ttemp++;
                ep2_last_name = *ttemp++;
                ttemp++;
                ttemp++;
            }
            else {
                ep2_last_number = *ttemp++;
                ep2_last_name = *ttemp++;
                ep2_last_dn = *ttemp++;
                ep2_last = *ttemp++;
            }
            *tmp_events++ = ep2_last_number;       /* e164 */
            *tmp_events++ = ep2_last_name;         /* h323 */
            *tmp_events++ = ep2_last_dn;           /* dn   */
            *tmp_events++ = ep2_last;              /* formatted */
            tmp_events++;                          /* image_ep2 */
            cnt = 2;                               /* to/from-setup-? */
        }
        /* remote: outgoing/incomming */
        if(ep2_last_number) {
            remote_e164 = (char *)malloc((strlen(ep2_last_number)+1)*sizeof(char)); 
            strcpy(remote_e164, ep2_last_number);
        }
        if(ep2_last_name) {
            remote_h323 = (char *)malloc((strlen(ep2_last_name)+1)*sizeof(char)); 
            strcpy(remote_h323, ep2_last_name);
        }
        if(ep2_last_dn) {
            remote_dn = (char *)malloc((strlen(ep2_last_dn)+1)*sizeof(char)); 
            strcpy(remote_dn, ep2_last_dn);
        }
        if(ep2_last) {
            remote_f = (char *)malloc((strlen(ep2_last)+1)*sizeof(char)); 
            strcpy(remote_f, ep2_last);
        }
        last_number = ep2_last_number;
        last_name = ep2_last_name;
        last_dn = ep2_last_dn;
        last = ep2_last;
        if(!f_pickup) {
            if(conn_disc_rel >= 2) {
                *tmp_events++ = ptr_xml->er;
                *tmp_events++ = (char *)image_lookup_table[ERROR]; /* state/imgage */
                tmp_events++;
                cnt = secArray;
            } else if(conn_disc_rel == 1) {
                *tmp_events++ = ptr_xml->co;
                if(is_callback)
                    *tmp_events++ = (char *)image_lookup_table[CONN_CALLBACK];
                else
                    *tmp_events++ = (char *)image_lookup_table[CONN];
                tmp_events++;
            } else {
                call_state = tmp_events; 
                tmp_events += 3;                      /* state/image/type */
            }
            *tmp_events++ = ptr_xml->true;            /* entry */
            ind = start_ind = 1;
        }
    }

    ttemp = *subevents;
    /* state of entry event */
    for(ind_t=cnt; ind_t<secArray && !is_call_state; ind_t++) {
        switch(call_flow_msgs[ind_t]) {
            case CONN_TO_MSG:
            case CONNECTED_MSG:
            case CONN_FROM_MSG:
            case TRANSFER_TO_MSG:
            case TRANSFER_FROM_MSG:
            case TRANSFER_REMOTE:
                *call_state++ = ptr_xml->co;
                if(is_callback)
                    *call_state = (char *)image_lookup_table[CONN_CALLBACK];
                else
                    *call_state = (char *)image_lookup_table[CONN];
                ptr_xml->state = ptr_xml->co;
                is_call_state = 1;
                break;
            case TRANSFERRED_MSG:
                if( (call_flow_msgs[ind_t+1] == CONN_TO_MSG) ||\
                    (call_flow_msgs[ind_t+1] == CONN_FROM_MSG) ||\
                    (call_flow_msgs[ind_t+1] == CONNECTED_MSG) ) {
                    *call_state++ = ptr_xml->co;
                    if(is_callback)
                        *call_state = (char *)image_lookup_table[CONN_CALLBACK];
                    else
                        *call_state = (char *)image_lookup_table[CONN];
                    ptr_xml->state = ptr_xml->co;
                } else {
                    *call_state++ = ptr_xml->al;
                    if(is_callback)
                        *call_state = (char *)image_lookup_table[NO_RES_CALLBACK];
                    else
                        *call_state = (char *)image_lookup_table[NO_RES];
                    if(ptr_xml->state == ptr_xml->er) ptr_xml->state = ptr_xml->al;
                }
                is_call_state = 1;
                break;
            case CF_TO_MSG:
            case CF_FROM_MSG:
            case DISC_FROM_MSG:
            case DISC_TO_MSG:
            case REL_FROM_MSG:
            case REL_TO_MSG:
                *call_state++ = ptr_xml->al;
                if(is_callback)
                    *call_state = (char *)image_lookup_table[NO_RES_CALLBACK];
                else
                    *call_state = (char *)image_lookup_table[NO_RES];
                if(ptr_xml->state == ptr_xml->er) ptr_xml->state = ptr_xml->al;
                is_call_state = 1;
                break;
        }
    }
    /* needed for remote and incomming calls, search for a transfer_to at the beginning */
    if(ptr_xml->tmpDir == ptr_xml->ep2) {
        for(ind_t=cnt; ind_t<secArray; ind_t++) {
            if(call_flow_msgs[ind_t] == TRANSFER_TO_MSG || call_flow_msgs[ind_t] == TRANSFER_REMOTE) {
                is_transfer = 1;
                break;
            }
        }
    }

    /*  incoming calls: best found state in call flow state */
    if(ptr_xml->tmpDir == ptr_xml->ep1 && ptr_xml->state != ptr_xml->co) {
        for(ind_t=cnt; ind_t<secArray; ind_t++) {
            switch(call_flow_msgs[ind_t]) {
                case CONN_TO_MSG:
                case CONNECTED_MSG:
                case CONN_FROM_MSG:
                case TRANSFER_TO_MSG:
                case TRANSFER_FROM_MSG:
                case TRANSFER_REMOTE:
                    ptr_xml->state = ptr_xml->co;
                    break;
            }
        }
    }

    ttemp = *subevents+CALL_FLOW_INDEXES_PDF*cnt;
    p_div = NULL;
    ptr_ev_state = NULL;
    sub_events = *subevents;
    for(; cnt<secArray; cnt++) {
        if(trace_level & TRACE_CALL_FLOW) {
            do_log(LOG_REPORTING, "", "reporting: msg: %s", msg_lookup_table[call_flow_msgs[cnt]]);
            do_log(LOG_REPORTING, "", "last number: %s %s %s %s", last_number, last_name, last_dn, last);
            do_log(LOG_REPORTING, "", "ep1 last: %s %s %s", ep1_last_number, ep1_last_name, ep1_last_dn);
            do_log(LOG_REPORTING, "", "ep2 last: %s %s %s", ep2_last_number, ep2_last_name, ep2_last_dn);
        }
        // Check Pickup
        if(((call_flow_msgs[cnt] == ALERT_TO_MSG) ||
            (call_flow_msgs[cnt] == ALERT_FROM_MSG) ||
            (call_flow_msgs[cnt] == TRANSFER_TO_MSG) ||
            (call_flow_msgs[cnt] == TRANSFER_FROM_MSG) ||
            (call_flow_msgs[cnt] == CF_TO_MSG) ||
            (call_flow_msgs[cnt] == CF_FROM_MSG)) &&
            ((call_flow_msgs[cnt+1] == CONN_FROM_MSG) || (call_flow_msgs[cnt+1] == CONN_TO_MSG) || (call_flow_msgs[cnt+1] == CONNECTED_MSG)) &&
            ((*(ttemp+NAME_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF) && strcmp(*(ttemp+NAME_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF))) ||
             (*(ttemp+DN_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+DN_PDF) && strcmp(*(ttemp+DN_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+DN_PDF))) ||
             (*(ttemp+NUMBER_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF) && (strlen(*(ttemp+NUMBER_PDF)) == strlen(*(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF))) && strcmp(*(ttemp+NUMBER_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF))))) {
            int side = 0;
            tmp_events += 2;                                /* caller */
            // Pickup
            if(p_div && ((call_flow_msgs[cnt] == ALERT_TO_MSG) || (call_flow_msgs[cnt] == ALERT_FROM_MSG))) {
                // rewrite with alert data
                *(p_div+NUMBER_PDF) = *(ttemp+NUMBER_PDF);
                *(p_div+NAME_PDF) = *(ttemp+NAME_PDF);
                *(p_div+DN_PDF) = *(ttemp+DN_PDF);
                *(p_div+FORMATTED_PDF) = *(ttemp+FORMATTED_PDF);
                ttemp += CALL_FLOW_INDEXES_PDF;
                cnt++;                                          // points now to connect event
                if(!ep1_right) {
                    tmp_events += 5;                        /* ep1 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);    /* ep2 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                    *tmp_events++ = (char *)image_lookup_table[PICKUP_REV];
                    ep2_last_number = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);
                    ep2_last_name = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    ep2_last_dn = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    ep2_last = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                }
                else {
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);    /* ep1  */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                    *tmp_events++ = (char *)image_lookup_table[PICKUP];
                    ep1_last_number = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);
                    ep1_last_name = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    ep1_last_dn = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    ep1_last = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                    tmp_events += 5;                        /* ep2 */
                }
            }
            else {
                if((call_flow_msgs[cnt] == ALERT_TO_MSG) || (call_flow_msgs[cnt] == TRANSFER_TO_MSG) || (call_flow_msgs[cnt] == CF_TO_MSG)) {
                    if(!ep1_right) {
                        tmp_events += 5;                        /* ep1 */
                        *tmp_events++ = *(ttemp+NUMBER_PDF);    /* ep2 */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt] == ALERT_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[NO_RES];
                        else if(call_flow_msgs[cnt] == TRANSFER_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CT_REV];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CF_REV];
                        side = 1;
                    }
                    else {
                        *tmp_events++ = *(ttemp+NUMBER_PDF);    /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt] == ALERT_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[NO_RES];
                        else if(call_flow_msgs[cnt] == TRANSFER_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CT];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CF];
                        tmp_events += 5;                        /* ep2 */
                    }
                } 
                else {
                    if(!ep1_right) {
                        *tmp_events++ = *(ttemp+NUMBER_PDF);    /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt] == ALERT_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[NO_RES];
                        else if(call_flow_msgs[cnt] == TRANSFER_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CT];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CF];
                        tmp_events += 5;                        /* ep2 */
                        ep1_right = 1;
                    }
                    else {
                        tmp_events += 5;                        /* ep1 */
                        *tmp_events++ = *(ttemp+NUMBER_PDF);    /* ep2 */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt] == ALERT_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[NO_RES];
                        else if(call_flow_msgs[cnt] == TRANSFER_TO_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CT_REV];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CF_REV];
                        side = 1;
                        ep1_right = 0;
                    }
                }
                ttemp += CALL_FLOW_INDEXES_PDF;
                *tmp_events++ = ptr_xml->al;                               /* state */
                *tmp_events++ = (char *)image_lookup_table[NO_RES];        /* state_img */
                if((call_flow_msgs[cnt] == CF_TO_MSG) || (call_flow_msgs[cnt] == CF_FROM_MSG)) {
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = ptr_xml->cf;                       /* xml-type */
                    }
                    *tmp_events++ = ptr_xml->cf;                           /* type */
                    tmp_events++;                                          /* entry */
                }
                else if((call_flow_msgs[cnt] == TRANSFER_TO_MSG) || (call_flow_msgs[cnt] == TRANSFER_FROM_MSG)) {
                    if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                        *tmp_events = ptr_xml->cct;             /* type   */
                    else
                        *tmp_events = ptr_xml->ct;              /* type   */
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = *tmp_events;            /* xml-type   */
                    }
                    tmp_events += 2;                            /* type/entry */
                }
                else
                    tmp_events += 2;                            /* type/entry */
                ind++;
                cnt++;                                          // points now to connect event
                tmp_events += 2;                                /* caller */
                if(!side) {
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);    /* ep1  */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                    *tmp_events++ = (char *)image_lookup_table[PICKUP];
                    ep1_last_number = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);
                    ep1_last_name = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    ep1_last_dn = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    ep1_last = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                    tmp_events += 5;                        /* ep2 */
                }
                else {
                    tmp_events += 5;                        /* ep1 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);    /* ep2 */
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    *tmp_events++ = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                    *tmp_events++ = (char *)image_lookup_table[PICKUP_REV];
                    ep2_last_number = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);
                    ep2_last_name = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
                    ep2_last_dn = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
                    ep2_last = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
                }
            }
            ttemp += CALL_FLOW_INDEXES_PDF;
            *tmp_events++ = ptr_xml->co;                           /* state */
            *tmp_events++ = (char *)image_lookup_table[CONN];      /* state_img */
            last_number = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NUMBER_PDF);
            last_name = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+NAME_PDF);
            last_dn = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+DN_PDF);
            last = *(sub_events+CALL_FLOW_INDEXES_PDF*cnt+FORMATTED_PDF);
            *tmp_events++ = ptr_xml->pu;                           /* type */
            tmp_events++;                                          /* entry */
            ind++;
            ptr_xml->state = ptr_xml->co;
            ptr_ev_state = NULL;
        }
        else {
            switch(call_flow_msgs[cnt]) {
                case CF_TO_MSG:
                    tmp_events += 2;                                       /* caller */   
                    if(!ep1_right) {
                        tmp_events += 5;                                   /* ep1 */
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);               /* ep2  */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        *tmp_events++ = (char *)image_lookup_table[CF_REV];
                        ptr_ev_state = tmp_events;                         /* state */
                        *tmp_events++ = ptr_xml->al;
                        *tmp_events++ = (char *)image_lookup_table[NO_RES];/* state_img */
                        ep2_last_number = *(ttemp+NUMBER_PDF);
                        ep2_last_name = *(ttemp+NAME_PDF);
                        ep2_last_dn = *(ttemp+DN_PDF);
                        ep2_last = *(ttemp+FORMATTED_PDF);
                    } else {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);               /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        *tmp_events++ = (char *)image_lookup_table[CF];
                        ep1_last_number = *(ttemp+NUMBER_PDF);
                        ep1_last_name = *(ttemp+NAME_PDF);
                        ep1_last_dn = *(ttemp+DN_PDF);
                        ep1_last = *(ttemp+FORMATTED_PDF);
                        tmp_events += 5;                                   /* ep2 */
                        ptr_ev_state = tmp_events;                         /* state */
                        *tmp_events++ = ptr_xml->al;
                        *tmp_events++ = (char *)image_lookup_table[NO_RES];/* state_img */
                    }
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    last = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        if( *(p_div+NUMBER_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF) ) {
                            check_ep += (strcmp(*(p_div+NAME_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF);
                            *(p_div+NAME_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF);
                            *(p_div+DN_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+DN_PDF);
                            *(p_div+FORMATTED_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+FORMATTED_PDF);
                            last_number = *(p_div+NUMBER_PDF);
                            last_name = *(p_div+NAME_PDF);
                            last_dn = *(p_div+DN_PDF);
                            last = *(p_div+FORMATTED_PDF);
                        }
                    }
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = ptr_xml->cf;                       /* xml-type   */
                    }
                    *tmp_events++ = ptr_xml->cf;                           /* type */
                    tmp_events++;                                          /* entry */ 
                    ind++;
                    break;
                case CF_FROM_MSG:
                    tmp_events += 2;                                       /* caller */   
                    if(!ep1_right) {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);                   /* ep1 */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        *tmp_events++ = (char *)image_lookup_table[CF];
                        ep1_last_number = *(ttemp+NUMBER_PDF);
                        ep1_last_name = *(ttemp+NAME_PDF);
                        ep1_last_dn = *(ttemp+DN_PDF);
                        ep1_last = *(ttemp+FORMATTED_PDF);
                        tmp_events += 5;                                       /* ep2 */ 
                        ep1_right = 1;
                    } else {
                        tmp_events += 5;                                       /* ep1 */ 
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);                   /* ep2 */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        *tmp_events++ = (char *)image_lookup_table[CF];
                        ep2_last_number = *(ttemp+NUMBER_PDF);
                        ep2_last_name = *(ttemp+NAME_PDF);
                        ep2_last_dn = *(ttemp+DN_PDF);
                        ep2_last = *(ttemp+FORMATTED_PDF);
                        ep1_right = 0;
                    }
                    ptr_ev_state = tmp_events;                             /* state */
                    *tmp_events++ = ptr_xml->al;
                    *tmp_events++ = (char *)image_lookup_table[NO_RES];    /* state_img */
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = ptr_xml->cf;                       /* xml-type */
                    }
                    *tmp_events++ = ptr_xml->cf;                           /* type */
                    tmp_events++;                                          /* entry */
                    ind++;
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    last = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        if( *(p_div+NUMBER_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF) ) {
                            check_ep += (strcmp(*(p_div+NAME_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF);
                            *(p_div+NAME_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF);
                            *(p_div+DN_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+DN_PDF);
                            *(p_div+FORMATTED_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+FORMATTED_PDF);
                            last_number = *(p_div+NUMBER_PDF);
                            last_name = *(p_div+NAME_PDF);
                            last_dn = *(p_div+DN_PDF);
                            last = *(p_div+FORMATTED_PDF);
                        }
                    }
                    break;
                case TRANSFER_REMOTE:
                case TRANSFER_TO_MSG:
                    tmp_events += 2;                                       /* caller */   
                    if(ep1_right) {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);               /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        ep1_last_number = *(ttemp+NUMBER_PDF);
                        ep1_last_name = *(ttemp+NAME_PDF);
                        ep1_last_dn = *(ttemp+DN_PDF);
                        ep1_last = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CCT];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CT];
                        tmp_events += 5;                                   /* ep2 */ 
                        if(call_flow_msgs[cnt] == TRANSFER_REMOTE) {
                            *tmp_events++ = ptr_xml->co;
                            *tmp_events++ = (char *)image_lookup_table[CONN];  /* state_img */
                        } else {
                            ptr_ev_state = tmp_events;                         /* state */
                            *tmp_events++ = ptr_xml->al;
                            *tmp_events++ = (char *)image_lookup_table[NO_RES];/* state_img */
                        }
                    } else {
                        tmp_events += 5;                                   /* ep1 */ 
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);               /* ep2  */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CCT_REV];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CT_REV];
                        if(call_flow_msgs[cnt] == TRANSFER_REMOTE) {
                            *tmp_events++ = ptr_xml->co;
                            *tmp_events++ = (char *)image_lookup_table[CONN];  /* state_img */
                        } else {
                            ptr_ev_state = tmp_events;                         /* state */
                            *tmp_events++ = ptr_xml->al;
                            *tmp_events++ = (char *)image_lookup_table[NO_RES];/* state_img */
                        }
                        ep2_last_number = *(ttemp+NUMBER_PDF);
                        ep2_last_name = *(ttemp+NAME_PDF);
                        ep2_last_dn = *(ttemp+DN_PDF);
                        ep2_last = *(ttemp+FORMATTED_PDF);
                        if(is_transfer) {
                            /* remote: outgoing/incomming */
                            if(remote_e164 != NULL) {
                                free(remote_e164);
                                remote_e164 = NULL;
                            }
                            if(ep2_last_number) {
                                remote_e164 = (char *)malloc((strlen(ep2_last_number)+1)*sizeof(char)); 
                                strcpy(remote_e164, ep2_last_number);
                            }
                            if(remote_h323 != NULL) {
                                free(remote_h323);
                                remote_h323 = NULL;
                            }
                            if(ep2_last_name) {
                                remote_h323 = (char *)malloc((strlen(ep2_last_name)+1)*sizeof(char)); 
                                strcpy(remote_h323, ep2_last_name);
                            }
                            if(remote_dn != NULL) {
                                free(remote_dn);
                                remote_dn = NULL;
                            }
                            if(ep2_last_dn) {
                                remote_dn = (char *)malloc((strlen(ep2_last_dn)+1)*sizeof(char)); 
                                strcpy(remote_dn, ep2_last_dn);
                            }
                            if(remote_f != NULL) {
                                free(remote_f);
                                remote_f = NULL;
                            }
                            if(ep2_last) {
                                remote_f = (char *)malloc((strlen(ep2_last)+1)*sizeof(char)); 
                                strcpy(remote_f, ep2_last);
                            }
                            is_transfer = 0;
                        }
                    }
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    last = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        if( *(p_div+NUMBER_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF) ) {
                            check_ep += (strcmp(*(p_div+NAME_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF);
                            *(p_div+NAME_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF);
                            *(p_div+DN_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+DN_PDF);
                            *(p_div+FORMATTED_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+FORMATTED_PDF);
                            last_number = *(p_div+NUMBER_PDF);
                            last_name = *(p_div+NAME_PDF);
                            last_dn = *(p_div+DN_PDF);
                            last = *(p_div+FORMATTED_PDF);
                        }
                    }
                    if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                        *tmp_events = ptr_xml->cct;             /* type   */
                    else
                        *tmp_events = ptr_xml->ct;              /* type   */
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = *tmp_events;            /* xml-type   */
                    }
                    tmp_events += 2;                            /* type/entry */
                    ind++;
                    break;
                case TRANSFER_FROM_MSG:
                    tmp_events += 2;                            /* caller */   
                    if(!ep1_right) {
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);        /* ep1  */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        ep1_last_number = *(ttemp+NUMBER_PDF);
                        ep1_last_name = *(ttemp+NAME_PDF);
                        ep1_last_dn = *(ttemp+DN_PDF);
                        ep1_last = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CCT];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CT];
                        tmp_events += 5;                            /* ep2 */ 
                        ep1_right = 1;
                    }
                    else {
                        tmp_events += 5;                            /* ep1 */
                        p_div = tmp_events;
                        *tmp_events++ = *(ttemp+NUMBER_PDF);        /* ep2 */
                        *tmp_events++ = *(ttemp+NAME_PDF);
                        *tmp_events++ = *(ttemp+DN_PDF);
                        *tmp_events++ = *(ttemp+FORMATTED_PDF);
                        ep2_last_number = *(ttemp+NUMBER_PDF);
                        ep2_last_name = *(ttemp+NAME_PDF);
                        ep2_last_dn = *(ttemp+DN_PDF);
                        ep2_last = *(ttemp+FORMATTED_PDF);
                        if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                            *tmp_events++ = (char *)image_lookup_table[CCT_REV];
                        else
                            *tmp_events++ = (char *)image_lookup_table[CT_REV];
                        ep1_right = 0;
                    }
                    ptr_ev_state = tmp_events;                           /* state */
                    *tmp_events++ = ptr_xml->al;
                    *tmp_events++ = (char *)image_lookup_table[NO_RES];  /* state_img */
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    last = *ttemp++;
                    /* Check if next event is better */
                    if((cnt+1) < secArray) {    // It is always true but ...
                        int check_ep = 0;
                        int checked_ep = 0;

                        if( *(p_div+NUMBER_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF) ) {
                            check_ep += (strcmp(*(p_div+NUMBER_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if( *(p_div+NAME_PDF) && *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF) ) {
                            check_ep += (strcmp(*(p_div+NAME_PDF), *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF)) != 0);
                            checked_ep = 1;
                        }
                        if(checked_ep && !check_ep) {
                            *(p_div+NUMBER_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NUMBER_PDF);
                            *(p_div+NAME_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+NAME_PDF);
                            *(p_div+DN_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+DN_PDF);
                            *(p_div+FORMATTED_PDF) =  *(sub_events+CALL_FLOW_INDEXES_PDF*(cnt+1)+FORMATTED_PDF);
                            last_number = *(p_div+NUMBER_PDF);
                            last_name = *(p_div+NAME_PDF);
                            last_dn = *(p_div+DN_PDF);
                            last = *(p_div+FORMATTED_PDF);
                        }
                    }
                    if(call_flow_msgs[cnt+1] == CONNECTED_MSG)
                        *tmp_events = ptr_xml->cct;             /* type   */
                    else
                        *tmp_events = ptr_xml->ct;              /* type   */
                    if(ind == start_ind && !ptr_xml->type) {
                        ptr_xml->type = *tmp_events;            /* xml-type */
                    }
                    tmp_events += 2;                            /* state/entry */
                    ind++;
                    break;
                case CONNECTED_MSG:
                case CONN_TO_MSG:
                case CONN_FROM_MSG:
                    if(ptr_ev_state) {
                        *ptr_ev_state++ = ptr_xml->co;
                        *ptr_ev_state = (char *)image_lookup_table[CONN];      /* state_img */
                    }
                    ptr_ev_state = NULL;
                case ALERT_TO_MSG:
                case ALERT_FROM_MSG:
                case DISC_FROM_MSG:
                case DISC_TO_MSG:
                case REL_FROM_MSG:
                case REL_TO_MSG:
                default:
                    last_number = *ttemp++;
                    last_name = *ttemp++;
                    last_dn = *ttemp++;
                    last = *ttemp++;
                    p_div = NULL;
                    break;
            }
        }
        if(call_flow_msgs[cnt] == TRANSFER_REMOTE) break;
    }

    if(ind > 0 && cause_code != NULL) {
        *(tmp_events-4) = cause_code;                           /* bu, er */
        if(cause_code == ptr_xml->bu) {
            if(is_callback)
                *(tmp_events-3) = (char *)image_lookup_table[BUSY_CALLBACK]; /* bu, er */
            else
                *(tmp_events-3) = (char *)image_lookup_table[BUSY]; /* bu, er */
        } else if(cause_code == ptr_xml->er) {
            if(is_callback)
                *(tmp_events-3) = (char *)image_lookup_table[ERROR_CALLBACK]; /* bu, er */
            else
                *(tmp_events-3) = (char *)image_lookup_table[ERROR]; /* bu, er */
        }
        if(cause_code == ptr_xml->bu && ptr_xml->state != ptr_xml->co) 
            ptr_xml->state = cause_code;
        else if(cause_code == ptr_xml->er && ind == 1)           /* ind > 1, there is for sure a better state, "al" probably */
            ptr_xml->state = cause_code;
    }
    *numEvents = ind;

    if(remote) {
        remote->remote_e164 = remote_e164;
        remote->remote_h323 = remote_h323;
        remote->remote_dn = remote_dn;
        remote->remote = remote_f;
    }
    else {
        if(remote_e164) free(remote_e164);
        if(remote_h323) free(remote_h323);
        if(remote_dn) free(remote_dn);
        if(remote_f) free(remote_f);
    }

    if(csv) {
        csv->object_info = object_info;
        csv->object_called = object_called;
        csv->diverting = diverting;
        csv->transferring = transferring;
    }
    else {
        if(object_info) free(object_info);
        if(object_called) free(object_called);
        if(diverting) free(diverting);
        if(transferring) free(transferring);
    }

    if(trace_level & TRACE_CALL_FLOW_TOTAL) {
        ttemp = *events;
        for(i=0; i<secArray; i++) {
            for(j=0; j<PDF_EVENTS_ATTRIB; j++) {
                if(*ttemp != NULL) {
                    do_log(LOG_REPORTING, "", "reporting: %s = %s", pdf_events_attrib[j], *ttemp);
                }
                ttemp++;
            }
        }
        do_log(LOG_REPORTING, "", "reporting: free: %d-%d-%p", secArray, *numEvents, *subevents);
    }

    free(call_flow_msgs);
    free(msg_buffer);

    return secArray;
}

static int
sec2hms(int seconds, char *time, int showh)
{
    if(seconds >= 3600 || showh) {
        int mins = (int)(seconds / 60); 
        int secs = seconds % 60;
        int hours = (int)(mins / 60); 

        mins = mins % 60;

        if((mins > 9) && (secs > 9)) {
            sprintf(time,"%d%s%d%s%d",hours,":",mins,":",secs);
        } else if (mins > 9) {
            sprintf(time,"%d%s%d%s%d",hours,":",mins,":0",secs);
        } else if(secs > 9) {
            sprintf(time,"%d%s%d%s%d",hours,":0",mins,":",secs);
        } else {
            sprintf(time,"%d%s%d%s%d",hours,":0",mins,":0",secs);
        }
    } else if(seconds >= 60) {
        int mins = (int)(seconds / 60); 
        int secs = seconds % 60;

        if(secs < 10) {
            sprintf(time,"%d%s%d",mins,":0",secs);
        } else {
            sprintf(time,"%d%s%d",mins,":",secs);
        }
    } else if(seconds > 9) {
        sprintf(time,"%s%d","0:",seconds);
    } else if(seconds > 0) {
        sprintf(time,"%s%d","0:0",seconds);
    } else {
        return 0;
    }
    return 1;
}

int create_report(char *query_string, FCGX_Request *cgi, char * doc_root, int *bytes_sent, int *output_len)
{
    CURL * curl = curl_easy_init();
    FILE *f = NULL;
    PGconn *conn;
    PGresult *res;
    int nFields_db = 0, nFields = 0, nTuples = 0;
    int i, j, num_cols=0, equal=0, cause=0, c_type = 0;
    time_t curtime_report, after_time_report;
    time_t curtime_db, after_time_db;
    struct timeval tvBegin, tvEnd, tvDiff;
    int chk_further = 0;
    int callTimeIndex = -1;
    int callTimeShortIndex = -1;
    int callDateIndex = -1;
    int callDateSortIndex = -1;
    int callUnixTimeIndex = -1;
    int callUtcUnixTimeIndex = -1;
    int callCCnIndex = -1;
    int callConfIndex = -1;
    int callTypeIndex = -1;
    int callDirectionIndex = -1;
    int callFlowIndex = -1;
    int callCallDurIndex = -1;
    int callBillDurIndex = -1;
    int callConnDurIndex = -1;
    int callAlertIndex = -1;
    int callCauseIndex = -1;
    int callCbH323Index = -1;
    int callCbE164Index = -1;
    int callCbDnIndex = -1;
    int callCbTimeIndex = -1;
    int callCbTimeUnixIndex = -1;
    int callPbxIndex = -1;
    int callPhysIndex = -1;
    int callNodeIndex = -1;
    int callSystemIndex = -1;
    int groupByIndex = 0;
    char *xml_out_i = NULL;
    char *xml_out = NULL;
    int xml_out_len = 0;
    char *csv_out = NULL;
    int csv_out_len = 0;
    int start_put = 0;
    char *xml_out_gz = NULL;
    char *elemTmp, *groupValue;
    char *conninfo = NULL;
    char *query = NULL;
    char *format = NULL;
    char *href = NULL;
    char *file_name = NULL;
    char *server = NULL;
    char *order = NULL;
    char *svalue = NULL;
    char *gvalue = NULL;
    char *filter_name = NULL;
    char *filters_name = NULL;
    char *pbx_object = NULL;
    char *pbx = NULL;
    char *from_date = NULL;
    char *to_date = NULL;
    char *logo = NULL;
    char *logo_width = NULL;
    char *footer = NULL;
    char *footer_width = NULL;
    int  footer_width_len = 0;
    char *cn = NULL;
    char *userpbx = NULL;
    char *usergroup = NULL;
    char **columns = NULL, **tmp_columns = NULL;
    int  *ind_columns = NULL;
    xml_strings *ptr_strings = NULL;
#ifdef _ADD_CALL_FLOW
    const char *xmlTmp;
#endif
    int num_calls_in = 0;
    int num_calls_out = 0;
    int total_call_length_in = 0;
    int total_call_length_out = 0;
    int total_alert_dur_in = 0;
    int total_alert_dur_out = 0;
    char time_formatted[32];
    z_stream strm;
    int use_deflate = 0;
    char * accept_encoding = NULL;
    char file_read[1024];
    char file_len_str[15];
    int file_len = 0;
    int file_read_len = 0;
    int lang = -1;
    char * lang_str = NULL;
    char * displayed_duration = NULL;
    int internal = 0, mypbx = 0, filter_info = 0, anonym = 0;
    int digits_to_hide = 0;
    int report_limit = 0;
    char * cfg_file_param = get_url_param(curl, query_string, "cfg", "reporting", LOG_REPORTING);
    char * cfg_file;
    curl_easy_cleanup(curl);
    ldap_servers_t *ldap_servers;
    int txt_displayed_duration_index = 0, callDisplayedDuration = 0, displayedDurCol = 0;
    config_t *reporting_cfg = NULL;
    reporting_cfg = read_config(NULL);

    //unsigned int crc = 0, tot = 0;

    if(!cfg_file_param || !*cfg_file_param) {
        do_log(LOG_REPORTING, "", "reporting: cfg file not given");;
        if(cfg_file_param) free(cfg_file_param);
        cleanup_config(reporting_cfg);
        return ERROR_REPORT_NO_CONFIG_FILE;
    }
    if (reporting_cfg->error) {
        do_log(LOG_REPORTING, "", "reporting: reporting config couldn't be read %s", reporting_cfg->error);
        cleanup_config(reporting_cfg);
        return ERROR_REPORTING_CONFIG;
    }

    internal = (cgi == NULL);

    /* PARSE CFG FILE */
    {
        int eol = 0xA;
        cfg_file = malloc(strlen(doc_root) + strlen("/apps/innovaphone-reporting/tmp/") + strlen(cfg_file_param) + 1);
        strcpy(cfg_file, doc_root);
        strcat(cfg_file, "/apps/innovaphone-reporting/tmp/");
        strcat(cfg_file, cfg_file_param);
        FILE *cfg = fopen((const char *)cfg_file,"r");
        free(cfg_file_param);
        int ch;
        int res_parsing = NO_ERROR, alloc_length;
        char *fline0;
        char *fline1;
        char *tmp_line0, *tmp_line1;

        if(cfg==NULL) {
            do_log(LOG_REPORTING, "", "reporting: cfg file '%s' could not be opened", cfg_file);
            free(cfg_file);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_OPENING_CFG;
        }
        free(cfg_file);
        fline0 = (char *)malloc(128*sizeof(char));
        int fline_size = 2048;
        int fline_count = 0;
        fline1 = (char *)malloc(fline_size*sizeof(char));
        do {
            tmp_line0 = fline0; tmp_line1 = fline1;
            do {
                ch = fgetc(cfg);
                if((ch == EOF) || (ch == eol)) break;
                *tmp_line0++ = (char)ch;
            } while(1);
            fline_count = 0;
            do {
                ch = fgetc(cfg);
                if((ch == EOF) || (ch == eol)) break;
                if(++fline_count >= fline_size) {
                    fline_size += 1024;
                    char * fline_tmp = (char *)malloc(fline_size*sizeof(char));
                    memcpy(fline_tmp, fline1, fline_count - 1);
                    free(fline1);
                    fline1 = fline_tmp;
                    tmp_line1 = fline1 + fline_count - 1;
                }
                *tmp_line1++ = (char)ch;
            } while(1);
            if(ch == EOF) break;
            *tmp_line0 = 0x0; *tmp_line1 = 0x0;
            alloc_length = (((strlen(fline1)+4)>>2)<<2);
            if(strstr(fline0, CFG_CONN_DB)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_CONN_DB;
                else {
                    conninfo = (char *)malloc(alloc_length*sizeof(char));
                    if(conninfo)
                        memcpy(conninfo, fline1, strlen(fline1)*sizeof(char) + 1); 
                    else res_parsing=ERROR_MEM_CONN_DB;
                }
            } else if(strstr(fline0, CFG_QUERY)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_QUERY;
                else {
                    query = (char *)malloc(alloc_length*sizeof(char));
                    if(query)
                        memcpy(query, fline1, strlen(fline1)*sizeof(char) + 1); 
                    else res_parsing=ERROR_MEM_QUERY;
                }
            } else if(strstr(fline0, CFG_LANGUAGE)) {
                lang_str = (char *)malloc(alloc_length*sizeof(char));
                if(lang_str)
                    memcpy(lang_str, fline1, strlen(fline1)*sizeof(char) + 1); 
                else res_parsing=ERROR_MEM_LANGUAGE;
            } else if(strstr(fline0, CFG_HREF)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_HREF;
                else {
                    href = (char *)malloc((alloc_length<<3)*sizeof(char));
                    if(href)
                        xmlentities(fline1, href, strlen(fline1));
                    else res_parsing=ERROR_MEM_HREF;
                }
            } else if(strstr(fline0, CFG_FORMAT)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_FORMAT;
                else {
                    format = (char *)malloc(alloc_length*sizeof(char));
                    if(format) 
                        memcpy(format, fline1, strlen(fline1) + 1);
                    else res_parsing=ERROR_MEM_FORMAT;
                }
            } else if(strstr(fline0, CFG_SERVER)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_SERVER;
                else {
                    server = (char *)malloc(alloc_length*sizeof(char));
                    if(server) 
                        memcpy(server, fline1, strlen(fline1) + 1);
                    else res_parsing=ERROR_MEM_SERVER;
                }
            } else if(strstr(fline0, CFG_MYPBX)) {
                if(strlen(fline1) <= 0 || !strcmp(fline1, "0")) mypbx = 0;
                else mypbx = 1;
            } else if(strstr(fline0, CFG_FILTER_INFO)) {
                if(strlen(fline1) <= 0 || !strcmp(fline1, "0")) filter_info = 0;
                else filter_info = 1;
            } else if(strstr(fline0, CFG_ANONYM)) {
                if(strlen(fline1) <= 0 || !strcmp(fline1, "0")) anonym = 0;
                else anonym = 1;
            } else if(strstr(fline0, CFG_DISPLAYED_DURATION)) {
                displayed_duration = (char *)malloc(alloc_length*sizeof(char));
                if(displayed_duration)
                    memcpy(displayed_duration, fline1, strlen(fline1)*sizeof(char) + 1); 
                else res_parsing=ERROR_MEM_DISPLAYED_DURATION;
            } else if(strstr(fline0, CFG_HIDE_DIGITS)) {
                if(strlen(fline1) <= 0 || !strcmp(fline1, "0")) digits_to_hide = 0;
                else digits_to_hide = atoi(fline1);
            } else if(strstr(fline0, CFG_REPORT_LIMIT)) {
                if(strlen(fline1) <= 0 || !strcmp(fline1, "0")) report_limit = 0;
                else report_limit = atoi(fline1);
            } else if(strstr(fline0, CFG_REPORT_FILE)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_FILENAME;
                else {
                    file_name = (char *)malloc(alloc_length*sizeof(char));
                    if(file_name)
                        memcpy(file_name, fline1, strlen(fline1) + 1);
                    else res_parsing=ERROR_MEM_FILENAME;
                }
            } else if(strstr(fline0, CFG_CN)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_CN;
                else {
                    cn = (char *)malloc(alloc_length*sizeof(char));
                    if(cn)
                        memcpy(cn, fline1, strlen(fline1) + 1);
                    else res_parsing=ERROR_MEM_CN;
                }
            } else if(strstr(fline0, CFG_USER_PBX)) {
                userpbx = (char *)malloc(alloc_length*sizeof(char));
                if(userpbx)
                    memcpy(userpbx, fline1, strlen(fline1) + 1);
                else res_parsing=ERROR_MEM_USER_PBX;
            } else if(strstr(fline0, CFG_USER_GROUP)) {
                if(strlen(fline1) <= 0) res_parsing=ERROR_USER_GROUP;
                else {
                    usergroup = (char *)malloc(alloc_length*sizeof(char));
                    if(usergroup)
                        memcpy(usergroup, fline1, strlen(fline1) + 1);
                    else res_parsing=ERROR_MEM_USER_GROUP;
                }
            } else if(strstr(fline0, CFG_SORT_ORDER)) {
                order = (char *)malloc(alloc_length*sizeof(char));
                if(order == NULL) {
                    res_parsing=ERROR_MEM_SORDER;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(order, 0x0, alloc_length);
                    } else {
                        memcpy(order, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_SORT_VALUE)) {
                svalue = (char *)malloc(alloc_length*sizeof(char));
                if(svalue == NULL) {
                    res_parsing=ERROR_MEM_SVALUE;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(svalue, 0x0, alloc_length);
                    } else {
                        memcpy(svalue, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_GROUP_VALUE)) {
                gvalue = (char *)malloc(alloc_length*sizeof(char));
                if(gvalue == NULL) {
                    res_parsing=ERROR_MEM_GVALUE;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(gvalue, 0x0, alloc_length);
                    } else {
                        memcpy(gvalue, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_FILTERS)) {
                filters_name = (char *)malloc(alloc_length*sizeof(char));
                if(filters_name == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(filters_name, 0x0, alloc_length);
                    } else {
                        memcpy(filters_name, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_FILTER_NAME)) {
                filter_name = (char *)malloc(alloc_length*sizeof(char));
                if(filter_name == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(filter_name, 0x0, alloc_length);
                    } else {
                        memcpy(filter_name, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_PBX_OBJECT)) {
                pbx_object = (char *)malloc(alloc_length*sizeof(char));
                if(pbx_object == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(pbx_object, 0x0, alloc_length);
                    } else {
                        memcpy(pbx_object, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_PBX)) {
                pbx = (char *)malloc(alloc_length*sizeof(char));
                if(pbx == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(pbx, 0x0, alloc_length);
                    } else {
                        memcpy(pbx, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_FROM_DATE)) {
                from_date = (char *)malloc(alloc_length*sizeof(char));
                if(from_date == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(from_date, 0x0, alloc_length);
                    } else {
                        memcpy(from_date, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_TO_DATE)) {
                to_date = (char *)malloc(alloc_length*sizeof(char));
                if(to_date == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(to_date, 0x0, alloc_length);
                    } else {
                        memcpy(to_date, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_LOGO)) {
                logo = (char *)malloc(alloc_length*sizeof(char));
                if(logo == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(logo, 0x0, alloc_length);
                    } else {
                        memcpy(logo, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_LOGO_WIDTH)) {
                logo_width = (char *)malloc(alloc_length*sizeof(char));
                if(logo_width == NULL) {
                    res_parsing=ERROR_MEM_LOGO;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(logo_width, 0x0, alloc_length);
                    } else {
                        memcpy(logo_width, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_FOOTER)) {
                footer = (char *)malloc(alloc_length*sizeof(char));
                if(footer == NULL) {
                    res_parsing=ERROR_MEM_FOOTER;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(footer, 0x0, alloc_length);
                    } else {
                        memcpy(footer, fline1, strlen(fline1) + 1);
                    }
                }
            } else if(strstr(fline0, CFG_FOOTER_WIDTH)) {
                footer_width = (char *)malloc(alloc_length*sizeof(char));
                if(footer_width == NULL) {
                    res_parsing=ERROR_MEM_FOOTER;
                } else {
                    if(strlen(fline1) <= 0) {
                        memset(footer_width, 0x0, alloc_length);
                    } else {
                        memcpy(footer_width, fline1, strlen(fline1) + 1);
                        footer_width_len = atoi(footer_width);
                    }
                }
            } else if(strstr(fline0, CFG_COL_NAMES)) {
                char **tmp_cols;
                int i;
                num_cols = atoi(fline1);
                columns = (char **)malloc(num_cols*sizeof(char *));
                ind_columns = (int *)malloc(num_cols<<2);
                if(columns == NULL || ind_columns == NULL) {
                    res_parsing=ERROR_MEM_COLUMNS;
                } else {
                    tmp_cols = columns;
                    for(i=0;i<num_cols;i++) {
                        tmp_line1 = fline1;
                        do {
                            ch = fgetc(cfg);
                            if((ch == EOF) || (ch == eol)) break;
                            *tmp_line1++ = (char)ch;
                        } while(1);
                        if(ch == EOF)
                            break;
                        *tmp_line1 = 0x0;
                        alloc_length = (((strlen(fline1)+4)>>2)<<2);
                        *tmp_cols = (char *)malloc(alloc_length*sizeof(char));
                        if(*tmp_cols) {
                            memcpy(*tmp_cols, fline1, strlen(fline1) + 1);
                            tmp_cols++;
                        } else { 
                            res_parsing=ERROR_MEM_COLUMNS; 
                            break; 
                        }
                    }
                }
            } else {
                //printf("cfg not known\n");
            }
            if(res_parsing != 0) break;
        } while(ch != EOF);
        fclose(cfg);
        free(fline0);
        free(fline1);
        if(res_parsing != NO_ERROR) {
            do_log(LOG_REPORTING, "", "reporting: error parsing configuration file: %s", parse_errors[res_parsing]);
            if(href != NULL) free(href);
            if(query != NULL) free(query);
            if(conninfo != NULL) free(conninfo);
            if(format != NULL) free(format);
            if(file_name != NULL) free(file_name);
            if(server != NULL) free(server);
            if(order != NULL) free(order);
            if(svalue != NULL) free(svalue);
            if(gvalue != NULL) free(gvalue);
            if(logo != NULL) free(logo);
            if(logo_width != NULL) free(logo_width);
            if(footer != NULL) free(footer);
            if(footer_width != NULL) free(footer_width);
            if(cn != NULL) free(cn);
            if(usergroup != NULL) free(usergroup);
            if(userpbx != NULL) free(userpbx);
            if(filter_name != NULL) free(filter_name);
            if(filters_name != NULL) free(filters_name);
            if(pbx_object != NULL) free(pbx_object);
            if(pbx != NULL) free(pbx);
            if(from_date != NULL) free(from_date);
            if(to_date != NULL) free(to_date);
            if(lang_str != NULL) free(lang_str);
            if(displayed_duration != NULL) free(displayed_duration);
            tmp_columns = columns;
            for(i=0;i<num_cols;i++) {
               if(*tmp_columns != NULL) free(*tmp_columns);
               tmp_columns++;
            }
            free(columns);
            free(ind_columns);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_PARSING_CFG_FILE;
        }
    }
    if(anonym && !digits_to_hide) digits_to_hide = 3;
    lang = lookup_language(lang_str);
    if(displayed_duration == NULL) displayed_duration = str_malloc("call_duration");
    
    if(!internal) {
        // check client accept encoding
        accept_encoding = FCGX_GetParam("HTTP_ACCEPT_ENCODING", cgi->envp);
        if(accept_encoding && strstr(accept_encoding, "deflate")) {
            use_deflate = 1;
        }
    }

    tmp_columns = columns;
    for(i=0; i<num_cols; i++) {
        ind_columns[i] = TOTAL_NUMBER_COLUMNS+1;
        for(j=0;j<TOTAL_NUMBER_COLUMNS;j++) {
            if(!strcmp(*tmp_columns, column_lookup_table[j])) {
                ind_columns[i] = j;
                switch(j) {
                    case CALL_FLOW_COL: callFlowIndex = i; break;
                    case CALLBACK_E164: callCbE164Index = i; break;
                    case CALLBACK_H323: callCbH323Index = i; break;
                    case CALLBACK_DN: callCbDnIndex = i; break;
                    case CALLBACK_TIME: callCbTimeIndex = i; break;
                    case CALLBACK_TIME_UNIX: callCbTimeUnixIndex = i; break;
                    case TIME_COL: callTimeIndex = i; break;
                    case DATUM_COL: callDateIndex = i; break;
                    case TIME_SHORT_COL: callTimeShortIndex = i; break;
                    case DATUM_SORT_COL: callDateSortIndex = i; break;
                    case UNIX_TIME_COL: callUnixTimeIndex = i; break;
                    case UTC_UNIX_TIME_COL: callUtcUnixTimeIndex = i; break;
                    case DIR_COL: callDirectionIndex = i; break;
                    case CONF_COL: callConfIndex = i; break;
                    case CN_COL: callCCnIndex = i; break;
                    case CALL_COL: callTypeIndex = i; break;
                    case CALL_CONN_COL: callConnDurIndex = i; break;
                    case CALL_DUR_COL: callCallDurIndex = i; break;
                    case ALERT_COL: callAlertIndex = i; break;
                    case CALL_BILLING_COL: callBillDurIndex = i; break;
                    case CAUSE_COL: callCauseIndex = i; break;
                    case PBX_COL: callPbxIndex = i; break;
                    case PHYS_COL: callPhysIndex = i; break;
                    case NODE_COL: callNodeIndex = i; break;
                    case SYSTEM_COL: callSystemIndex = i; break;
                }
                //break;
            }
        }
        tmp_columns++;
    }
    if(gvalue) {
        if(!strcmp(gvalue, xml_lookup_table[TIME_COL])) {
            groupByIndex = callDateIndex;
        }
        else {
            groupByIndex = callCCnIndex;
        }
    }

    chk_further = ((callDirectionIndex != -1) && (callCCnIndex != -1) && (callConfIndex != -1) && (callConnDurIndex != -1) && (callCallDurIndex != -1));
    if((callPbxIndex == -1) || (callPhysIndex == -1)) {
        digits_to_hide = 0;
    }

    if(trace_level & TRACE_PARSE_CFG) {
        tmp_columns = columns;
        do_log(LOG_REPORTING, "", "reporting: CFG: %s-%s-%s-%s-%s-%s-%s-%s cols:%d db:%s digits=%d anonym=%d<br>",query,href,server,format,file_name,order,svalue,gvalue,num_cols,conninfo,digits_to_hide,anonym);
        for(i=0;i<num_cols;i++) {
            do_log(LOG_REPORTING, "", "reporting: cols[%d,%d]:%s index:%d", i, strlen(*tmp_columns), *tmp_columns, ind_columns[i]);
            tmp_columns++;
        }
        do_log(LOG_REPORTING, "", "reporting: Indexes: Flow:%d Dir:%d Conf:%d cn:%d len:%d-%d-%d-%d cause:%d time:%d time-short:%d date:%d date_sort:%d unix-time:%d pbx-phys:%d-%d group-index=%d", callFlowIndex,callDirectionIndex,callConfIndex,callCCnIndex,callConnDurIndex,callCallDurIndex,callBillDurIndex,callAlertIndex,callCauseIndex,callTimeIndex,callTimeShortIndex,callDateIndex,callDateSortIndex,callUnixTimeIndex,callPbxIndex,callPhysIndex,groupByIndex);
        do_log(LOG_REPORTING, "", "reporting: Indexes[%d]: CbH323:%d CbE164:%d CbDn:%d CbTime:%d CbTimeUnix:%d", chk_further, callCbH323Index, callCbE164Index, callCbDnIndex, callCbTimeIndex, callCbTimeUnixIndex);
    }

    ptr_strings = (xml_strings *)malloc(sizeof(xml_strings));
    if(ptr_strings == NULL) {
        do_log(LOG_REPORTING, "", "reporting: No memory available");
        cleanup_config(reporting_cfg);
        return ERROR_REPORT_NO_MEMORY_AVAILABLE;
    } else {
        ptr_strings->true = (char *)malloc(8*sizeof(char));
        ptr_strings->ct = (char *)malloc(8*sizeof(char));
        ptr_strings->cct = (char *)malloc(8*sizeof(char));
        ptr_strings->cf = (char *)malloc(8*sizeof(char));
        ptr_strings->co = (char *)malloc(8*sizeof(char));
        ptr_strings->al = (char *)malloc(8*sizeof(char));
        ptr_strings->er = (char *)malloc(8*sizeof(char));
        ptr_strings->bu = (char *)malloc(8*sizeof(char));
        ptr_strings->pu = (char *)malloc(8*sizeof(char));
        ptr_strings->ep1 = (char *)malloc(8*sizeof(char));
        ptr_strings->ep2 = (char *)malloc(8*sizeof(char));
        if(ptr_strings->ct == NULL || ptr_strings->cct == NULL || ptr_strings->cf == NULL || ptr_strings->true == NULL ||\
           ptr_strings->ep1 == NULL || ptr_strings->ep2 == NULL ||\
           ptr_strings->co == NULL || ptr_strings->al == NULL || ptr_strings->er == NULL || ptr_strings->bu == NULL  || ptr_strings->pu == NULL) {
            do_log(LOG_REPORTING, "", "reporting: No memory available");
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_NO_MEMORY_AVAILABLE;
        }
        strcpy(ptr_strings->ct,"ct");
        strcpy(ptr_strings->cct,"cct");
        strcpy(ptr_strings->cf,"cf");
        strcpy(ptr_strings->true,"true");
        strcpy(ptr_strings->co,"co");
        strcpy(ptr_strings->al,"al");
        strcpy(ptr_strings->er,"er");
        strcpy(ptr_strings->bu,"bu");
        strcpy(ptr_strings->pu,"pu");
        strcpy(ptr_strings->ep1,"ep1");
        strcpy(ptr_strings->ep2,"ep2");
    }

    if(trace_level & TRACE_TIME) {
        curtime_db = time (NULL);
    }
    
    /* Make a connection to the database */
    conn = PQconnectdb(conninfo);
    PQsetNoticeProcessor(conn, defaultNoticeProcessor, NULL);

    /* Check to see that the backend connection was successfully made */
    if (PQstatus(conn) != CONNECTION_OK)
    {
        do_log(LOG_REPORTING, "", "reporting: connection to database failed: %s", PQerrorMessage(conn));
        PQfinish(conn);
        cleanup_config(reporting_cfg);
        return ERROR_CONNECTING_TO_DB;
    }
    if (PQsetClientEncoding(conn, "UTF-8") != 0) {
        do_log(LOG_REPORTING, "", "reporting: setting client encoding failed: %s", PQerrorMessage(conn));
        PQfinish(conn);
        cleanup_config(reporting_cfg);
        return ERROR_SETTING_ENCODING;
    }

    /*
     * Our test case here involves using a cursor, for which we must be inside
     * a transaction block.  We could do the whole thing with a single
     * PQexec() of "select * from pg_database", but that's too trivial to make
     * a good example.
     */

    /* Start a transaction block */
    res = PQexec(conn, "BEGIN");
    if (PQresultStatus(res) != PGRES_COMMAND_OK)
    {
        do_log(LOG_REPORTING, "", "reporting: BEGIN command failed: %s", PQerrorMessage(conn));
        PQclear(res);
        PQfinish(conn);
        cleanup_config(reporting_cfg);
        return ERROR_EXECUTING_BEGIN_CMD;
    }

    /*
     * Should PQclear PGresult whenever it is no longer needed to avoid memory
     * leaks
     */
    PQclear(res);

    /*
     * Fetch rows from pg_database, the system catalog of databases
     */
    res = PQexec(conn, query);
    if (PQresultStatus(res) != PGRES_TUPLES_OK)
    {
        do_log(LOG_REPORTING, "", "reporting: query failed: %s", query);
        do_log(LOG_REPORTING, "", "reporting: query error: %s", PQerrorMessage(conn));
        PQclear(res);
        nTuples = nFields = 0;
        PQfinish(conn);
        cleanup_config(reporting_cfg);
        return ERROR_EXECUTING_QUERY;
    }

    nTuples = PQntuples(res);
    nFields_db = PQnfields(res);

    if(trace_level & TRACE_TIME) {
        after_time_db = time (NULL);
        curtime_report = time (NULL);
        gettimeofday(&tvBegin, NULL);
    }
    
    ldap_servers = read_ldap_config(conn, NULL, NULL);

    txt_displayed_duration_index = TXT_CALL_DURATION;
    callDisplayedDuration = callCallDurIndex;
    displayedDurCol = CALL_DUR_COL;
    if(!strcmp(displayed_duration, column_lookup_table[CALL_CONN_COL])) {
        txt_displayed_duration_index = TXT_CONN_DURATION;
        callDisplayedDuration = callConnDurIndex;
        displayedDurCol = CALL_CONN_COL;
    }
    else if(!strcmp(displayed_duration, column_lookup_table[CALL_BILLING_COL])) {
        txt_displayed_duration_index = TXT_BILLING_DURATION;
        callDisplayedDuration = callBillDurIndex;
        displayedDurCol = CALL_BILLING_COL;
    }
    if(!strcmp(format, "pdf")) {
        HPDF_Doc pdf;
        HPDF_Font font;
        HPDF_TextWidth check_w;
        HPDF_Page *ptr_page, *pages = NULL;
        HPDF_Rect rect;
        int max_num_pages;
        int x, y, ind, total_line_sep = 0;
        int *index_cols = NULL;
        int *ptr_index_cols;
        int pdf_width = DIMA4_WIDTH;
        int pdf_height = DIMA4_HEIGHT;
        int set_first_line = 0, added_new_page = 0;
        int total_number_lines = 0;
        int x_logo = 0, x_footer = 0;
        int grp_calls_in = 0, grp_calls_out = 0, grp_conn_duration = 0, grp_alert_duration = 0;
        const char *fontname; 
        const char *fontname_bold; 
        char *last_group_by = NULL;
        char tot_calls_io[40];
        char tot_duration_io[40];
        char tot_alert_io[40];
        char num_page[8]; 
        int num_pages = 1;
        int bottom_margin = BOTTOM_MARGIN;
        HPDF_Image *images = NULL;
        int check_obj_length = 0;
        int check_left_length = 0;
        int check_right_length = 0;
        int obj_length = 0, left_length = 0, right_length = 0;
        int time_length = 0, dur_length = 50, alert_length = 50;
        int dir_icon_length = 23, state_icon_length = 23;
        int right_icon_length = 23, left_icon_length = 23;
        int max_length_chars = 238, max_num_chars = 58;
        int lines_gvalue = 0;
        
        pdf = HPDF_New (error_handler, NULL);
        if (!pdf) {
            do_log(LOG_REPORTING, "", "reporting: ERROR cannot create PdfDoc object");
            free_ldap_config(ldap_servers);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_CREATING_PDF_OBJECT;
        }

        /*if(HPDF_NewDoc(pdf)) {
            do_log(LOG_REPORTING, "", "reporting: ERROR cannot create new document");
            free_ldap_config(ldap_servers);
            return ERROR_REPORT_CREATING_NEW_PDF_DOC;
        }*/
        HPDF_SetCompressionMode (pdf, HPDF_COMP_ALL);

        /* create default-font */
        HPDF_UseUTFEncodings(pdf); 
        fontname_bold = HPDF_LoadTTFontFromFile(pdf, "apps/innovaphone-reporting/fonts/FreeSansBold.ttf", HPDF_TRUE); 
        fontname = HPDF_LoadTTFontFromFile(pdf, "apps/innovaphone-reporting/fonts/FreeSans.ttf", HPDF_TRUE); 
        font = HPDF_GetFont (pdf, fontname, "UTF-8");

        images = (HPDF_Image *)malloc((NUM_PDF_IMAGES+2) * sizeof(HPDF_Image));  // 2 == logo and footer
        if(images == NULL) {
            do_log(LOG_REPORTING, "", "reporting: ERROR no memory to load images");
            free_ldap_config(ldap_servers);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_NO_MEMORY_AVAILABLE;
        }
        for(i=0;i<NUM_PDF_IMAGES;i++) {
            images[i] = HPDF_LoadJpegImageFromFile (pdf, image_load_table[i]);
            if(images[i] == NULL) {
                do_log(LOG_REPORTING, "", "reporting: ERROR loading image %d %s", i, image_load_table[i]);
                free_ldap_config(ldap_servers);
                cleanup_config(reporting_cfg);
                return ERROR_REPORT_LOADING_IMAGES;
            }
        }
        if(logo != NULL) {
           if(strstr(logo, ".png"))
               images[NUM_PDF_IMAGES] = HPDF_LoadPngImageFromFile (pdf, logo);  
           else if((strstr(logo, ".jpg")) || (strstr(logo, ".jpeg")))
               images[NUM_PDF_IMAGES] = HPDF_LoadJpegImageFromFile (pdf, logo);  
        }
        if(footer != NULL) {
           bottom_margin = 80;
           if(strstr(footer, ".png"))
               images[NUM_PDF_IMAGES+1] = HPDF_LoadPngImageFromFile (pdf, footer);
           else if((strstr(footer, ".jpg")) || (strstr(footer, ".jpeg")))
               images[NUM_PDF_IMAGES+1] = HPDF_LoadJpegImageFromFile (pdf, footer);  
        }
        if(strcmp(gvalue,"")) lines_gvalue = 2;

        nFields = (num_cols < nFields_db ) ? num_cols : nFields_db;

        {   /* get dimensions */
            int numEvents = 0, free_events = -1, k, temp_col;
            char **events=NULL, **tmp_events=NULL, **subevents = NULL;
            remote_t remote;
            remote.remote_e164 = NULL;
            remote.remote_h323 = NULL;
            remote.remote_dn = NULL;
            remote.remote = NULL;

            index_cols = (int *)malloc(nFields * sizeof(int));
            ptr_index_cols = index_cols;
            for (j = 0; j < nFields; j++) {
                *ptr_index_cols++ = 0;
            }
            for (i = 0; i < nTuples; i++) {
                if(equal-- > 0) continue;

                ptr_strings->tmpDir = NULL;
                ptr_strings->type = NULL;
                ptr_strings->state = ptr_strings->er;
                cause = ((callCauseIndex == -1) ? 0 : atoi(PQgetvalue(res, i, callCauseIndex)));
                c_type = ((callTypeIndex == -1) ? 0 : !strcmp(PQgetvalue(res, i, callTypeIndex), "ext"));
                if(digits_to_hide > 0)
                    free_events = pg_array_parse_pdf(PQgetvalue(res, i, callFlowIndex), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, NULL, 0, digits_to_hide, anonym, PQgetvalue(res, i, callPbxIndex), PQgetvalue(res, i, callPhysIndex), ldap_servers);
                else 
                    free_events = pg_array_parse_pdf(PQgetvalue(res, i, callFlowIndex), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, NULL, 0, digits_to_hide, anonym, NULL, NULL, ldap_servers);
                if((free_events == -1) || (numEvents >= MAX_NUM_EVENTS)) {
                    do_log(LOG_REPORTING, "", "reporting: unable to calculate dimensions: %d %d", free_events, numEvents);
                    free(images);
                    free(index_cols);
                    free_ldap_config(ldap_servers);
                    cleanup_config(reporting_cfg);
                    return ERROR_REPORT_CALCULATE_DIM;
                }

                /* Object column */
                if(!anonym) {
                    elemTmp = PQgetvalue(res, i, callCCnIndex);
                    check_w = HPDF_Font_TextWidth(font,(unsigned char *)elemTmp,strlen(elemTmp));
                    x = ((check_w.width << 3) / 1000);
                    temp_col = (x > obj_length) ? x : obj_length;
                    obj_length = temp_col;
                }

                /* Left and Right column */
                tmp_events = events;
                for(k=0; k<numEvents;k++) {
                    elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+EP1_PDF);
                    if(elemTmp != NULL) {
                        check_w = HPDF_Font_TextWidth(font,(unsigned char *)elemTmp,strlen(elemTmp));
                        x = ((check_w.width << 3) / 1000);
                        temp_col = (x > left_length) ? x : left_length;
                        left_length = temp_col;
                    }

                    elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+EP2_PDF);
                    if(elemTmp != NULL) {
                        check_w = HPDF_Font_TextWidth(font,(unsigned char *)elemTmp,strlen(elemTmp));
                        x = ((check_w.width << 3) / 1000);
                        temp_col = (x > right_length) ? x : right_length;
                        right_length = temp_col;
                    }
                }

                if(free_events != -1) {
                    if(events) free(events);
                    free_allocated_mem(&subevents, free_events, CALL_FLOW_INDEXES_PDF, 0, FLAG_OK);
                }

                if(ptr_strings->tmpDir) {
                    if(ptr_strings->tmpDir == ptr_strings->ep1) {
                        num_calls_out++;
                        total_call_length_out += atoi(PQgetvalue(res, i, callDisplayedDuration));
                        total_alert_dur_out += atoi(PQgetvalue(res, i, callAlertIndex));
                    } else {
                        num_calls_in++;
                        total_call_length_in += atoi(PQgetvalue(res, i, callDisplayedDuration));
                        total_alert_dur_in += atoi(PQgetvalue(res, i, callAlertIndex));
                    }
                }

                if(i<(nTuples-1)) {
                    int i_rows = 0, tmp_equal;
                    equal = 0;
                    do {
                        i_rows++;
                        tmp_equal = (!strcmp(PQgetvalue(res, i, callConfIndex),PQgetvalue(res, i+i_rows, callConfIndex)) &&
                                     !strcmp(PQgetvalue(res, i, callCCnIndex),PQgetvalue(res, i+i_rows, callCCnIndex)) && 
                                     !strcmp(PQgetvalue(res, i, callDirectionIndex),PQgetvalue(res, i+i_rows, callDirectionIndex)) && 
                                     (atoi(PQgetvalue(res, i+i_rows, callConnDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callConnDurIndex), PQgetvalue(res, i+i_rows, callConnDurIndex))) &&
                                     (atoi(PQgetvalue(res, i+i_rows, callCallDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callCallDurIndex), PQgetvalue(res, i+i_rows, callCallDurIndex))) );
                        equal += tmp_equal;
                    } while(tmp_equal && ((i+i_rows)<(nTuples-1)));
                }

                if(remote.remote_e164 != NULL) {
                    free(remote.remote_e164);
                    remote.remote_e164 = NULL;
                }
                if(remote.remote_h323 != NULL) {
                    free(remote.remote_h323);
                    remote.remote_h323 = NULL;
                }
                if(remote.remote_dn != NULL) {
                    free(remote.remote_dn);
                    remote.remote_dn = NULL;
                }
                if(remote.remote != NULL) { 
                    free(remote.remote);
                    remote.remote = NULL;
                }
                total_number_lines += numEvents + lines_gvalue;
            }
            obj_length += 8;
            left_length += 8;
            right_length += 8;
        }

        sprintf(tot_calls_io,"%d / %d",num_calls_in, num_calls_out); 
        sec2hms(total_call_length_in, tot_duration_io, 1);
        strcat(tot_duration_io, " / ");
        sec2hms(total_call_length_out, &tot_duration_io[strlen(tot_duration_io)], 1);
        
        sec2hms(total_alert_dur_in, tot_alert_io, 1);
        strcat(tot_alert_io, " / ");
        sec2hms(total_alert_dur_out, &tot_alert_io[strlen(tot_alert_io)], 1);
        
        if(!strcmp(gvalue, xml_lookup_table[TIME_COL])) {
            time_length = 50;
        } else {
            time_length = 80;    // 0000-00-00 00:00:00
        }

        font = HPDF_GetFont (pdf, fontname_bold, "UTF-8");
        check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[txt_displayed_duration_index].lang[lang],strlen(process_string_table[txt_displayed_duration_index].lang[lang]));
        dur_length = (check_w.width << 3)/1000+5;
        check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[TXT_ALERT_DURATION].lang[lang],strlen(process_string_table[TXT_ALERT_DURATION].lang[lang]));
        alert_length = (check_w.width << 3)/1000-15;
        font = HPDF_GetFont (pdf, fontname, "UTF-8");
        
        if(!strcmp(gvalue, xml_lookup_table[CN_COL])) {
            total_line_sep = time_length + dur_length + alert_length + left_length + left_icon_length + dir_icon_length + state_icon_length + right_length + right_icon_length;
        } else {
            total_line_sep = time_length + obj_length + dur_length + alert_length + left_length + left_icon_length + dir_icon_length + state_icon_length + right_length + right_icon_length;
        }

        if( total_line_sep > (DIMA4_WIDTH-(LEFT_MARGIN<<1)) ) {
            /* Landscape */
            pdf_width = DIMA4_HEIGHT;
            pdf_height = DIMA4_WIDTH;
            max_num_pages = (total_number_lines / 20);
            if(total_line_sep > (pdf_width-(LEFT_MARGIN<<1))) {
                total_line_sep -= (left_length+right_length+obj_length);
                if(!strcmp(gvalue,"") || !strcmp(gvalue, xml_lookup_table[TIME_COL])) {
                    max_length_chars = 170;
                    max_num_chars = 41;
                    if(obj_length > max_length_chars) {
                        obj_length = max_length_chars; 
                        check_obj_length = 1;
                    }
                }
                if(left_length > max_length_chars) {
                    left_length = max_length_chars; 
                    check_left_length = 1;
                }
                if(right_length > max_length_chars) {
                    right_length = max_length_chars; 
                    check_right_length = 1;
                }
                total_line_sep += (left_length+right_length+obj_length);
            }
            x_logo = 850;
        } else {
            max_num_pages = (total_number_lines / 25);
            x_logo = 550;
        }
        x_footer = (pdf_width-footer_width_len)>>1;

        pages = (HPDF_Page *)malloc(max_num_pages * sizeof(HPDF_Page));
        ptr_page = pages;
        if(pages == NULL) {
            do_log(LOG_REPORTING, "", "reporting: no memory available");
            free(images);
            free(index_cols);
            free_ldap_config(ldap_servers);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_NO_MEMORY_AVAILABLE;
        }

        /* add a new page object. */
        *ptr_page = HPDF_AddPage (pdf);
        HPDF_Page_SetLineWidth (*ptr_page, 0);
        HPDF_Page_SetWidth (*ptr_page, pdf_width);
        HPDF_Page_SetHeight (*ptr_page, pdf_height);
        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
        HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
        HPDF_Page_SetLineWidth (*ptr_page, 0);

        y = pdf_height - TOP_MARGIN;
        x = LEFT_MARGIN+5;
        font = HPDF_GetFont (pdf, fontname_bold, "UTF-8");
        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);

        if(logo) {
            HPDF_Page_DrawImage(*ptr_page, images[NUM_PDF_IMAGES], x_logo, y - 15, 32, 32);
        }
        if(footer) {
            HPDF_Page_DrawImage(*ptr_page, images[NUM_PDF_IMAGES+1], x_footer, 5, footer_width_len, 50);
        }
 
        sprintf(num_page, "%d", num_pages);
        HPDF_Page_BeginText (*ptr_page);
        HPDF_Page_MoveTextPos (*ptr_page, 8, 5);
        HPDF_Page_ShowText (*ptr_page, num_page);
        HPDF_Page_EndText (*ptr_page);
        num_pages++;

        HPDF_Page_BeginText (*ptr_page);
        HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
        HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SUMMARY_IO].lang[lang]);
        HPDF_Page_EndText (*ptr_page);
        font = HPDF_GetFont (pdf, fontname, "UTF-8");
        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
            
        if(!internal && !filter_info) {
            rect.left = LEFT_MARGIN;
            rect.top = y-LINE_SPACING;
            rect.right = 285;
            rect.bottom = rect.top - LINE_SPACING*2 - 10;

            HPDF_Page_Rectangle (*ptr_page, rect.left, rect.bottom, rect.right - rect.left, rect.top - rect.bottom);
            HPDF_Page_Stroke (*ptr_page);
            x = LEFT_MARGIN+5;
            y -= LINE_SPACING;
        }
        else {
            if(strlen(filters_name) > strlen(filter_name))
                check_w = HPDF_Font_TextWidth(font, (unsigned char *)filters_name, strlen(filters_name));
            else
                check_w = HPDF_Font_TextWidth(font, (unsigned char *)filter_name, strlen(filter_name));
            rect.left = LEFT_MARGIN;
            rect.top = y-LINE_SPACING;
            rect.right = MIN(total_line_sep, (110 + MAX(50, ((check_w.width << 3) / 1000))));
            // minimum length for summary
            if(rect.right < 285)
                rect.right = 285;
            if(nTuples > 0)
                rect.bottom = rect.top - LINE_SPACING*3 - 135;
            else
                rect.bottom = rect.top - 151;

            y -= LINE_SPACING;
            x = LEFT_MARGIN+5;
            HPDF_Page_Rectangle (*ptr_page, rect.left, rect.bottom, rect.right - rect.left, rect.top - rect.bottom);
            HPDF_Page_Stroke (*ptr_page);
        }
        if(nTuples > 0) {
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SUMMARY_CALLS_IO].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=160;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, tot_calls_io);
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SUMMARY_DURATION_IO].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=160;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, tot_duration_io);
            HPDF_Page_EndText (*ptr_page);

            y -= (LINE_SPACING-5);
            x = LEFT_MARGIN+5;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SUMMARY_ALERT_IO].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=160;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, tot_alert_io);
            HPDF_Page_EndText (*ptr_page);
        }
        if(internal || filter_info) {
            /* Name */
            if(nTuples > 0) {
                x = LEFT_MARGIN+5;
                y -= (LINE_SPACING-5);
            }
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_FILTER_NAME].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, filter_name);
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_FILTER_NAMES].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(check_w.width > 375) {
                char t_filter[70];
                memcpy(t_filter, filters_name, 66);
                t_filter[66] = 0x2e;
                t_filter[67] = 0x2e;
                t_filter[68] = 0x2e;
                t_filter[69] = 0x0;
                HPDF_Page_ShowText (*ptr_page, t_filter);
            }
            else {
                HPDF_Page_ShowText (*ptr_page, filters_name);
            }
            HPDF_Page_EndText (*ptr_page);
            
            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_PBX].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(pbx_object)
                HPDF_Page_ShowText (*ptr_page, pbx);
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_OBJECT_LONG_NAME].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(pbx_object)
                HPDF_Page_ShowText (*ptr_page, pbx_object);
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_DATE_FROM].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(from_date)
                HPDF_Page_ShowText (*ptr_page, from_date);
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_DATE_TO].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(to_date)
                HPDF_Page_ShowText (*ptr_page, to_date);
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_GROUP_BY].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(gvalue) {
                if(!strcmp(gvalue, "time"))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_DATE].lang[lang]);
                else if(!strcmp(gvalue, "obj"))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_OBJECT].lang[lang]);
                else
                    HPDF_Page_ShowText (*ptr_page, gvalue);
            }
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_DISPLAYED_DURATION].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[txt_displayed_duration_index].lang[lang]);
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SORT_BY].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(svalue) {
                if(!strcmp(svalue, column_lookup_table[TIME_COL]))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_TIME].lang[lang]);
                else if(!strcmp(svalue, column_lookup_table[CN_COL]))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_OBJECT].lang[lang]);
                else if(!strcmp(svalue, column_lookup_table[CALL_DUR_COL]))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_DURATION].lang[lang]);
                else if(!strcmp(svalue, column_lookup_table[CALL_CONN_COL]))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_CONN_DURATION].lang[lang]);
                else if(!strcmp(svalue, column_lookup_table[ALERT_COL]))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_ALERT_DURATION].lang[lang]);
                else if(!strcmp(svalue, column_lookup_table[CALL_BILLING_COL]))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_BILLING_DURATION].lang[lang]);
                else if(!strcmp(svalue, column_lookup_table[DIR_COL]))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_DIRECTION].lang[lang]);
                else
                    HPDF_Page_ShowText (*ptr_page, svalue);
            } 
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SORT_ORDER].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(order) {
                if(!strcmp(order, "ASC"))
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SORT_ASCENDING].lang[lang]);
                else
                    HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_SORT_DESCENDING].lang[lang]);
            }
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);

            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_HIDE_DIGITS].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(digits_to_hide) {
                char tdigits[4];
                sprintf(tdigits, "%d", digits_to_hide);
                HPDF_Page_ShowText (*ptr_page, tdigits);
            } 
            else
                HPDF_Page_ShowText (*ptr_page, "");
            HPDF_Page_EndText (*ptr_page);
            
            x = LEFT_MARGIN+5;
            y -= (LINE_SPACING-5);
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_ANONYM].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            x+=80;
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(anonym) {
                HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_YES].lang[lang]);
            } 
            else
                HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_NO].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
        }
        
        font = HPDF_GetFont (pdf, fontname_bold, "UTF-8");
        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
        if(nTuples == 0) {
            HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
            HPDF_Page_SetLineWidth (*ptr_page, 0);

            y -= (LINE_SPACING+10);
            x = LEFT_MARGIN+5;

            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_NO_RECORDS].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
        }
        else {
            y -= (LINE_SPACING+10);
            x = LEFT_MARGIN;

            HPDF_Page_SetLineWidth (*ptr_page, 2);
            HPDF_Page_MoveTo (*ptr_page, x, y - 20);
            HPDF_Page_LineTo (*ptr_page, x + total_line_sep, y - 20);
            HPDF_Page_Stroke (*ptr_page);

            /* Title */
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_TIME].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[TXT_TIME].lang[lang],strlen(process_string_table[TXT_TIME].lang[lang]));
            x += time_length;

            if(!anonym && strcmp(gvalue, xml_lookup_table[CN_COL])) {
                HPDF_Page_BeginText (*ptr_page);
                HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_OBJECT].lang[lang]);
                HPDF_Page_EndText (*ptr_page);
                check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[TXT_OBJECT].lang[lang],strlen(process_string_table[TXT_OBJECT].lang[lang]));
                x += obj_length;
            }

            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[txt_displayed_duration_index].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[txt_displayed_duration_index].lang[lang],strlen(process_string_table[txt_displayed_duration_index].lang[lang]));
            x += dur_length;
            
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_ALERT_DURATION].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[TXT_ALERT_DURATION].lang[lang],strlen(process_string_table[TXT_ALERT_DURATION].lang[lang]));
            x += alert_length;
            
            x += left_icon_length;

            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_LEFT].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[TXT_LEFT].lang[lang],strlen(process_string_table[TXT_LEFT].lang[lang]));
            x += left_length;

            HPDF_Page_DrawImage(*ptr_page,images[DUMMY], x, y - 16, 14, 14);
            x += dir_icon_length;

            HPDF_Page_DrawImage(*ptr_page,images[STATE], x, y - 16, 14, 14);
            x += state_icon_length;

            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            HPDF_Page_ShowText (*ptr_page, process_string_table[TXT_RIGHT].lang[lang]);
            HPDF_Page_EndText (*ptr_page);
            check_w = HPDF_Font_TextWidth(font,(unsigned char *)process_string_table[TXT_RIGHT].lang[lang],strlen(process_string_table[TXT_RIGHT].lang[lang]));
            x += right_length;
            x += right_icon_length;
            /* End of Title */

            y -= (LINE_SPACING+4);  // First Line
            x = LEFT_MARGIN;

            HPDF_Page_SetLineWidth (*ptr_page, 0);
            HPDF_Page_SetRGBFill (*ptr_page, 0.0, 0.0, 0.0);
            HPDF_Page_SetRGBStroke (*ptr_page, 0.0, 0.0, 0.0);
            if(strcmp(gvalue, "")) {
                last_group_by = (char *)malloc(256*sizeof(char));
                if(last_group_by == NULL) {
                    do_log(LOG_REPORTING, "", "reporting: cannot create PdfDoc object");
                    free(images);
                    free(index_cols);
                    free(pages);
                    HPDF_Free (pdf);
                    free_ldap_config(ldap_servers);
                    cleanup_config(reporting_cfg);
                    return ERROR_REPORT_CREATING_PDF_OBJECT;
                } else {
                    memset(last_group_by,0x0,256*sizeof(char));
                }
            }
        }

        font = HPDF_GetFont (pdf, fontname, "UTF-8");
        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
        for (i = 0, ind = 0; i < nTuples; i++)
        {
            int numEvents, free_events, k, x_call_flow = 0, is_callback = 0;
            char **events=NULL, **tmp_events=NULL, **subevents = NULL;
            remote_t remote;
            remote.remote_e164 = NULL;
            remote.remote_h323 = NULL;
            remote.remote_dn = NULL;
            remote.remote = NULL;
            char *group_value;
            char *cb_e164 = NULL, *cb_h323 = NULL, *cb_dn = NULL;

            if(equal-- > 0) continue;

            if(strcmp(gvalue, "")) {
                group_value = PQgetvalue(res, i, groupByIndex);

                if(strcmp(last_group_by, group_value)) {
                    if(i>0) {
                        char grp_calls[32];
                        char grp_summary[512];

                        strcpy(grp_summary, process_string_table[TXT_INCOMING].lang[lang]);
                        strcat(grp_summary, " ");
                        sprintf(grp_calls,"%d",grp_calls_in);
                        strcat(grp_summary, grp_calls);
                        strcat(grp_summary, " ");
                        strcat(grp_summary, process_string_table[TXT_OUTGOING].lang[lang]);
                        strcat(grp_summary, " ");
                        sprintf(grp_calls,"%d",grp_calls_out);
                        strcat(grp_summary, grp_calls);
                        strcat(grp_summary, " ");
                        strcat(grp_summary, process_string_table[txt_displayed_duration_index].lang[lang]);
                        strcat(grp_summary, " ");
                        sec2hms(grp_conn_duration, time_formatted, 1);
                        strcat(grp_summary, time_formatted);
                        
                        strcat(grp_summary, " ");
                        strcat(grp_summary, process_string_table[TXT_ALERT_DURATION].lang[lang]);
                        strcat(grp_summary, " ");
                        sec2hms(grp_alert_duration, time_formatted, 1);
                        strcat(grp_summary, time_formatted);
                        
                        font = HPDF_GetFont (pdf, fontname_bold, "UTF-8");
                        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
                        check_w = HPDF_Font_TextWidth(font,(unsigned char *)grp_summary,strlen(grp_summary));

                        HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
                        HPDF_Page_SetLineWidth (*ptr_page, 0);
                        HPDF_Page_MoveTo (*ptr_page, x+(total_line_sep-((check_w.width<<3)/1000)), y-2);
                        HPDF_Page_LineTo (*ptr_page, x+total_line_sep , y-2);
                        HPDF_Page_Stroke (*ptr_page);

                        HPDF_Page_BeginText (*ptr_page);
                        HPDF_Page_MoveTextPos(*ptr_page, x+(total_line_sep-((check_w.width<<3)/1000)), y - 12);
                        HPDF_Page_ShowText (*ptr_page, grp_summary);
                        HPDF_Page_EndText (*ptr_page);
                        font = HPDF_GetFont (pdf, fontname, "UTF-8");
                        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
                        y -= 18;
                    }
                    grp_alert_duration = grp_conn_duration = grp_calls_in = grp_calls_out = 0;

                    if(set_first_line) {
                        HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
                        HPDF_Page_SetLineWidth (*ptr_page, 2);
                        HPDF_Page_MoveTo (*ptr_page, x, y-1);
                        HPDF_Page_LineTo (*ptr_page, x + total_line_sep, y-1);
                        HPDF_Page_Stroke (*ptr_page);
                        y -= 1;
                    }
                    set_first_line = 1;

                    font = HPDF_GetFont (pdf, fontname_bold, "UTF-8");
                    HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
                    HPDF_Page_BeginText (*ptr_page);
                    HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                    if(anonym && !strcmp(gvalue, xml_lookup_table[CN_COL]))
                        HPDF_Page_ShowText (*ptr_page, "*");
                    else
                        HPDF_Page_ShowText (*ptr_page, group_value);
                    HPDF_Page_EndText (*ptr_page);
                    font = HPDF_GetFont (pdf, fontname, "UTF-8");
                    HPDF_Page_SetFontAndSize (*ptr_page, font, 8);

                    if(y <= bottom_margin) {
                        ptr_page++;
                        *ptr_page = HPDF_AddPage (pdf);
                        HPDF_Page_SetLineWidth (*ptr_page, 0);
                        HPDF_Page_SetWidth (*ptr_page, pdf_width);
                        HPDF_Page_SetHeight (*ptr_page, pdf_height);
                        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
    
                        y = pdf_height-TOP_MARGIN;
                        ind++;
                        if(ind > max_num_pages) {
                            do_log(LOG_REPORTING, "", "reporting: not enough pages allocated: %d-%d!", ind, max_num_pages);
                            break;
                        }
                        if(logo) {
                            HPDF_Page_DrawImage(*ptr_page, images[NUM_PDF_IMAGES], x_logo, y - 15, 32, 32);
                        }
                        if(footer) {
                            HPDF_Page_DrawImage(*ptr_page, images[NUM_PDF_IMAGES+1], x_footer, 5, footer_width_len, 50);
                        }
                        sprintf(num_page, "%d", num_pages);
                        HPDF_Page_BeginText (*ptr_page);
                        HPDF_Page_MoveTextPos (*ptr_page, 8, 5);
                        HPDF_Page_ShowText (*ptr_page, num_page);
                        HPDF_Page_EndText (*ptr_page);
                        num_pages++;
                    } else {
                       y -= LINE_SPACING;
                       HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
                       HPDF_Page_SetLineWidth (*ptr_page, 0);
                       HPDF_Page_MoveTo (*ptr_page, x, y+1);
                       HPDF_Page_LineTo (*ptr_page, x + total_line_sep, y+1);
                       HPDF_Page_Stroke (*ptr_page);
                    }
                    strcpy(last_group_by, group_value);
                } else {
                    if(!added_new_page) {
                        HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
                        HPDF_Page_SetLineWidth (*ptr_page, 0);
                        HPDF_Page_MoveTo (*ptr_page, x, y);
                        HPDF_Page_LineTo (*ptr_page, x + total_line_sep, y);
                        HPDF_Page_Stroke (*ptr_page);
                    }  
                }
            } else {
                j = 0;
                if((!added_new_page) && (set_first_line)) {
                    HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
                    HPDF_Page_SetLineWidth (*ptr_page, 0);
                    HPDF_Page_MoveTo (*ptr_page, x, y);
                    HPDF_Page_LineTo (*ptr_page, x + total_line_sep, y);
                    HPDF_Page_Stroke (*ptr_page);
                }
                set_first_line = 1;
            }
            added_new_page = 0;

            ptr_strings->tmpDir = NULL;
            ptr_strings->type = NULL;
            ptr_strings->state = ptr_strings->er;
            cause = ((callCauseIndex == -1) ? 0 : atoi(PQgetvalue(res, i, callCauseIndex)));
            c_type = ((callTypeIndex == -1) ? 0 : !strcmp(PQgetvalue(res, i, callTypeIndex), "ext"));
            cb_e164 = PQgetvalue(res, i, callCbE164Index);
            cb_h323 = PQgetvalue(res, i, callCbH323Index);
            cb_dn = PQgetvalue(res, i, callCbDnIndex);
            if(*cb_e164 || *cb_h323 || *cb_dn) is_callback = 1;
            if(digits_to_hide)
                free_events = pg_array_parse_pdf(PQgetvalue(res, i, callFlowIndex), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, NULL, is_callback, digits_to_hide, anonym, PQgetvalue(res, i, callPbxIndex), PQgetvalue(res, i, callPhysIndex), ldap_servers);
            else 
                free_events = pg_array_parse_pdf(PQgetvalue(res, i, callFlowIndex), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, NULL, is_callback, digits_to_hide, anonym, NULL, NULL, ldap_servers);
            if((free_events == -1) || (numEvents >= MAX_NUM_EVENTS)) {
                do_log(LOG_REPORTING, "", "reporting: unable to calculate dimensions: %d %d", free_events, numEvents);
                free(images);
                free(index_cols);
                free(pages);
                HPDF_Free (pdf);
                free_ldap_config(ldap_servers);
                cleanup_config(reporting_cfg);
                return ERROR_REPORT_CALCULATE_DIM;
            }

            /* Time */
            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
            if(!strcmp(gvalue, xml_lookup_table[TIME_COL])) 
                HPDF_Page_ShowText (*ptr_page, PQgetvalue(res, i, callTimeShortIndex));
            else
                HPDF_Page_ShowText (*ptr_page, PQgetvalue(res, i, callTimeIndex));
            HPDF_Page_EndText (*ptr_page);
            x += time_length;

            /* Object */
            if(!anonym && strcmp(gvalue, xml_lookup_table[CN_COL])) {
                HPDF_Page_BeginText (*ptr_page);
                HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                elemTmp = PQgetvalue(res, i, callCCnIndex);
                if(check_obj_length) {
                    char tmp_ep1[64];

                    strncpy(tmp_ep1, elemTmp, max_num_chars);    // max_num_chars is the maximun number of chars for max_length_chars width
                    tmp_ep1[max_num_chars] = '\0';
                    HPDF_Page_ShowText (*ptr_page, tmp_ep1);
                } else
                    HPDF_Page_ShowText (*ptr_page, elemTmp);
                HPDF_Page_EndText (*ptr_page);
                x += obj_length;
            }

            /* Duration */
            grp_conn_duration += atoi(PQgetvalue(res, i, callDisplayedDuration));
            if(sec2hms(atoi(PQgetvalue(res, i, callDisplayedDuration)),time_formatted,0)) {
                HPDF_Page_BeginText (*ptr_page);
                HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                HPDF_Page_ShowText (*ptr_page, time_formatted);
                HPDF_Page_EndText (*ptr_page);
            } else {
                HPDF_Page_BeginText (*ptr_page);
                HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                HPDF_Page_ShowText (*ptr_page, "0:00");
                HPDF_Page_EndText (*ptr_page);
            }
            x += dur_length;
            
            /* Alert Duration */
            grp_alert_duration += atoi(PQgetvalue(res, i, callAlertIndex));
            if(sec2hms(atoi(PQgetvalue(res, i, callAlertIndex)),time_formatted,0)) {
                HPDF_Page_BeginText (*ptr_page);
                HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                HPDF_Page_ShowText (*ptr_page, time_formatted);
                HPDF_Page_EndText (*ptr_page);
            } else {
                HPDF_Page_BeginText (*ptr_page);
                HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                HPDF_Page_ShowText (*ptr_page, "0:00");
                HPDF_Page_EndText (*ptr_page);
            }
            x += alert_length;

            /* Left and Right column */
            tmp_events = events;
            x_call_flow = x;
            for(k=0; k<numEvents;k++) {
                elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+EP1_PDF_IMG);
                if(elemTmp != NULL) {
                    HPDF_Page_DrawImage(*ptr_page, images[lookup_image(elemTmp)], x, y - 15, 14, 14);
                }
                x += left_icon_length;
                elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+EP1_PDF);
                if(elemTmp != NULL) {
                    HPDF_Page_BeginText (*ptr_page);
                    HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                    if(check_left_length) {
                        char tmp_ep1[64];

                        strncpy(tmp_ep1, elemTmp, max_num_chars);    // max_num_chars is the maximun number of chars for max_length_chars width
                        tmp_ep1[max_num_chars] = '\0';
                        HPDF_Page_ShowText (*ptr_page, tmp_ep1);
                    } else
                        HPDF_Page_ShowText (*ptr_page, elemTmp);
                    HPDF_Page_EndText (*ptr_page);
                }
                x += left_length;
                elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+CALLER_PDF_IMG);
                if(elemTmp != NULL) {
                    if(lookup_image(elemTmp) == DIR_IN) grp_calls_in++;
                    else if(lookup_image(elemTmp) == DIR_OUT) grp_calls_out++;
                    HPDF_Page_DrawImage(*ptr_page, images[lookup_image(elemTmp)], x, y - 15, 14, 14);
                }
                x += dir_icon_length;
                elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+STATUS_PDF_IMG);
                if(elemTmp != NULL) {
                    HPDF_Page_DrawImage(*ptr_page, images[lookup_image(elemTmp)], x, y - 15, 14, 14);
                }
                x += state_icon_length;
                elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+EP2_PDF);
                if(elemTmp != NULL) {
                    HPDF_Page_BeginText (*ptr_page);
                    HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                    if(check_right_length) {
                        char tmp_ep1[64];

                        strncpy(tmp_ep1, elemTmp, max_num_chars);    // max_num_chars is the maximun number of chars for max_length_chars width
                        tmp_ep1[max_num_chars] = '\0';
                        HPDF_Page_ShowText (*ptr_page, tmp_ep1);
                    } else
                        HPDF_Page_ShowText (*ptr_page, elemTmp);
                    HPDF_Page_EndText (*ptr_page);
                } else if(numEvents == 1) {
                    HPDF_Page_BeginText (*ptr_page);
                    HPDF_Page_MoveTextPos (*ptr_page, x, y - 12);
                    HPDF_Page_ShowText (*ptr_page, "(N/A)");
                    HPDF_Page_EndText (*ptr_page);
                }
                x += right_length;
                elemTmp = *(tmp_events+k*PDF_EVENTS_ATTRIB+EP2_PDF_IMG);
                if(elemTmp != NULL) {
                    HPDF_Page_DrawImage(*ptr_page, images[lookup_image(elemTmp)], x, y - 15, 14, 14);
                }
                x += right_icon_length;

                /* new page? */
                if(y <= bottom_margin) {
                    // Avoid empty page if we process last entry and last event
                    if((i<(nTuples-1)) || (k<(numEvents-1))) {
                        ptr_page++;
                        *ptr_page = HPDF_AddPage (pdf);
                        HPDF_Page_SetLineWidth (*ptr_page, 0);
                        HPDF_Page_SetWidth (*ptr_page, pdf_width);
                        HPDF_Page_SetHeight (*ptr_page, pdf_height);
                        HPDF_Page_SetFontAndSize (*ptr_page, font, 8);

                        y = pdf_height-TOP_MARGIN;
                        ind++;
                        if(ind > max_num_pages) {
                            do_log(LOG_REPORTING, "", "reporting: not enough pages allocated: %d - %d!", ind, max_num_pages);
                            break;
                        }
                        if(logo) {
                            HPDF_Page_DrawImage(*ptr_page, images[NUM_PDF_IMAGES], x_logo, y - 15, 32, 32);
                        }
                        if(footer) {
                            HPDF_Page_DrawImage(*ptr_page, images[NUM_PDF_IMAGES+1], x_footer, 5, footer_width_len, 50);
                        }
                        sprintf(num_page, "%d", num_pages);
                        HPDF_Page_BeginText (*ptr_page);
                        HPDF_Page_MoveTextPos (*ptr_page, 8, 5);
                        HPDF_Page_ShowText (*ptr_page, num_page);
                        HPDF_Page_EndText (*ptr_page);
                        num_pages++;
                    }
                } else {
                    y -= LINE_SPACING;
                }
                x = x_call_flow;
            }
            if(free_events != -1) {
                if(events) free(events);
                free_allocated_mem(&subevents, free_events, CALL_FLOW_INDEXES_PDF, 0, FLAG_OK);
            }

            x = LEFT_MARGIN;

            if(i<(nTuples-1)) {
                int i_rows = 0, tmp_equal;
                equal = 0;
                do {
                    i_rows++;
                    tmp_equal = (!strcmp(PQgetvalue(res, i, callConfIndex),PQgetvalue(res, i+i_rows, callConfIndex)) &&
                                 !strcmp(PQgetvalue(res, i, callCCnIndex),PQgetvalue(res, i+i_rows, callCCnIndex)) &&
                                 !strcmp(PQgetvalue(res, i, callDirectionIndex),PQgetvalue(res, i+i_rows, callDirectionIndex)) &&
                                 (atoi(PQgetvalue(res, i+i_rows, callConnDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callConnDurIndex), PQgetvalue(res, i+i_rows, callConnDurIndex))) &&
                                 (atoi(PQgetvalue(res, i+i_rows, callCallDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callCallDurIndex), PQgetvalue(res, i+i_rows, callCallDurIndex))) );
                    equal += tmp_equal;
                } while(tmp_equal && ((i+i_rows)<(nTuples-1)));
            }
            if(remote.remote_e164 != NULL) {
                free(remote.remote_e164);
                remote.remote_e164 = NULL;
            }
            if(remote.remote_h323 != NULL) {
                free(remote.remote_h323);
                remote.remote_h323 = NULL;
            }
            if(remote.remote_dn != NULL) {
                free(remote.remote_dn);
                remote.remote_dn = NULL;
            }
            if(remote.remote != NULL) {
                free(remote.remote);
                remote.remote = NULL;
            }
        }
        if(strcmp(gvalue, "")) {
            char grp_calls[32];
            char grp_summary[512];

            strcpy(grp_summary, process_string_table[TXT_INCOMING].lang[lang]);
            strcat(grp_summary, " ");
            sprintf(grp_calls,"%d",grp_calls_in);
            strcat(grp_summary, grp_calls);
            strcat(grp_summary, " ");
            strcat(grp_summary, process_string_table[TXT_OUTGOING].lang[lang]);
            strcat(grp_summary, " ");
            sprintf(grp_calls,"%d",grp_calls_out);
            strcat(grp_summary, grp_calls);
            strcat(grp_summary, " ");
            strcat(grp_summary, process_string_table[txt_displayed_duration_index].lang[lang]);
            strcat(grp_summary, " ");
            sec2hms(grp_conn_duration, time_formatted,1);
            strcat(grp_summary, time_formatted);
            strcat(grp_summary, " ");
            strcat(grp_summary, process_string_table[TXT_ALERT_DURATION].lang[lang]);
            strcat(grp_summary, " ");
            sec2hms(grp_alert_duration, time_formatted,1);
            strcat(grp_summary, time_formatted);
            
            font = HPDF_GetFont (pdf, fontname_bold, "UTF-8");
            HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
            check_w = HPDF_Font_TextWidth(font,(unsigned char *)grp_summary,strlen(grp_summary));

            HPDF_Page_SetRGBStroke (*ptr_page, 0.50, 0.50, 0.50);
            HPDF_Page_SetLineWidth (*ptr_page, 0);
            HPDF_Page_MoveTo (*ptr_page, x+(total_line_sep-((check_w.width<<3)/1000)), y-2);
            HPDF_Page_LineTo (*ptr_page, x+total_line_sep , y-2);
            HPDF_Page_Stroke (*ptr_page);

            HPDF_Page_BeginText (*ptr_page);
            HPDF_Page_MoveTextPos(*ptr_page, x+(total_line_sep-((check_w.width<<3)/1000)), y - 12);
            HPDF_Page_ShowText (*ptr_page, grp_summary);
            HPDF_Page_EndText (*ptr_page);
            font = HPDF_GetFont (pdf, fontname, "UTF-8");
            HPDF_Page_SetFontAndSize (*ptr_page, font, 8);
        }

        /* save the document to a file */
        HPDF_SaveToFile (pdf, file_name);
        /* clean up */
        HPDF_Free (pdf);
        if(!internal) {
            f = fopen(file_name, "r");
            if(f) {
                fseek(f, 0L, SEEK_END);
                file_len = ftell(f);
                fseek(f, 0L, SEEK_SET);
                *bytes_sent = FCGX_PutS(CONTENT_TYPE_PDF, cgi->out);
                *output_len += strlen(CONTENT_TYPE_PDF);
                *bytes_sent += FCGX_PutS(CONTENT_LENGTH, cgi->out);
                *output_len += strlen(CONTENT_LENGTH);
                sprintf(file_len_str, "%d\r\n", file_len);
                *bytes_sent += FCGX_PutS(file_len_str, cgi->out);
                *output_len += strlen(file_len_str);
                *bytes_sent += FCGX_PutS(CONTENT_DISPOS, cgi->out);
                *output_len += strlen(CONTENT_DISPOS);
                *bytes_sent += FCGX_PutS("report.pdf", cgi->out);
                *output_len += strlen("report.pdf");
                *bytes_sent += FCGX_PutS("\r\n\r\n", cgi->out);
                *output_len += strlen("\r\n\r\n");
                while(!feof(f)) {
                    file_read_len = fread(file_read, 1, sizeof(file_read), f);
                    *bytes_sent += FCGX_PutStr(file_read, file_read_len, cgi->out);
                    *output_len += file_read_len;
                }
                fclose(f);
            }
	    }      
        if(last_group_by) free(last_group_by);
        if(pages) free(pages);
        if(index_cols) free(index_cols);
        if(images) free(images);
    } else if(!strcmp(format, "csv")) {
        f=fopen(file_name,"w+");
        if(f==NULL) {
            if(href != NULL) free(href);
            if(query != NULL) free(query);
            if(conninfo != NULL) free(conninfo);
            if(format != NULL) free(format);
            if(file_name != NULL) free(file_name);
            if(server != NULL) free(server);
            if(order != NULL) free(order);
            if(svalue != NULL) free(svalue);
            if(gvalue != NULL) free(gvalue);
            if(logo != NULL) free(logo);
            if(logo_width != NULL) free(logo_width);
            if(footer != NULL) free(footer);
            if(footer_width != NULL) free(footer_width);
            if(cn != NULL) free(cn);
            if(usergroup != NULL) free(usergroup);
            if(userpbx != NULL) free(userpbx);
            if(filter_name != NULL) free(filter_name);
            if(filters_name != NULL) free(filters_name);
            if(pbx_object != NULL) free(pbx_object);
            if(pbx != NULL) free(pbx);
            if(from_date != NULL) free(from_date);
            if(to_date != NULL) free(to_date);
            if(lang_str != NULL) free(lang_str);
            if(displayed_duration != NULL) free(displayed_duration);
            tmp_columns = columns;
            for(i=0;i<num_cols;i++) {
                if(*tmp_columns != NULL) free(*tmp_columns);
                tmp_columns++;
            }
            free(columns);
            free(ind_columns);
            do_log(LOG_REPORTING, "", "reporting: ERROR opening file '%s'", file_name);
            free_ldap_config(ldap_servers);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_OPENING_ZIP_FILE;
        }

        csv_out = (char *)malloc(8192*sizeof(char));
        if(csv_out == NULL) {
            do_log(LOG_REPORTING, "", "reporting: ERROR no memory available");
            if(f) fclose(f);
            free_ldap_config(ldap_servers);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_NO_MEMORY_AVAILABLE;
        }

        // Use translations
        strcpy(csv_out, "");
        strcat_xml(csv_out, process_string_table[TXT_TIME].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_OBJECT].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_OBJECT_INFO].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_CONFERENCE_ID].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_CALL].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_ALERT_DURATION].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_CALL_DURATION].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_BILLING_DURATION].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_CONN_DURATION].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_SYSTEM_NAME].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_NODE].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_PBX].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, "Phys");
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_CAUSE].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_DIRECTION].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_STATUS].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_TYPE].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_REMOTE_PARTY].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_ORIGINAL_CALLED].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_DIVERTING].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_TRANSFERRING].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_FURTHER_REG].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_DATE].lang[lang]);
        strcat(csv_out, ";");
        strcat_xml(csv_out, process_string_table[TXT_TIME].lang[lang]);
        strcat(csv_out, "_2");  // second time col, short time
        strcat(csv_out, "\r\n");

        csv_out_len = strlen(csv_out);
        fwrite(csv_out, 1, csv_out_len, f);

    	nFields = (num_cols < nFields_db ) ? num_cols : nFields_db;
        for(i=0; i<nTuples; i++) {
            int free_events = -1, numEvents = 0;
            char **events = NULL, **subevents = NULL;
            remote_t remote;
            remote.remote_e164 = NULL;
            remote.remote_h323 = NULL;
            remote.remote_dn = NULL;
            remote.remote = NULL;
            csv_infos_t csv;
            csv.object_called = NULL;
            csv.diverting = NULL;
            csv.transferring = NULL;
            csv.object_info = NULL;
            char *tmp_val;

            ptr_strings->type = NULL;
            ptr_strings->tmpDir = NULL;
            ptr_strings->state = ptr_strings->er;
            cause = ((callCauseIndex == -1) ? 0 : atoi(PQgetvalue(res, i, callCauseIndex)));
            c_type = ((callTypeIndex == -1) ? 0 : !strcmp(PQgetvalue(res, i, callTypeIndex), "ext"));
            if(digits_to_hide > 0) {
                free_events = pg_array_parse_pdf(PQgetvalue(res, i, callFlowIndex), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, &csv, 0, digits_to_hide, anonym, PQgetvalue(res, i, callPbxIndex), PQgetvalue(res, i, callPhysIndex), ldap_servers);
            }
            else {
                free_events = pg_array_parse_pdf(PQgetvalue(res, i, callFlowIndex), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, &csv, 0, digits_to_hide, anonym, NULL, NULL, ldap_servers);
            }

            // Time
            strcpy(csv_out, PQgetvalue(res, i, callTimeIndex));
            strcat(csv_out, ";");
            // Object
            // Escape commas
            strcat(csv_out, "\"");
            tmp_val = PQgetvalue(res, i, callCCnIndex);
            if(strchr(tmp_val, '"')) {
                int search_len = strlen(tmp_val);
                char *new_string = (char *)malloc((search_len<<1)+1);
                char *p, *old;
                
                memset(new_string, 0x0, (search_len<<1)+1);
                old = tmp_val;
                for(p=strchr(tmp_val, '"'); p!=NULL; p=strchr(old, '"')) {
                    strncpy(new_string+strlen(new_string), old, p-old+1);  // +1, Copy " too
                    strcat(new_string, "\"");
                    old = p+1;
                }
                strcpy(new_string+strlen(new_string), old);
                strcat(csv_out, new_string);
                free(new_string);
            }
            else            
                strcat(csv_out, tmp_val);
            strcat(csv_out, "\"");
            strcat(csv_out, ";");
            // Object info
            strcat(csv_out, "\"");
            if(csv.object_info) {
                tmp_val = csv.object_info;
                if(strchr(csv.object_info, '"')) {
                    int search_len = strlen(tmp_val);
                    char *new_string = (char *)malloc((search_len<<1)+1);
                    char *p, *old;

                    memset(new_string, 0x0, (search_len<<1)+1);
                    old = tmp_val;
                    for(p=strchr(tmp_val, '"'); p!=NULL; p=strchr(old, '"')) {
                        strncpy(new_string+strlen(new_string), old, p-old+1);  // +1, Copy " too
                        strcat(new_string, "\"");
                        old = p+1;
                    }
                    strcpy(new_string+strlen(new_string), old);
                    strcat(csv_out, new_string);
                    free(new_string);
                }
                else
                    strcat(csv_out, tmp_val);
            }
            else 
                strcat(csv_out, "");
            strcat(csv_out, "\"");
            strcat(csv_out, ";");
            // Conf id
            strcat(csv_out, PQgetvalue(res, i, callConfIndex));
            strcat(csv_out, ";");
            // Call Type
            strcat(csv_out, PQgetvalue(res, i, callTypeIndex));
            strcat(csv_out, ";");
            // Alert Duration
            strcat(csv_out, PQgetvalue(res, i, callAlertIndex));
            strcat(csv_out, ";");
            // Call Duration
            strcat(csv_out, PQgetvalue(res, i, callCallDurIndex));
            strcat(csv_out, ";");
            // Billing Duration
            strcat(csv_out, PQgetvalue(res, i, callBillDurIndex));
            strcat(csv_out, ";");
            // Conn Duration
            strcat(csv_out, PQgetvalue(res, i, callConnDurIndex));
            strcat(csv_out, ";");
            // System Name
            strcat(csv_out, PQgetvalue(res, i, callSystemIndex));
            strcat(csv_out, ";");
            // Node
            strcat(csv_out, PQgetvalue(res, i, callNodeIndex));
            strcat(csv_out, ";");
            // Pbx
            strcat(csv_out, PQgetvalue(res, i, callPbxIndex));
            strcat(csv_out, ";");
            // Phys
            strcat(csv_out, PQgetvalue(res, i, callPhysIndex));
            strcat(csv_out, ";");
            // Call Cause 
            strcat(csv_out, PQgetvalue(res, i, callCauseIndex));
            strcat(csv_out, ";");
            // Call Direction
            if(ptr_strings->tmpDir) {
                if(ptr_strings->tmpDir == ptr_strings->ep1) {
                    strcat(csv_out,"o");
                } else {
                    strcat(csv_out,"i");
                }
            } else
                strcat(csv_out,"");
            strcat(csv_out, ";");
            // Status
            if(ptr_strings->state) {
                strcat(csv_out,ptr_strings->state);
            } else
                strcat(csv_out,"");
            strcat(csv_out, ";");
            // Call Type
            if(ptr_strings->type) {
                strcat(csv_out,ptr_strings->type);
            } else
                strcat(csv_out,"");
            strcat(csv_out, ";");
            // Remote Party
            if(remote.remote) {
                strcat(csv_out, "\"");
                tmp_val = remote.remote;
                if(strchr(tmp_val, '"')) {
                    int search_len = strlen(tmp_val);
                    char *new_string = (char *)malloc((search_len<<1)+1);
                    char *p, *old;

                    memset(new_string, 0x0, (search_len<<1)+1);
                    old = tmp_val;
                    for(p=strchr(tmp_val, '"'); p!=NULL; p=strchr(old, '"')) {
                        strncpy(new_string+strlen(new_string), old, p-old+1);  // +1, Copy " too
                        strcat(new_string, "\"");
                        old = p+1;
                    }
                    strcpy(new_string+strlen(new_string), old);
                    strcat(csv_out, new_string);
                    free(new_string);
                }
                else {
                    strcat(csv_out, remote.remote);
                }
                strcat(csv_out, "\"");
            }
            else
                strcat(csv_out, "");
            strcat(csv_out, ";");
            // Object called
            strcat(csv_out, "\"");
            if(csv.object_called) {
                tmp_val = csv.object_called;
                if(strchr(csv.object_called, '"')) {
                    int search_len = strlen(tmp_val);
                    char *new_string = (char *)malloc((search_len<<1)+1);
                    char *p, *old;

                    memset(new_string, 0x0, (search_len<<1)+1);
                    old = tmp_val;
                    for(p=strchr(tmp_val, '"'); p!=NULL; p=strchr(old, '"')) {
                        strncpy(new_string+strlen(new_string), old, p-old+1);  // +1, Copy " too
                        strcat(new_string, "\"");
                        old = p+1;
                    }
                    strcpy(new_string+strlen(new_string), old);
                    strcat(csv_out, new_string);
                    free(new_string);
                }
                else
                    strcat(csv_out, tmp_val);
            }
            else
                strcat(csv_out, "");
            strcat(csv_out, "\"");
            strcat(csv_out, ";");
            // Diverting 
            strcat(csv_out, "\"");
            if(csv.diverting) {
                tmp_val = csv.diverting;
                if(strchr(csv.diverting, '"')) {
                    int search_len = strlen(tmp_val);
                    char *new_string = (char *)malloc((search_len<<1)+1);
                    char *p, *old;

                    memset(new_string, 0x0, (search_len<<1)+1);
                    old = tmp_val;
                    for(p=strchr(tmp_val, '"'); p!=NULL; p=strchr(old, '"')) {
                        strncpy(new_string+strlen(new_string), old, p-old+1);  // +1, Copy " too
                        strcat(new_string, "\"");
                        old = p+1;
                    }
                    strcpy(new_string+strlen(new_string), old);
                    strcat(csv_out, new_string);
                    free(new_string);
                }
                else
                    strcat(csv_out, tmp_val);
            }
            else
                strcat(csv_out, "");
            strcat(csv_out, "\"");
            strcat(csv_out, ";");
            // Object called
            strcat(csv_out, "\"");
            if(csv.transferring) {
                tmp_val = csv.transferring;
                if(strchr(csv.transferring, '"')) {
                    int search_len = strlen(tmp_val);
                    char *new_string = (char *)malloc((search_len<<1)+1);
                    char *p, *old;

                    memset(new_string, 0x0, (search_len<<1)+1);
                    old = tmp_val;
                    for(p=strchr(tmp_val, '"'); p!=NULL; p=strchr(old, '"')) {
                        strncpy(new_string+strlen(new_string), old, p-old+1);  // +1, Copy " too
                        strcat(new_string, "\"");
                        old = p+1;
                    }
                    strcpy(new_string+strlen(new_string), old);
                    strcat(csv_out, new_string);
                    free(new_string);
                }
                else
                    strcat(csv_out, tmp_val);
            }
            else
                strcat(csv_out, "");
            strcat(csv_out, "\"");
            strcat(csv_out, ";");
            // Further Registration
            if(equal) {
                strcat(csv_out, "1;");
                equal=0;
            } else {
                strcat(csv_out, "0;");
            }
            // Time
            tmp_val = PQgetvalue(res, i, callTimeIndex);
            strncat(csv_out, tmp_val, 10);
            strcat(csv_out, ";");
            tmp_val += 11;
            // date
            strcat(csv_out, tmp_val);
            strcat(csv_out, "\r\n");
            csv_out_len = strlen(csv_out);
            fwrite(csv_out, 1, csv_out_len, f);

            if(free_events != -1) {
                if(events) free(events);
                free_allocated_mem(&subevents, free_events, CALL_FLOW_INDEXES_XML, 0, FLAG_OK);
            } 

            if(chk_further && (i<(nTuples-1))) {
                equal = (!strcmp(PQgetvalue(res, i, callConfIndex),PQgetvalue(res, i+1, callConfIndex)) &&
                         !strcmp(PQgetvalue(res, i, callCCnIndex),PQgetvalue(res, i+1, callCCnIndex)) &&
                         !strcmp(PQgetvalue(res, i, callDirectionIndex),PQgetvalue(res, i+1, callDirectionIndex)) &&
                         (atoi(PQgetvalue(res, i+1, callConnDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callConnDurIndex), PQgetvalue(res, i+1, callConnDurIndex))) &&
                         (atoi(PQgetvalue(res, i+1, callCallDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callCallDurIndex), PQgetvalue(res, i+1, callCallDurIndex))) );
            }
            if(remote.remote_e164 != NULL) {
                free(remote.remote_e164);
                remote.remote_e164 = NULL;
            }
            if(remote.remote_h323 != NULL) {
                free(remote.remote_h323);
                remote.remote_h323 = NULL;
            }
            if(remote.remote_dn != NULL) {
                free(remote.remote_dn);
                remote.remote_dn = NULL;
            }
            if(remote.remote != NULL) { 
                free(remote.remote);
                remote.remote = NULL;
            }
            if(csv.object_info != NULL) {
                free(csv.object_info);
                csv.object_info = NULL;
            }
            if(csv.object_called != NULL) {
                free(csv.object_called);
                csv.object_called = NULL;
            }
            if(csv.transferring != NULL) {
                free(csv.transferring);
                csv.transferring = NULL;
            }
            if(csv.diverting != NULL) {
                free(csv.diverting);
                csv.diverting = NULL;
            }
        }
        if(f) fclose(f);
        free(csv_out);
        if(!internal) {
            f = fopen(file_name, "r");
            if(f) {
                fseek(f, 0L, SEEK_END);
                file_len = ftell(f);
                fseek(f, 0L, SEEK_SET);
                *bytes_sent = FCGX_PutS(CONTENT_TYPE_CSV, cgi->out);
                *output_len += strlen(CONTENT_TYPE_CSV);
                *bytes_sent += FCGX_PutS(CONTENT_LENGTH, cgi->out);
                *output_len += strlen(CONTENT_LENGTH);
                sprintf(file_len_str, "%d\r\n", file_len);
                *bytes_sent += FCGX_PutS(file_len_str, cgi->out);
                *output_len += strlen(file_len_str);
                *bytes_sent += FCGX_PutS(CONTENT_DISPOS, cgi->out);
                *output_len += strlen(CONTENT_DISPOS);
                *bytes_sent += FCGX_PutS("report.csv", cgi->out);
                *output_len += strlen("report.csv");
                *bytes_sent += FCGX_PutS("\r\n\r\n", cgi->out);
                *output_len += strlen("\r\n\r\n");
                while(!feof(f)) {
                    file_read_len = fread(file_read, 1, sizeof(file_read), f);
                    *bytes_sent += FCGX_PutStr(file_read, file_read_len, cgi->out);
                    *output_len += file_read_len;
                }
                fclose(f);
            }
        }
    } else {
        /* allocate deflate state */
        remote_t remote;
        remote.remote_e164 = NULL;
        remote.remote_h323 = NULL;
        remote.remote_dn = NULL;
        remote.remote = NULL;
        char *cb_e164 = NULL, *cb_h323 = NULL, *cb_dn = NULL, *cb_time = NULL, *cb_time_unix = NULL;
        int deflate_error = 0, flag_gz = 1, level = 6, ret;  /* 6 is a good choice, 9 slower and doesn't bring significant improvement */
        int xml_events_length[NUM_PRINT_XML_EVENTS];
        int gvalue_bool;
        int first_put = 1;

        if(!internal) {
            *bytes_sent = FCGX_PutS(CONTENT_TYPE_XML, cgi->out);
            *output_len += strlen(CONTENT_TYPE_XML);
            if(!strcmp(format, "xml")) {
                *bytes_sent += FCGX_PutS(CONTENT_DISPOS, cgi->out);
                *output_len += strlen(CONTENT_DISPOS);
                *bytes_sent += FCGX_PutS("report.xml", cgi->out);
                *output_len += strlen("report.xml");
                *bytes_sent += FCGX_PutS("\r\n", cgi->out);
                *output_len += strlen("\r\n");
            }
            strm.zalloc = Z_NULL;
            strm.zfree = Z_NULL;
            strm.opaque = Z_NULL;
            ret = deflateInit(&strm, level);
            if (ret != Z_OK) {
                flag_gz = 0;
            }
        }
        else {
            flag_gz = 0;
        }

        if(!mypbx) {
            f=fopen(file_name,"w+");
            if(f==NULL) {
                if(href != NULL) free(href);
                if(query != NULL) free(query);
                if(conninfo != NULL) free(conninfo);
                if(format != NULL) free(format);
                if(file_name != NULL) free(file_name);
                if(server != NULL) free(server);
                if(order != NULL) free(order);
                if(svalue != NULL) free(svalue);
                if(gvalue != NULL) free(gvalue);
                if(logo != NULL) free(logo);
                if(logo_width != NULL) free(logo_width);
                if(footer != NULL) free(footer);
                if(footer_width != NULL) free(footer_width);
                if(cn != NULL) free(cn);
                if(usergroup != NULL) free(usergroup);
                if(userpbx != NULL) free(userpbx);
                if(filter_name != NULL) free(filter_name);
                if(filters_name != NULL) free(filters_name);
                if(pbx_object != NULL) free(pbx_object);
                if(pbx != NULL) free(pbx);
                if(from_date != NULL) free(from_date);
                if(to_date != NULL) free(to_date);
                if(lang_str != NULL) free(lang_str);
                if(displayed_duration != NULL) free(displayed_duration);
                tmp_columns = columns;
                for(i=0;i<num_cols;i++) {
                    if(*tmp_columns != NULL) free(*tmp_columns);
                    tmp_columns++;
                }
                free(columns);
                free(ind_columns);
                do_log(LOG_REPORTING, "", "reporting: ERROR opening file '%s'", file_name);
                free_ldap_config(ldap_servers);
                cleanup_config(reporting_cfg);
                return ERROR_REPORT_OPENING_ZIP_FILE;
            }
        }

        xml_out_i = (char *)malloc(8192*sizeof(char));
        if(xml_out_i == NULL) {
            do_log(LOG_REPORTING, "", "reporting: ERROR no memory available");
            if(f) fclose(f);
            free_ldap_config(ldap_servers);
            cleanup_config(reporting_cfg);
            return ERROR_REPORT_NO_MEMORY_AVAILABLE;
        }
        xml_events_length[CALLER_XML] = CALLER_LEN;
        xml_events_length[EP1_XML_NUMBER] = EP1_NUMBER_LEN;
        xml_events_length[EP1_XML_NAME] = EP1_NAME_LEN;
        xml_events_length[EP1_XML_DN] = EP1_DN_LEN;
        xml_events_length[EP2_XML_NUMBER] = EP2_NUMBER_LEN;
        xml_events_length[EP2_XML_NAME] = EP2_NAME_LEN;
        xml_events_length[EP2_XML_DN] = EP2_DN_LEN;
        xml_events_length[STATUS_XML] = STATUS_LEN;
        xml_events_length[TYPE_XML] = TYPE_LEN;
        xml_events_length[ENTRY_XML] = ENTRY_LEN;

        gvalue_bool = gvalue ? strcmp(gvalue, "") : 0;

        if(flag_gz) {
            xml_out_gz = (char *)malloc(8192*sizeof(char));
            if(xml_out_gz == NULL) {
                flag_gz = 0;
                (void)deflateEnd(&strm);
            }
        }
        xml_out = xml_out_i;
        strcpy(xml_out, "<?xml version='1.0' encoding='utf-8'?>\r\n");
        if(mypbx) {
            strcat(xml_out, "<?xml-stylesheet type='text/xsl' href='call_list.xsl'?>\r\n");
        }
        else {
            strcat(xml_out, "<?xml-stylesheet type='text/xsl' href='report.xsl'?>\r\n");
        }
        if(mypbx) {
            strcat(xml_out, "<report>\r\n");
        }
        else {
            strcat(xml_out, "<report group-by='");
            strcat(xml_out, gvalue);
            strcat(xml_out, "' href='");
            strcat(xml_out, href);
            strcat(xml_out, "' sort-by='");
            strcat(xml_out, svalue);
            strcat(xml_out, "' sort-order='");
            strcat(xml_out, (!strcmp(order,"ASC") ? "ascending" : "descending"));
            strcat(xml_out, "' server='");
            strcat(xml_out, server);
            strcat(xml_out, "' displayed-duration='");
            strcat(xml_out, xml_lookup_table[displayedDurCol]);
            if(anonym) {
                strcat(xml_out, "' anonym='1");
            }
            strcat(xml_out, "' limit='");
            char buffer[12];
            sprintf(buffer, "%d", report_limit);
            strcat(xml_out, buffer);
            strcat(xml_out, "' voice-player-port='");
            sprintf(buffer, "%d", reporting_cfg->voice_player->port);
            strcat(xml_out, buffer);
            strcat(xml_out, "'>\r\n");
        }
        strcat(xml_out, "  <translation>\r\n");
        strcat(xml_out, "    <obj>");
        strcat_xml(xml_out, process_string_table[TXT_OBJECT].lang[lang]);
        strcat(xml_out, "</obj>\r\n");
        strcat(xml_out, "    <id>");
        strcat_xml(xml_out, process_string_table[TXT_CONFERENCE_ID].lang[lang]);
        strcat(xml_out, "</id>\r\n");
        strcat(xml_out, "    <flow>");
        strcat_xml(xml_out, process_string_table[TXT_CALL_FLOW].lang[lang]);
        strcat(xml_out, "</flow>\r\n");
        strcat(xml_out, "    <dir>");
        strcat_xml(xml_out, process_string_table[TXT_DIRECTION].lang[lang]);
        strcat(xml_out, "</dir>\r\n");
        strcat(xml_out, "    <type>");
        strcat_xml(xml_out, process_string_table[TXT_TYPE].lang[lang]);
        strcat(xml_out, "</type>\r\n");
        strcat(xml_out, "    <alert-duration>");
        strcat_xml(xml_out, process_string_table[TXT_ALERT_DURATION].lang[lang]);
        strcat(xml_out, "</alert-duration>\r\n");
        strcat(xml_out, "    <call-duration>");
        strcat_xml(xml_out, process_string_table[TXT_CALL_DURATION].lang[lang]);
        strcat(xml_out, "</call-duration>\r\n");
        strcat(xml_out, "    <billing-duration>");
        strcat_xml(xml_out, process_string_table[TXT_BILLING_DURATION].lang[lang]);
        strcat(xml_out, "</billing-duration>\r\n");
        strcat(xml_out, "    <conn-duration>");
        strcat_xml(xml_out, process_string_table[TXT_CONN_DURATION].lang[lang]);
        strcat(xml_out, "</conn-duration>\r\n");
        strcat(xml_out, "    <groups>");
        strcat_xml(xml_out, process_string_table[TXT_OBJECT_GROUPS].lang[lang]);
        strcat(xml_out, "</groups>\r\n");
        strcat(xml_out, "    <node>");
        strcat_xml(xml_out, process_string_table[TXT_NODE].lang[lang]);
        strcat(xml_out, "</node>\r\n");
        strcat(xml_out, "    <pbx>");
        strcat_xml(xml_out, process_string_table[TXT_PBX].lang[lang]);
        strcat(xml_out, "</pbx>\r\n");
        strcat(xml_out, "    <cause>");
        strcat_xml(xml_out, process_string_table[TXT_CAUSE].lang[lang]);
        strcat(xml_out, "</cause>\r\n");
        strcat(xml_out, "    <right>");
        strcat_xml(xml_out, process_string_table[TXT_RIGHT].lang[lang]);
        strcat(xml_out, "</right>\r\n");
        strcat(xml_out, "    <left>");
        strcat_xml(xml_out, process_string_table[TXT_LEFT].lang[lang]);
        strcat(xml_out, "</left>\r\n");
        strcat(xml_out, "    <time>");
        strcat_xml(xml_out, process_string_table[TXT_TIME].lang[lang]);
        strcat(xml_out, "</time>\r\n");
        strcat(xml_out, "    <object-long-name>");
        strcat_xml(xml_out, process_string_table[TXT_OBJECT_LONG_NAME].lang[lang]);
        strcat(xml_out, "</object-long-name>\r\n");
        strcat(xml_out, "    <callback>");
        strcat_xml(xml_out, process_string_table[TXT_CALLBACK].lang[lang]);
        strcat(xml_out, "</callback>\r\n");
        strcat(xml_out, "    <status>");
        strcat_xml(xml_out, process_string_table[TXT_STATUS].lang[lang]);
        strcat(xml_out, "</status>\r\n");
        strcat(xml_out, "    <filter-name>");
        strcat_xml(xml_out, process_string_table[TXT_FILTER_NAME].lang[lang]);
        strcat(xml_out, "</filter-name>\r\n");
        strcat(xml_out, "    <filter-names>");
        strcat_xml(xml_out, process_string_table[TXT_FILTER_NAMES].lang[lang]);
        strcat(xml_out, "</filter-names>\r\n");
        strcat(xml_out, "    <sum-io>");
        strcat_xml(xml_out, process_string_table[TXT_SUMMARY_IO].lang[lang]);
        strcat(xml_out, "</sum-io>\r\n");
        strcat(xml_out, "    <sum-dur-io>");
        strcat_xml(xml_out, process_string_table[TXT_SUMMARY_DURATION_IO].lang[lang]);
        strcat(xml_out, "</sum-dur-io>\r\n");
        strcat(xml_out, "    <sum-alert-dur-io>");
        strcat_xml(xml_out, process_string_table[TXT_SUMMARY_ALERT_IO].lang[lang]);
        strcat(xml_out, "</sum-alert-dur-io>\r\n");
        strcat(xml_out, "    <sum-calls-io>");
        strcat_xml(xml_out, process_string_table[TXT_SUMMARY_CALLS_IO].lang[lang]);
        strcat(xml_out, "</sum-calls-io>\r\n");
        strcat(xml_out, "    <group-by>");
        strcat_xml(xml_out, process_string_table[TXT_GROUP_BY].lang[lang]);
        strcat(xml_out, "</group-by>\r\n");
        strcat(xml_out, "    <displayed-duration>");
        strcat_xml(xml_out, process_string_table[TXT_DISPLAYED_DURATION].lang[lang]);
        strcat(xml_out, "</displayed-duration>\r\n");
        strcat(xml_out, "    <sort-by>");
        strcat_xml(xml_out, process_string_table[TXT_SORT_BY].lang[lang]);
        strcat(xml_out, "</sort-by>\r\n");
        strcat(xml_out, "    <sort-order>");
        strcat_xml(xml_out, process_string_table[TXT_SORT_ORDER].lang[lang]);
        strcat(xml_out, "</sort-order>\r\n");
        strcat(xml_out, "    <hide-digits>");
        strcat_xml(xml_out, process_string_table[TXT_HIDE_DIGITS].lang[lang]);
        strcat(xml_out, "</hide-digits>\r\n");
        strcat(xml_out, "    <anonym>");
        strcat_xml(xml_out, process_string_table[TXT_ANONYM].lang[lang]);
        strcat(xml_out, "</anonym>\r\n");
        strcat(xml_out, "    <to>");
        strcat_xml(xml_out, process_string_table[TXT_DATE_TO].lang[lang]);
        strcat(xml_out, "</to>\r\n");
        strcat(xml_out, "    <from>");
        strcat_xml(xml_out, process_string_table[TXT_DATE_FROM].lang[lang]);
        strcat(xml_out, "</from>\r\n");
        strcat(xml_out, "    <no-records>");
        strcat_xml(xml_out, process_string_table[TXT_NO_RECORDS].lang[lang]);
        strcat(xml_out, "</no-records>\r\n");
        strcat(xml_out, "    <today>");
        strcat_xml(xml_out, process_string_table[TXT_TODAY].lang[lang]);
        strcat(xml_out, "</today>\r\n");
        strcat(xml_out, "    <yesterday>");
        strcat_xml(xml_out, process_string_table[TXT_YESTERDAY].lang[lang]);
        strcat(xml_out, "</yesterday>\r\n");
        strcat(xml_out, "    <incoming>");
        strcat_xml(xml_out, process_string_table[TXT_INCOMING].lang[lang]);
        strcat(xml_out, "</incoming>\r\n");
        strcat(xml_out, "    <outgoing>");
        strcat_xml(xml_out, process_string_table[TXT_OUTGOING].lang[lang]);
        strcat(xml_out, "</outgoing>\r\n");
        strcat(xml_out, "    <yes>");
        strcat_xml(xml_out, process_string_table[TXT_YES].lang[lang]);
        strcat(xml_out, "</yes>\r\n");
        strcat(xml_out, "    <no>");
        strcat_xml(xml_out, process_string_table[TXT_NO].lang[lang]);
        strcat(xml_out, "</no>\r\n");
        strcat(xml_out, "    <limit>");
        strcat_xml(xml_out, process_string_table[TXT_REPORT_LIMIT].lang[lang]);
        strcat(xml_out, "</limit>\r\n");
        strcat(xml_out, "  </translation>\r\n");
        if(filter_info) {
            strcat(xml_out, "  <filter-info>\r\n");
            strcat(xml_out, "    <name>");
            strcat(xml_out, filter_name);
            strcat(xml_out, "</name>\r\n");

            strcat(xml_out, "    <names>");
            strcat(xml_out, filters_name);
            strcat(xml_out, "</names>\r\n");

            strcat(xml_out, "    <object>");
            strcat(xml_out, pbx_object);
            strcat(xml_out, "</object>\r\n");

            strcat(xml_out, "    <pbx>");
            strcat(xml_out, pbx);
            strcat(xml_out, "</pbx>\r\n");

            strcat(xml_out, "    <from>");
            strcat(xml_out, from_date);
            strcat(xml_out, "</from>\r\n");

            strcat(xml_out, "    <to>");
            strcat(xml_out, to_date);
            strcat(xml_out, "</to>\r\n");

            strcat(xml_out, "    <group-by>");
            if(gvalue) {
                if(!strcmp(gvalue, "time"))
                    strcat_xml(xml_out, process_string_table[TXT_DATE].lang[lang]);
                else if(!strcmp(gvalue, "obj"))
                    strcat_xml(xml_out, process_string_table[TXT_OBJECT].lang[lang]);
            }
            strcat(xml_out, "</group-by>\r\n");
            
            strcat(xml_out, "    <displayed-duration>");
            strcat(xml_out, process_string_table[txt_displayed_duration_index].lang[lang]);
            strcat(xml_out, "</displayed-duration>\r\n");

            if(internal) {
                strcat(xml_out, "    <sort-by>");
                if(svalue) {
                    if(!strcmp(svalue, column_lookup_table[TIME_COL]))
                        strcat_xml(xml_out, process_string_table[TXT_TIME].lang[lang]);
                    else if(!strcmp(svalue, column_lookup_table[CN_COL]))
                        strcat_xml(xml_out, process_string_table[TXT_OBJECT].lang[lang]);
                    else if(!strcmp(svalue, column_lookup_table[CALL_DUR_COL]))
                        strcat_xml(xml_out, process_string_table[TXT_DURATION].lang[lang]);
                    else if(!strcmp(svalue, column_lookup_table[DIR_COL]))
                        strcat_xml(xml_out, process_string_table[TXT_DIRECTION].lang[lang]);
                    else 
                        strcat(xml_out, svalue);
                }
                strcat(xml_out, "</sort-by>\r\n");

                strcat(xml_out, "    <sort-order>");
                if(order) {
                    if(!strcmp(order, "ASC"))
                        strcat_xml(xml_out, process_string_table[TXT_SORT_ASCENDING].lang[lang]);
                    else
                        strcat_xml(xml_out, process_string_table[TXT_SORT_DESCENDING].lang[lang]);
                }
                strcat(xml_out, "</sort-order>\r\n");
            }
            strcat(xml_out, "    <hide-digits>");
            if(digits_to_hide) {
                char tdigits[4];
                sprintf(tdigits, "%d", digits_to_hide);
                strcat(xml_out, tdigits);
            }
            strcat(xml_out, "</hide-digits>\r\n");
            if(anonym) {
                strcat(xml_out, "    <anonym/>\r\n");
            }

            strcat(xml_out, "  </filter-info>\r\n");
        }
        xml_out_len = strlen(xml_out);
        if(flag_gz) {
            strm.avail_in = xml_out_len;
            strm.next_in = (unsigned char *)xml_out;
            do {
                strm.avail_out = 8192;
                strm.next_out = (unsigned char *)xml_out_gz;
                ret = deflate(&strm, Z_NO_FLUSH);
                if(ret == Z_STREAM_ERROR) {
                    flag_gz = 0;
                    if(f) {
                        rewind(f); 
                        fwrite(xml_out, 1, xml_out_len, f);
                    }
                    if(first_put) { // end header section, don't put deflate header
                        first_put = 0;  
                        *bytes_sent += FCGX_PutS("\r\n", cgi->out);
                        *output_len += strlen("\r\n");
                    }
                    use_deflate = 0;
                    if(xml_out_gz) free(xml_out_gz);
                    (void)deflateEnd(&strm);
                    break; 
                } else {
                    start_put = first_put ? 2 : 0;
                    if(first_put) {
                        if(use_deflate) {
                            *bytes_sent += FCGX_PutS(CONTENT_ENCODING_DEFLATE, cgi->out);   // put deflate header
                            *output_len += strlen(CONTENT_ENCODING_DEFLATE);
                        }
                        *bytes_sent += FCGX_PutS("\r\n", cgi->out); // end header section
                        *output_len += strlen("\r\n");
                        first_put = 0;
                    }
                    if(f) fwrite(xml_out_gz, 1, (8192-strm.avail_out), f);
                    if(use_deflate) {
                        *bytes_sent += FCGX_PutStr(&xml_out_gz[start_put], (8192-strm.avail_out-start_put), cgi->out);
                        *output_len += (8192-strm.avail_out-start_put);
                    }
                }
            } while (strm.avail_out == 0);
            //tot += strlen(xml_out);
            //crc = crc32(crc, xml_out, strlen(xml_out));
        } else {
            if(f) fwrite(xml_out, 1, xml_out_len, f);
        }
        if(!internal && !use_deflate) {
            *bytes_sent += FCGX_PutStr(xml_out, xml_out_len, cgi->out);
            *output_len += xml_out_len;
        }
        if(trace_level & TRACE_CALL_FLOW) {
            do_log(LOG_REPORTING, "", "reporting: nTuples: %d nFields: %d-%d", nTuples, nFields_db, num_cols);
        }

    	nFields = (num_cols < nFields_db ) ? num_cols : nFields_db;
        for (i = 0; i < nTuples; i++)
        {
            int call_duration = 0;
            int alert_duration = 0;

            memset(xml_out, 0x0, strlen(xml_out));
            xml_out = xml_out_i;
            strcpy(xml_out, "  <record group-by=\"");
            if(gvalue_bool) {
                groupValue = PQgetvalue(res, i, groupByIndex);
                strcat(xml_out, groupValue);
                strcat(xml_out, "\" group-by-sort=\"");
                if(!strcmp(gvalue, xml_lookup_table[TIME_COL]))
                    strcat(xml_out,PQgetvalue(res, i, callDateSortIndex));
                else 
                    strcat(xml_out,groupValue);
            }
            strcat(xml_out, "\">\r\n");
            ptr_strings->tmpDir = NULL;
            ptr_strings->type = NULL;
            ptr_strings->state = ptr_strings->er;
            cause = ((callCauseIndex == -1) ? 0 : atoi(PQgetvalue(res, i, callCauseIndex)));
            c_type = ((callTypeIndex == -1) ? 0 : !strcmp(PQgetvalue(res, i, callTypeIndex), "ext"));
            for (j = 0; j < nFields; j++) {
                switch(ind_columns[j]) {
                    case TIME_COL:
                        {
                            strcat(xml_out,xml_lookup_table_open[ind_columns[j]]);    //    <time time=" 
                            strcat(xml_out,PQgetvalue(res, i, callUnixTimeIndex));
                            if(callUtcUnixTimeIndex >= 0) {
                                strcat(xml_out,"\" utc=\"");
                                strcat(xml_out,PQgetvalue(res, i, callUtcUnixTimeIndex));
                            }
                            strcat(xml_out,"\">");
                            strcat(xml_out,PQgetvalue(res, i, j));
                            strcat(xml_out,xml_lookup_table_close[ind_columns[j]]);   // </time>\r\n */
                        }
                        break;
                    case CALL_FLOW_COL:
                        {
                            int free_events = -1, numEvents = 0, k, l;
                            char **events = NULL, **tmp_events = NULL, **subevents = NULL;

    #ifdef _ADD_CALL_FLOW
                            xmlTmp  = xml_lookup_table[ind_columns[j]];

                            strcat(xml_out,"    <");
                            strcat(xml_out,xmlTmp);
                            strcat(xml_out," call-flow=\"");
                            strcat(xml_out,PQgetvalue(res, i, j));
                            /*strcat(xml_out, " id=\"");
                            strcat(xml_out,PQgetvalue(res, i, 22));*/
                            strcat(xml_out, "\">");
    #else
                            strcat(xml_out,xml_lookup_table_open[ind_columns[j]]);
    #endif
                            if(digits_to_hide > 0)
                                free_events = pg_array_parse_xml(PQgetvalue(res, i, j), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, digits_to_hide, anonym, PQgetvalue(res, i, callPbxIndex), PQgetvalue(res, i, callPhysIndex), ldap_servers);
                            else 
                                free_events = pg_array_parse_xml(PQgetvalue(res, i, j), cause, c_type, &events, &subevents, &numEvents, ptr_strings, &remote, digits_to_hide, anonym, NULL, NULL, ldap_servers);
                            if((free_events != -1) && (numEvents < MAX_NUM_EVENTS)) {
                                char *p_xml = &xml_out[strlen(xml_out)];
                                tmp_events = events;

                                for(k=0;k<numEvents;k++)
                                {
                                    strcpy(p_xml, START_EV_TAG); p_xml += START_EV_TAG_LEN;
                                    for(l=0;l<NUM_PRINT_XML_EVENTS;l++,tmp_events++) 
                                    {
                                        if(*tmp_events) 
                                        {
                                            strcpy(p_xml,xml_events_print[l]); p_xml += xml_events_length[l];
                                            strcpy(p_xml,*tmp_events);         p_xml += strlen(*tmp_events);
                                            strcpy(p_xml,"\"");                p_xml += 1;    /* strlen("\"") */
                                        }
                                    }
                                    strcpy(p_xml,"/>"); p_xml += 2;
                                }
                            }
                            strcat(xml_out,"\r\n    ");
                            strcat(xml_out,xml_lookup_table_close[ind_columns[j]]);
                            if(free_events != -1) {
                                if(events) free(events);
                                free_allocated_mem(&subevents, free_events, CALL_FLOW_INDEXES_XML, 0, FLAG_OK);
                            }
                        }
                        break;
                    case ALERT_COL:  //ReportingConfigConsts::colAlertTime:
                    case CALL_DUR_COL:
                    case CALL_CONN_COL:
                    case CALL_BILLING_COL:
                        {
                            int rec_call_duration;

                            elemTmp = PQgetvalue(res, i, j);
                            rec_call_duration = atoi(elemTmp);

                            strcat(xml_out,xml_lookup_table_open[ind_columns[j]]);
                            if(sec2hms(rec_call_duration,time_formatted,0)) {
                                strcat(xml_out,elemTmp);
                                strcat(xml_out,"\">");
                                strcat(xml_out,time_formatted);
                            } else {
                                strcat(xml_out,"0\">0:00");
                            }
                            strcat(xml_out,xml_lookup_table_close[ind_columns[j]]);
                            if(ind_columns[j] == displayedDurCol) call_duration = rec_call_duration;
                            else if (ind_columns[j] == ALERT_COL) {
                                alert_duration = rec_call_duration;
                            }
                        }
                        break;
                    case CONF_COL:   //ReportingConfigConsts::colConf:
                    case CALL_COL:   //ReportingConfigConsts::colCallType:
                    case CAUSE_COL:  //ReportingConfigConsts::colCauseCode:
                        strcat(xml_out,xml_lookup_table_open[ind_columns[j]]);
                        strcat(xml_out,PQgetvalue(res, i, j));
                        strcat(xml_out,xml_lookup_table_close[ind_columns[j]]);
                        break;
                    case GROUPS_COL: //ReportingConfigConsts::colGroups:
                        {
                            elemTmp = PQgetvalue(res, i, j);
                            if(!strcmp(elemTmp,"{}")) {
                                strcat(xml_out,"    <groups/>\r\n");
                            } else {
                                char *pch = elemTmp;
                                int i, j, grp_len, xml_length;

                                strcat(xml_out,"    <groups>\r\n");
                                do {
                                    strcat(xml_out,"        <group>");
                                    pch += 2;    /* {{ or ,{ */
                                    grp_len = find_separator(pch, RIGHT_CURLY_BRACKET_CHAR);
                                  
                                    xml_length = strlen(xml_out);
                                    for(i=0,j=0;i<grp_len;i++,j++) {  
                                        if(*pch == SLASH_CHAR) {
                                            pch++; i++;
                                        }
                                        xml_out[xml_length+j] = *pch++;
                                    }
                                    pch++;                      /* } */
                                    xml_out[xml_length+j] = '\0';
                                    strcat(xml_out,"</group>\r\n");
                                } while(*pch != RIGHT_CURLY_BRACKET_CHAR);
                                strcat(xml_out,"    </groups>\r\n");
                            }
                        }
                        break;
                    case CN_COL:
                    case NODE_COL:
                    case PBX_COL:
                    case SYSTEM_COL:
                    case PHYS_COL:
                    case RECORDER_PATH_COL:
                        {
                            if (ind_columns[j] == RECORDER_PATH_COL && reporting_cfg->voice_player->port <= 0) {    // skip recorder path if no player port is configured
                                break;
                            }
                            int len_ent;

                            elemTmp = PQgetvalue(res, i, j);
                            len_ent = strlen(elemTmp);
                            if (ind_columns[j] == RECORDER_PATH_COL && len_ent == 0) {                              // skip recorder path if emtpy
                                break;
                            }
                            char *xml_entities = (char *)malloc((len_ent<<3)*sizeof(char));	/* 6 == '&quot;' */

                            if(xml_entities != NULL) {
                                xmlentities(elemTmp, xml_entities, len_ent);
                                strcat(xml_out,xml_lookup_table_open[ind_columns[j]]);
                                strcat(xml_out,xml_entities);
                                strcat(xml_out,xml_lookup_table_close[ind_columns[j]]);
                                free(xml_entities);
                            } else {
                                strcat(xml_out,xml_lookup_table_open[ind_columns[j]]);
                                strcat(xml_out,xml_lookup_table_close[ind_columns[j]]);
                            }
                        }
                        break;
                }
            }
            if(trace_level & TRACE_CALL_FLOW) {
                do_log(LOG_REPORTING, "", "reporting: type: %s state: %s dir: %s", ptr_strings->type, ptr_strings->state, ptr_strings->tmpDir);
            }
            if(ptr_strings->tmpDir) {
                if(ptr_strings->tmpDir == ptr_strings->ep1) {
                    strcat(xml_out,"    <dir>o</dir>\r\n");
                    if(!equal) {
                        num_calls_out++;
                        total_call_length_out += call_duration;
                        total_alert_dur_out += alert_duration;
                    }
                } else {
                    strcat(xml_out,"    <dir>i</dir>\r\n");
                    if(!equal) {
                        num_calls_in++;
                        total_call_length_in += call_duration;
                        total_alert_dur_in += alert_duration;
                    }
                }
            } else 
                strcat(xml_out,"    <dir/>\r\n");
            if(ptr_strings->state) {
                strcat(xml_out,"    <status>");
                strcat(xml_out,ptr_strings->state);
                strcat(xml_out,"</status>\r\n");
            } else  
                strcat(xml_out,"    <status/>\r\n");
            if(ptr_strings->type) {
                strcat(xml_out,"    <type>");
                strcat(xml_out,ptr_strings->type);
                strcat(xml_out,"</type>\r\n");
            } else
                strcat(xml_out,"    <type/>\r\n");
            /* Remote */
            strcat(xml_out,"    <remote");
            if(trace_level & TRACE_CALL_FLOW) {
                do_log(LOG_REPORTING, "", "reporting: remote: %s %s %s", 
                       (remote.remote_e164 == NULL) ? "e164 Unknown" : remote.remote_e164, 
                       (remote.remote_h323 == NULL) ? "h323 Unknown" : remote.remote_h323, 
                       (remote.remote_dn == NULL) ? "dn Unknown" : remote.remote_dn); 
            }
            if(remote.remote_e164 != NULL) {
                strcat(xml_out," number=\"");
                strcat(xml_out,remote.remote_e164);
                strcat(xml_out,"\"");
                free(remote.remote_e164);
                remote.remote_e164 = NULL;
            }
            if(remote.remote_h323 != NULL) {
                strcat(xml_out," name=\"");
                strcat(xml_out,remote.remote_h323);
                strcat(xml_out,"\"");
                free(remote.remote_h323);
                remote.remote_h323 = NULL;
            }
            if(remote.remote_dn != NULL) {
                strcat(xml_out," dn=\"");
                strcat(xml_out,remote.remote_dn);
                strcat(xml_out,"\"");
                free(remote.remote_dn);
                remote.remote_dn = NULL;
            }
            if(remote.remote != NULL) {
                free(remote.remote);
                remote.remote = NULL;
            }
            strcat(xml_out,"/>\r\n");
            /* Callback */
            cb_e164 = PQgetvalue(res, i, callCbE164Index);
            cb_h323 = PQgetvalue(res, i, callCbH323Index);
            cb_dn = PQgetvalue(res, i, callCbDnIndex);
            if(*cb_e164 || *cb_h323 || *cb_dn) {
                strcat(xml_out,"    <callback");
                if(*cb_e164) {
                    strcat(xml_out, " number=\"");
                    strcat(xml_out,cb_e164);
                    strcat(xml_out, "\"");
                }
                if(*cb_h323) {
                    strcat(xml_out, " name=\"");
                    char *xml_entities = (char *)malloc((strlen(cb_h323) << 3)*sizeof(char));
                    if (xml_entities != NULL) {
                        xmlentities(cb_h323, xml_entities, strlen(cb_h323));
                        strcat(xml_out, xml_entities);
			free(xml_entities);
                    }
                    strcat(xml_out, "\"");
                }
                if(*cb_dn) {
                    strcat(xml_out, " dn=\"");
                    char *xml_entities = (char *)malloc((strlen(cb_dn) << 3)*sizeof(char));
                    if (xml_entities != NULL) {
                        xmlentities(cb_dn, xml_entities, strlen(cb_dn));
                        strcat(xml_out, xml_entities);
			free(xml_entities);
                    }
                    strcat(xml_out, "\"");
                }
                /* convert timestamp */
                cb_time = PQgetvalue(res, i, callCbTimeIndex);
                cb_time_unix = PQgetvalue(res, i, callCbTimeUnixIndex);
                
                strcat(xml_out," time=\"");
                strcat(xml_out,cb_time_unix);
                strcat(xml_out,"\">");
                strcat(xml_out,cb_time);
                strcat(xml_out,"</callback>\r\n");
            }
            /* Further Registration */ 
            if(equal) {
                strcat(xml_out,"    <further-registration/>\r\n  </record>\r\n");
                equal=0;
            } else {
                strcat(xml_out,"  </record>\r\n");
            }
            if(chk_further && (i<(nTuples-1))) {
                equal = (!strcmp(PQgetvalue(res, i, callConfIndex),PQgetvalue(res, i+1, callConfIndex)) &&
                         !strcmp(PQgetvalue(res, i, callCCnIndex),PQgetvalue(res, i+1, callCCnIndex)) && 
                         !strcmp(PQgetvalue(res, i, callDirectionIndex),PQgetvalue(res, i+1, callDirectionIndex)) && 
                         (atoi(PQgetvalue(res, i+1, callConnDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callConnDurIndex), PQgetvalue(res, i+1, callConnDurIndex))) &&
                         (atoi(PQgetvalue(res, i+1, callCallDurIndex)) == 0 || !strcmp(PQgetvalue(res, i, callCallDurIndex), PQgetvalue(res, i+1, callCallDurIndex))) );
            }
            xml_out_len = MIN(strlen(xml_out), 8192);
            if(flag_gz) {
                strm.avail_in = xml_out_len;
                strm.next_in = (unsigned char*)xml_out;
                do {
                    strm.avail_out = 8192;
                    strm.next_out = (unsigned char*)xml_out_gz;
                    ret = deflate(&strm, Z_NO_FLUSH);
                    if(ret == Z_STREAM_ERROR) {
                        deflate_error = 1;
                        break;
                    }
                    if(f) fwrite(xml_out_gz, 1, (8192-strm.avail_out), f);
                    if(use_deflate) {
                        *bytes_sent += FCGX_PutStr(xml_out_gz, (8192-strm.avail_out), cgi->out);
                        *output_len += (8192-strm.avail_out);
                    }
                } while (strm.avail_out == 0);
                if(deflate_error) break;
                //crc = crc32(crc, xml_out, MIN(strlen(xml_out), 8192));
                //tot += MIN(strlen(xml_out), 8192);
            } else {
                if(f) fwrite(xml_out, 1, xml_out_len, f);
            }
            if(!internal && !use_deflate) {
                *bytes_sent += FCGX_PutStr(xml_out, xml_out_len, cgi->out);
                *output_len += xml_out_len;
            }
        }
        if(!deflate_error) {
            strcpy(xml_out,"  <summary>\r\n    <calls>\r\n          ");
            strcat(xml_out,"<incoming>");
            sprintf(&xml_out[strlen(xml_out)],"%d",num_calls_in);
            strcat(xml_out,"</incoming>\r\n          <outgoing>");
            sprintf(&xml_out[strlen(xml_out)],"%d",num_calls_out);
            strcat(xml_out,"</outgoing>\r\n    </calls>\r\n    <duration>\r\n          ");
            strcat(xml_out,"<incoming>");
            sprintf(&xml_out[strlen(xml_out)],"%d",total_call_length_in);
            strcat(xml_out,"</incoming>\r\n");
            strcat(xml_out,"          <outgoing>");
            sprintf(&xml_out[strlen(xml_out)],"%d",total_call_length_out);
            strcat(xml_out,"</outgoing>\r\n");
            strcat(xml_out,"          <alert-incoming>");
            sprintf(&xml_out[strlen(xml_out)],"%d",total_alert_dur_in);
            strcat(xml_out,"</alert-incoming>\r\n");
            strcat(xml_out,"          <alert-outgoing>");
            sprintf(&xml_out[strlen(xml_out)],"%d",total_alert_dur_out);
            strcat(xml_out,"</alert-outgoing>\r\n");
            strcat(xml_out,"    </duration>\r\n  </summary>\r\n");
            strcat(xml_out,"</report>");
            xml_out_len = strlen(xml_out);
            if(flag_gz) {
                strm.avail_in = xml_out_len;
                strm.next_in = (unsigned char*)xml_out;
                do {
                    strm.avail_out = 8192;
                    strm.next_out = (unsigned char*)xml_out_gz;
                    ret = deflate(&strm, Z_FINISH);
                    if(ret == Z_STREAM_ERROR) {
                        break;
                    }
                    if(f) fwrite(xml_out_gz, 1, (8192-strm.avail_out), f);
                    if(use_deflate) {
                        *bytes_sent += FCGX_PutStr(xml_out_gz, (8192-strm.avail_out), cgi->out);
                        *output_len += (8192-strm.avail_out);
                    }
                } while (strm.avail_out == 0);
                //tot += strlen(xml_out);
                //crc = crc32(crc, xml_out, strlen(xml_out));
                //put4(crc, f);
                //put4(tot, f);
            } else {
                if(f) fwrite(xml_out, 1, xml_out_len, f);
            }
            if(!internal && !use_deflate) {
                *bytes_sent += FCGX_PutStr(xml_out, xml_out_len, cgi->out);
                *output_len += xml_out_len;
            }
        } else {
            // putting anything in here might not work, as some data (xml or gz) could be already sent
            /*strcpy(xml_out, "<?xml version='1.0' encoding='utf-8'?>\r\n");
            strcat(xml_out, "<report>Error compressing xml</report>");
            fwrite(xml_out, 1, strlen(xml_out), f);*/
        }
        if(f) fclose(f);
        free(xml_out_i);
        if(xml_out_gz) free(xml_out_gz);
        if(flag_gz) {
            (void)deflateEnd(&strm);
        }
    }
    /* free all used memory */
    free(ptr_strings->ct);
    free(ptr_strings->cct);
    free(ptr_strings->cf);
    free(ptr_strings->co);
    free(ptr_strings->al);
    free(ptr_strings->er);
    free(ptr_strings->bu);
    free(ptr_strings->ep1);
    free(ptr_strings->ep2);
    free(ptr_strings->true);
    free(ptr_strings);

    if(href != NULL) free(href);
    if(query != NULL) free(query);
    if(conninfo != NULL) free(conninfo);
    if(format != NULL) free(format);
    if(file_name != NULL) free(file_name);
    if(server != NULL) free(server);
    if(order != NULL) free(order);
    if(svalue != NULL) free(svalue);
    if(gvalue != NULL) free(gvalue);
    if(logo != NULL) free(logo);
    if(filter_name != NULL) free(filter_name);
    if(filters_name != NULL) free(filters_name);
    if(pbx_object != NULL) free(pbx_object);
    if(pbx != NULL) free(pbx);
    if(from_date != NULL) free(from_date);
    if(to_date != NULL) free(to_date);
    if(logo_width != NULL) free(logo_width);
    if(footer != NULL) free(footer);
    if(footer_width != NULL) free(footer_width);
    tmp_columns = columns;
    for(i=0;i<num_cols;i++) {
       if(*tmp_columns != NULL) free(*tmp_columns);
       tmp_columns++;
    }
    free(columns);
    free(ind_columns);
    if(lang_str) free(lang_str);
    if(displayed_duration) free(displayed_duration);

    PQclear(res);

    /* end the transaction */
    res = PQexec(conn, "END");
    PQclear(res);

    if(mypbx && cn && *cn && usergroup && *usergroup && userpbx) {  // *userpbx may be empty
        if(check_db_restore()) {
            do_log(LOG_REPORTING, "", "mypbx (%s): updating missed calls time for cn=%s %s=%s failed: db being restored", ACTION_REPORT, cn, usergroup, userpbx);
        }
        else {
            // update cdr_users table
            // try to update missed_calls_time for CN
            char cn_escaped[strlen(cn) * 2 + 1];
            char userpbx_escaped[strlen(userpbx) * 2 + 1];
            PQescapeStringConn(conn, cn_escaped, cn, sizeof(cn_escaped), NULL);
            PQescapeStringConn(conn, userpbx_escaped, userpbx, sizeof(userpbx_escaped), NULL);
            query = malloc(strlen(QUERY_MISSED_UPDATE) + strlen(cn_escaped) + strlen(usergroup) + strlen(userpbx_escaped) + 1);
            sprintf(query, QUERY_MISSED_UPDATE, cn_escaped, usergroup, userpbx_escaped);
            res = PQexec(conn, query);
            if(PQresultStatus(res) != PGRES_COMMAND_OK) {
                do_log(LOG_REPORTING, "", "mypbx (%s): updating missed calls time for cn=%s %s=%s failed: %s", ACTION_REPORT, cn, usergroup, userpbx, PQerrorMessage(conn));
            }
            PQclear(res);
            free(query);
        }
    }
    if(cn != NULL) free(cn);
    if(usergroup != NULL) free(usergroup);
    if(userpbx != NULL) free(userpbx);

    /* close the connection to the database and cleanup */
    PQfinish(conn);
    if(trace_level & TRACE_TIME) {
        after_time_report = time (NULL);
        gettimeofday(&tvEnd, NULL);
        do_log(LOG_REPORTING, "", "reporting: DB query start %s tuples: %d",asctime(localtime(&curtime_db)), nTuples);
        do_log(LOG_REPORTING, "", "reporting: DB query end is %s",asctime(localtime(&after_time_db)));
        do_log(LOG_REPORTING, "", "reporting: Report time start is %s",asctime(localtime(&curtime_report)));
        do_log(LOG_REPORTING, "", "reporting: Report time end is %s",asctime(localtime(&after_time_report)));
        timeval_subtract(&tvDiff, &tvEnd, &tvBegin);
        do_log(LOG_REPORTING, "", "reporting: %ld.%06ld", tvDiff.tv_sec, tvDiff.tv_usec);
    }

    free_ldap_config(ldap_servers);
    cleanup_config(reporting_cfg);
    return 0;
}
